@@ -243,6 +243,7 @@ namespace bt
 
 		if (check_priority)
 		{
+			during_load = true; // for performance reasons
 			for (Uint32 i = 0;i < tor.getNumFiles();i++)
 			{
 				TorrentFile & tf = tor.getFile(i);
@@ -254,6 +255,8 @@ namespace bt
 					downloadPriorityChanged(&tf,tf.getPriority(),tf.getOldPriority());
 				}
 			}
+			during_load = false;
+			savePriorityInfo();
 		}
 	}
 	
@@ -310,7 +313,7 @@ namespace bt
 		{
 			// load the chunk if it is on disk
 			cache->load(c);
-			loaded.insert(i,bt::GetCurrentTime());
+			loaded[i] = bt::GetCurrentTime();
 			bool check_allowed = do_data_check && (max_chunk_size_for_data_check == 0 || tor.getChunkSize() <= max_chunk_size_for_data_check);
 			
 			// when no corruptions have been found, only check once every 5 chunks
@@ -339,8 +342,12 @@ namespace bt
 				recheck_counter++;
 			}
 		}
+		else
+		{
+			// update timestamp 
+			loaded[i] = bt::GetCurrentTime();
+		}
 		
-		loaded.insert(i,bt::GetCurrentTime());
 		return c;
 	}
 		
@@ -390,9 +397,7 @@ namespace bt
 					cache->save(c);
 				c->clear();
 				c->setStatus(Chunk::ON_DISK);
-				QMap<Uint32,TimeStamp>::iterator j = i;
-				i++;
-				loaded.erase(j);
+				i = loaded.erase(i);
 				num_removed++;
 			}
 			else
@@ -639,6 +644,9 @@ namespace bt
 
 	void ChunkManager::saveFileInfo()
 	{
+		if (during_load)
+			return;
+		
 		// saves which TorrentFiles do not need to be downloaded
 		File fptr;
 		if (!fptr.open(file_info_file,"wb"))
@@ -671,9 +679,6 @@ namespace bt
 	
 	void ChunkManager::loadFileInfo()
 	{
-		if (during_load)
-			return;
-		
 		File fptr;
 		if (!fptr.open(file_info_file,"rb"))
 			return;
@@ -837,12 +842,22 @@ namespace bt
 		else
 		{
 			// check for exceptional case which causes very long loops
-			if (first == last && !isBorderChunk(first))
+			// check for exceptional case which causes very long loops
+			if (first == last)
 			{
-				resetChunk(first);
-				exclude(first,first);
+				if (!isBorderChunk(first))
+				{
+					resetChunk(first);
+					exclude(first,first);
+				}
+				else
+				{
+					if (resetBorderChunk(last,tf)) // try resetting it
+						exclude(first,last);
+				}
 				cache->downloadStatusChanged(tf,download);
 				savePriorityInfo();
+				tor.updateFilePercentage(*this);
 				return;
 			}
 			
@@ -873,6 +888,7 @@ namespace bt
 		// alert the cache but first put things in critical operation mode
 		cache->downloadStatusChanged(tf,download);
 		savePriorityInfo();
+		tor.updateFilePercentage(*this);
 	}
 
 	void ChunkManager::downloadPriorityChanged(TorrentFile* tf,Priority newpriority,Priority oldpriority)
