@@ -27,12 +27,12 @@
 #include "kopetechatsession.h"
 #include "kopeteplugin.h"
 #include "kopetepluginmanager.h"
-#include "kopeteprefs.h"
 #include "kopetestdaction.h"
 #include "kopeteviewmanager.h"
 
 #include <kaction.h>
-#include <kapplication.h>
+#include <ktoolbarspaceraction.h>
+#include <kstandardaction.h>
 #include <kcolordialog.h>
 #include <kconfig.h>
 #include <kcursor.h>
@@ -40,30 +40,40 @@
 #include <kdeversion.h>
 #include <kedittoolbar.h>
 #include <kfontdialog.h>
-#include <kglobalsettings.h>
+#include <kcolorscheme.h>
 #include <khtmlview.h>
 #include <kiconloader.h>
-#include <kkeydialog.h>
 #include <klibloader.h>
 #include <klocale.h>
 #include <kmenubar.h>
 #include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kpushbutton.h>
 #include <ktextedit.h>
-#include <kwin.h>
+#include <kwindowsystem.h>
 #include <kgenericfactory.h>
+#include <kxmlguifactory.h>
+#include <kvbox.h>
+#include <ktoolbar.h>
+#include <kicon.h>
 
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qtimer.h>
-#include <qvbox.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <QCloseEvent>
+#include <QHBoxLayout>
+#include <QList>
+#include <QMovie>
+#include <QSplitter>
+#include <kactioncollection.h>
 
-typedef KGenericFactory<EmailWindowPlugin> EmailWindowPluginFactory;
-K_EXPORT_COMPONENT_FACTORY( kopete_emailwindow, EmailWindowPluginFactory( "kopete_emailwindow" )  )
+K_PLUGIN_FACTORY( EmailWindowPluginFactory, registerPlugin<EmailWindowPlugin>(); )
+K_EXPORT_PLUGIN( EmailWindowPluginFactory( "kopete_emailwindow" ) )
 
-EmailWindowPlugin::EmailWindowPlugin(QObject *parent, const char *name, const QStringList &) :
-	Kopete::ViewPlugin( EmailWindowPluginFactory::instance(), parent, name )
+EmailWindowPlugin::EmailWindowPlugin(QObject *parent, const QVariantList &) :
+	Kopete::ViewPlugin( EmailWindowPluginFactory::componentData(), parent )
 {}
 
 KopeteView* EmailWindowPlugin::createView( Kopete::ChatSession *manager )
@@ -75,11 +85,11 @@ KopeteView* EmailWindowPlugin::createView( Kopete::ChatSession *manager )
 class KopeteEmailWindow::Private
 {
 public:
-	QValueList<Kopete::Message> messageQueue;
+	QList<Kopete::Message> messageQueue;
 	bool showingMessage;
 	bool sendInProgress;
 	bool visible;
-	uint queuePosition;
+	int queuePosition;
 	KPushButton *btnReplySend;
 	KPushButton *btnReadNext;
 	KPushButton *btnReadPrev;
@@ -100,22 +110,22 @@ public:
 KopeteEmailWindow::KopeteEmailWindow( Kopete::ChatSession *manager, EmailWindowPlugin *parent, bool foreignMessage )
 	:  KParts::MainWindow( ), KopeteView( manager, parent ), d( new Private )
 {
-	QVBox *v = new QVBox( this );
+	KVBox *v = new KVBox( this );
 	setCentralWidget( v );
 
 	setMinimumSize( QSize( 75, 20 ) );
 
 	d->split = new QSplitter( v );
-	d->split->setOrientation( QSplitter::Vertical );
+	d->split->setOrientation( Qt::Vertical );
 
-	d->messagePart = new ChatMessagePart( manager, d->split, "messagePart" );
+	d->messagePart = new ChatMessagePart( manager, d->split);
 
 	// FIXME: should this be in ChatView too? maybe move to ChatMessagePart?
 	d->messagePart->view()->setMarginWidth( 4 );
 	d->messagePart->view()->setMarginHeight( 4 );
 	d->messagePart->view()->setMinimumSize( QSize( 75, 20 ) );
 
-	d->editPart = new ChatTextEditPart( manager, d->split, "editPart" );
+	d->editPart = new ChatTextEditPart( manager, d->split );
 
 	/*
 	FIXME: dude, wtf?
@@ -149,7 +159,9 @@ KopeteEmailWindow::KopeteEmailWindow( Kopete::ChatSession *manager, EmailWindowP
 	QWidget *containerWidget = new QWidget( v );
 	containerWidget->setSizePolicy( QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum) );
 
-	QHBoxLayout *h = new QHBoxLayout( containerWidget, 4, 4 );
+	QHBoxLayout *h = new QHBoxLayout( containerWidget );
+	h->setMargin( 4 );
+	h->setSpacing( 4 );
 	h->addStretch();
 
 	d->btnReadPrev = new KPushButton( i18n( "<< Prev" ), containerWidget );
@@ -166,7 +178,7 @@ KopeteEmailWindow::KopeteEmailWindow( Kopete::ChatSession *manager, EmailWindowP
 	h->addWidget( d->btnReplySend, 0, Qt::AlignRight | Qt::AlignVCenter );
 
 	initActions();
-	setWFlags(Qt::WDestructiveClose);
+//	setWFlags(Qt::WDestructiveClose);
 
 	d->showingMessage = false;
 
@@ -175,13 +187,11 @@ KopeteEmailWindow::KopeteEmailWindow( Kopete::ChatSession *manager, EmailWindowP
 	else
 		toggleMode( Send );
 
-	KConfig *config = KGlobal::config();
-	applyMainWindowSettings( config, QString::fromLatin1( "KopeteEmailWindow" )  );
+	KSharedConfig::Ptr config = KGlobal::config();
+	applyMainWindowSettings( config->group( QLatin1String( "KopeteEmailWindow" )  ) );
 
 	d->sendInProgress = false;
 
-	toolBar()->alignItemRight( 99 );
-
 	d->visible = false;
 	d->queuePosition = 0;
 
@@ -195,9 +205,9 @@ KopeteEmailWindow::~KopeteEmailWindow()
 	emit( closing( this ) );
 
 	// saves menubar, toolbar and statusbar setting
-	KConfig *config = KGlobal::config();
-	saveMainWindowSettings( config, QString::fromLatin1( "KopeteEmailWindow" ) );
-	config->sync();
+	KConfigGroup cg( KGlobal::config(), QLatin1String( "KopeteEmailWindow" ) );
+        saveMainWindowSettings( cg );
+	cg.sync();
 
 	delete d;
 }
@@ -206,50 +216,66 @@ void KopeteEmailWindow::initActions(void)
 {
 	KActionCollection *coll = actionCollection();
 
-	d->chatSend = new KAction( i18n( "&Send Message" ), QString::fromLatin1( "mail_send" ), 0,
-		this, SLOT( slotReplySend() ), coll, "chat_send" );
+	d->chatSend = new KAction( KIcon("mail-send"), i18n( "&Send Message" ), this );
+        coll->addAction( "chat_send", d->chatSend );
 	//Default to 'Return' for sending messages
-	d->chatSend->setShortcut( QKeySequence( Key_Return ) );
+	d->chatSend->setShortcut( QKeySequence( Qt::Key_Return ) );
+	connect( d->chatSend, SIGNAL(triggered()), this, SLOT( slotReplySend()) );
 
-	KStdAction::quit ( this, SLOT( slotCloseView() ), coll );
+	KStandardAction::quit ( this, SLOT( slotCloseView() ), coll );
 
-	KStdAction::cut( d->editPart->widget(), SLOT( cut() ), coll );
-	KStdAction::copy( this, SLOT(slotCopy()), coll);
-	KStdAction::paste( d->editPart->widget(), SLOT( paste() ), coll );
+	KStandardAction::cut( d->editPart->widget(), SLOT( cut() ), coll );
+	KStandardAction::copy( this, SLOT(slotCopy()), coll);
+	KStandardAction::paste( d->editPart->widget(), SLOT( paste() ), coll );
 
-	new KAction( i18n( "&Set Font..." ), QString::fromLatin1( "charset" ), 0,
-	             d->editPart, SLOT( setFont() ), coll, "format_font" );
-	new KAction( i18n( "Set Text &Color..." ), QString::fromLatin1( "pencil" ), 0,
-	             d->editPart, SLOT( setFgColor() ), coll, "format_color" );
-	new KAction( i18n( "Set &Background Color..." ), QString::fromLatin1( "fill" ), 0,
-	             d->editPart, SLOT( setBgColor() ), coll, "format_bgcolor" );
+	KAction* action;
+	action = new KAction( KIcon("preferences-desktop-font"), i18n( "&Set Font..." ), coll );
+        coll->addAction( "format_font", action );
+	connect( action, SIGNAL(triggered(bool)), d->editPart, SLOT(setFont()) );
 
-	KStdAction::showMenubar( this, SLOT( slotViewMenuBar() ), coll );
+	action = new KAction( KIcon("format-stroke-color"), i18n( "Set Text &Color..." ), coll );
+        coll->addAction( "format_color", action );
+	connect( action, SIGNAL(triggered()), d->editPart, SLOT(setForegroundColorColor()) );
+
+	action = new KAction( KIcon("format-fill-color"), i18n( "Set &Background Color..." ), coll );
+        coll->addAction( "format_bgcolor", action );
+	connect( action, SIGNAL(triggered()), d->editPart, SLOT(setBackgroundColorColor()) );
+
+	KStandardAction::showMenubar( this, SLOT( slotViewMenuBar() ), coll );
 	setStandardToolBarMenuEnabled( true );
 
-	d->actionSmileyMenu = new KopeteEmoticonAction( coll, "format_smiley" );
+	d->actionSmileyMenu = new KopeteEmoticonAction( coll );
+        coll->addAction( "format_smiley", d->actionSmileyMenu );
 	d->actionSmileyMenu->setDelayed( false );
 	connect(d->actionSmileyMenu, SIGNAL(activated(const QString &)), this, SLOT(slotSmileyActivated(const QString &)));
 
 	// add configure key bindings menu item
-	KStdAction::keyBindings( guiFactory(), SLOT( configureShortcuts() ), coll );
-	KStdAction::configureToolbars(this, SLOT( slotConfToolbar() ), coll);
+	KStandardAction::keyBindings( guiFactory(), SLOT( configureShortcuts() ), coll );
+	KStandardAction::configureToolbars(this, SLOT( slotConfToolbar() ), coll);
 	//FIXME: no longer works?
 	KopeteStdAction::preferences( coll , "settings_prefs" );
 
 	// The animated toolbarbutton
-	d->normalIcon = QPixmap( BarIcon( QString::fromLatin1( "kopete" ) ) );
-	d->animIcon = KGlobal::iconLoader()->loadMovie( QString::fromLatin1( "newmessage" ), KIcon::Toolbar);
-	d->animIcon.pause();
+	d->normalIcon = QPixmap( BarIcon( QLatin1String( "kopete" ) ) );
+//	d->animIcon = KGlobal::iconLoader()->loadMovie( QLatin1String( "newmessage" ), KIconLoader::Toolbar);
+	d->animIcon.setPaused(true);
 
-	d->anim = new QLabel( this, "kde toolbar widget" );
+	d->anim = new QLabel( this );
+	d->anim->setObjectName( QLatin1String("kde toolbar widget") );
 	d->anim->setMargin( 5 );
 	d->anim->setPixmap( d->normalIcon );
-	new KWidgetAction( d->anim, i18n("Toolbar Animation"), 0, 0, 0, coll, "toolbar_animation" );
 
-	setXMLFile( QString::fromLatin1( "kopeteemailwindow.rc" ) );
+	KAction *spacerAction = new KToolBarSpacerAction( this );
+	spacerAction->setText( i18n( "Spacer for animation" ) );
+	coll->addAction( "toolbar_spacer", spacerAction );
+
+	KAction *animAction = new KAction( i18n("Toolbar Animation"), coll );
+        coll->addAction( "toolbar_animation", action );
+	animAction->setDefaultWidget( d->anim );
+
+	setXMLFile( QLatin1String( "kopeteemailwindow.rc" ) );
 	createGUI( d->editPart );
-	//createGUI( QString::fromLatin1( "kopeteemailwindow.rc" ) );
+	//createGUI( QLatin1String( "kopeteemailwindow.rc" ) );
 	guiFactory()->addClient(m_manager);
 }
 
@@ -280,24 +306,26 @@ void KopeteEmailWindow::slotSmileyActivated(const QString &sm )
 
 void KopeteEmailWindow::slotConfToolbar()
 {
-	saveMainWindowSettings(KGlobal::config(), QString::fromLatin1( "KopeteEmailWindow" ));
-	KEditToolbar *dlg = new KEditToolbar(actionCollection(), QString::fromLatin1("kopeteemailwindow.rc") );
+        KConfigGroup cg( KGlobal::config(), QLatin1String( "KopeteEmailWindow" ) );
+	saveMainWindowSettings( cg );
+	KEditToolBar *dlg = new KEditToolBar(actionCollection());
+	dlg->setResourceFile("kopeteemailwindow.rc");
 	if (dlg->exec())
 	{
 		createGUI( d->editPart );
-		applyMainWindowSettings(KGlobal::config(), QString::fromLatin1( "KopeteEmailWindow" ));
+		applyMainWindowSettings( cg );
 	}
 	delete dlg;
 }
 
 void KopeteEmailWindow::slotCopy()
 {
-//	kdDebug(14010) << k_funcinfo << endl;
+//	kDebug(14010) ;
 
 	if ( d->messagePart->hasSelection() )
 		d->messagePart->copy();
 	else
-		d->editPart->widget()->copy();
+		d->editPart->textEdit()->copy();
 }
 
 void KopeteEmailWindow::appendMessage(Kopete::Message &message)
@@ -313,7 +341,10 @@ void KopeteEmailWindow::appendMessage(Kopete::Message &message)
 			slotReadNext();
 		else
 		{
-			d->btnReadNext->setPaletteForegroundColor( QColor("red") );
+			QPalette palette;
+			palette.setColor(d->btnReadNext->foregroundRole(), QColor("red") );
+			d->btnReadNext->setPalette(palette);
+
 			updateNextButton();
 		}
 
@@ -325,7 +356,7 @@ void KopeteEmailWindow::appendMessage(Kopete::Message &message)
 
 void KopeteEmailWindow::slotMarkMessageRead()
 {
-	d->unreadMessageFrom = QString::null;
+	d->unreadMessageFrom.clear();
 }
 
 void KopeteEmailWindow::updateNextButton()
@@ -334,7 +365,9 @@ void KopeteEmailWindow::updateNextButton()
 	{
 		d->btnReadNext->setEnabled( false );
 
-		d->btnReadNext->setPaletteForegroundColor( KGlobalSettings::textColor() );
+		QPalette palette;
+		palette.setColor(d->btnReadNext->foregroundRole(), KColorScheme(QPalette::Active, KColorScheme::View).foreground().color() );
+		d->btnReadNext->setPalette(palette);
 	}
 	else
 		d->btnReadNext->setEnabled( true );
@@ -344,7 +377,7 @@ void KopeteEmailWindow::updateNextButton()
 	else
 		d->btnReadPrev->setEnabled( true );
 
-	d->btnReadNext->setText( i18n( "(%1) Next >>" ).arg( d->messageQueue.count() - d->queuePosition ) );
+	d->btnReadNext->setText( i18n( "(%1) Next >>", d->messageQueue.count() - d->queuePosition ) );
 }
 
 void KopeteEmailWindow::slotUpdateReplySend()
@@ -361,26 +394,26 @@ void KopeteEmailWindow::slotUpdateReplySend()
 
 void KopeteEmailWindow::slotReadNext()
 {
-//	kdDebug(14010) << k_funcinfo << endl;
+//	kDebug(14010) ;
 
 	d->showingMessage = true;
 
 	d->queuePosition++;
 
-	writeMessage( (*d->messageQueue.at( d->queuePosition - 1 )) );
+	writeMessage( (d->messageQueue[ d->queuePosition - 1 ]) );
 
 	updateNextButton();
 }
 
 void KopeteEmailWindow::slotReadPrev()
 {
-//	kdDebug(14010) << k_funcinfo << endl;
+//	kDebug(14010) ;
 
 	d->showingMessage = true;
 
 	d->queuePosition--;
 
-	writeMessage( (*d->messageQueue.at( d->queuePosition - 1 )) );
+	writeMessage( (d->messageQueue[ d->queuePosition - 1 ]) );
 
 	updateNextButton();
 }
@@ -396,8 +429,8 @@ void KopeteEmailWindow::sendMessage()
 	if ( !d->editPart->canSend() )
 		return;
 	d->sendInProgress = true;
-	d->anim->setMovie( d->animIcon );
-	d->animIcon.unpause();
+	d->anim->setMovie( &d->animIcon );
+	d->animIcon.setPaused(false);
 	d->editPart->widget()->setEnabled( false );
 	d->editPart->sendMessage();
 }
@@ -406,7 +439,7 @@ void KopeteEmailWindow::messageSentSuccessfully()
 {
 	d->sendInProgress = false;
 	d->anim->setPixmap( d->normalIcon );
-	d->animIcon.pause();
+	d->animIcon.setPaused(true);
 	closeView();
 }
 
@@ -418,27 +451,27 @@ bool KopeteEmailWindow::closeView( bool force )
 	{
 		if( m_manager->members().count() > 1 )
 		{
-			QString shortCaption = caption();
+			QString shortCaption = windowTitle();
 			if( shortCaption.length() > 40 )
-				shortCaption = shortCaption.left( 40 ) + QString::fromLatin1("...");
+				shortCaption = shortCaption.left( 40 ) + QLatin1String("...");
 
-			response = KMessageBox::warningContinueCancel(this, i18n("<qt>You are about to leave the group chat session <b>%1</b>.<br>"
-				"You will not receive future messages from this conversation.</qt>").arg(shortCaption), i18n("Closing Group Chat"),
-				i18n("Cl&ose Chat"), QString::fromLatin1("AskCloseGroupChat"));
+			response = KMessageBox::warningContinueCancel(this, i18n("<qt>You are about to leave the groupchat session <b>%1</b>.<br />"
+				"You will not receive future messages from this conversation.</qt>", shortCaption), i18n("Closing Group Chat"),
+				KGuiItem( i18n("Cl&ose Chat") ), KStandardGuiItem::cancel(), QLatin1String("AskCloseGroupChat"));
 		}
 
 		if( !d->unreadMessageFrom.isNull() && ( response == KMessageBox::Continue ) )
 		{
 			response = KMessageBox::warningContinueCancel(this, i18n("<qt>You have received a message from <b>%1</b> in the last "
-				"second. Are you sure you want to close this chat?</qt>").arg(d->unreadMessageFrom), i18n("Unread Message"),
-				i18n("Cl&ose Chat"), QString::fromLatin1("AskCloseChatRecentMessage"));
+				"second. Are you sure you want to close this chat?</qt>", d->unreadMessageFrom), i18n("Unread Message"),
+				KGuiItem( i18n("Cl&ose Chat") ), KStandardGuiItem::cancel(), QLatin1String("AskCloseChatRecentMessage"));
 		}
 
 		if( d->sendInProgress  && ( response == KMessageBox::Continue ) )
 		{
 			response = KMessageBox::warningContinueCancel(this, i18n("You have a message send in progress, which will be "
 				"aborted if this chat is closed. Are you sure you want to close this chat?"), i18n("Message in Transit"),
-				i18n("Cl&ose Chat"), QString::fromLatin1("AskCloseChatMessageInProgress") );
+				KGuiItem( i18n("Cl&ose Chat") ), KStandardGuiItem::cancel(), QLatin1String("AskCloseChatMessageInProgress") );
 		}
 	}
 
@@ -477,7 +510,7 @@ void KopeteEmailWindow::toggleMode( WindowMode newMode )
 			d->btnReadPrev->show();
 			break;
 		case Reply:
-			QValueList<int> splitPercent;
+			QList<int> splitPercent;
 			// FIXME: should be saved and restored
 			splitPercent.append(50);
 			splitPercent.append(50);
@@ -505,11 +538,11 @@ void KopeteEmailWindow::slotReplySend()
 void KopeteEmailWindow::raise(bool activate)
 {
 	makeVisible();
-
-	if ( !KWin::windowInfo( winId(), NET::WMDesktop ).onAllDesktops() )
-		KWin::setOnDesktop( winId(), KWin::currentDesktop() );
-
-	KMainWindow::raise();
+#ifdef Q_WS_X11
+	if ( !KWindowSystem::windowInfo( winId(), NET::WMDesktop ).onAllDesktops() )
+		KWindowSystem::setOnDesktop( winId(), KWindowSystem::currentDesktop() );
+#endif
+	KXmlGuiWindow::raise();
 
 	/* Removed Nov 2003
 	According to Zack, the user double-clicking a contact is not valid reason for a non-pager
@@ -519,21 +552,20 @@ void KopeteEmailWindow::raise(bool activate)
 	Redirect any bugs relating to the widnow now not grabbing focus on clicking a contact to KWin.
 		- Jason K
 	*/
-
 	//Will not activate window if user was typing
 	if(activate)
-		KWin::activateWindow( winId() );
+		KWindowSystem::activateWindow( winId() );
 }
 
-void KopeteEmailWindow::windowActivationChange( bool )
+void KopeteEmailWindow::changeEvent( QEvent *e )
 {
-	if( isActiveWindow() )
+	if( e->type() == QEvent::ActivationChange && isActiveWindow() )
 		emit( activated( static_cast<KopeteView*>(this) ) );
 }
 
 void KopeteEmailWindow::makeVisible()
 {
-//	kdDebug(14010) << k_funcinfo << endl;
+//	kDebug(14010) ;
 	d->visible = true;
 	show();
 }
