@@ -2,7 +2,7 @@
     appearanceconfig.h  -  Kopete Look Feel Config
 
     Copyright (c) 2001-2002 by Duncan Mac-Vicar Prett <duncan@kde.org>
-    Copyright (c) 2005      by Michaël Larouche       <michael.larouche@kdemail.net>
+    Copyright (c) 2005      by Michaël Larouche       <larouche@kde.org>
 
     Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -19,48 +19,32 @@
 #ifndef __APPEARANCE_H
 #define __APPEARANCE_H
 
-#include "kcmodule.h"
-#include <qptrlist.h>
-#include <qmap.h>
+#define KDE3_SUPPORT
+#include <kcmodule.h>
+#undef KDE3_SUPPORT
 
 /**
  * @author Duncan Mac-Vicar P. <duncan@kde.org>
- * @author Michaël Larouche <michael.larouche@kdemail.net>
+ * @author Michaël Larouche <larouche@kde.org>
  */
 class AppearanceConfig : public KCModule
 {
 	Q_OBJECT
 
-friend class KopeteStyleNewStuff;
 
 public:
-	AppearanceConfig( QWidget *parent, const char *name, const QStringList &args );
+	AppearanceConfig( QWidget *parent, const QVariantList &args );
 	~AppearanceConfig();
 
 	virtual void save();
 	virtual void load();
 
 private slots:
-	void slotSelectedEmoticonsThemeChanged();
-	void slotUpdateChatPreview();
 	void slotHighlightChanged();
 	void slotChangeFont();
-	void slotInstallChatStyle();
-	void slotDeleteChatStyle();
-	void slotChatStyleSelected();
-	void slotChatStyleVariantSelected(const QString &variantName);
 	void slotEditTooltips();
 	void emitChanged();
-	void installEmoticonTheme();
-	void removeSelectedEmoticonTheme();
-	void slotGetEmoticonThemes();
-	void slotGetChatStyles();
-	void slotLoadChatStyles();
-	void updateEmoticonsButton(bool);
 private:
-	void updateEmoticonlist();
-	void createPreviewChatSession();
-	void createPreviewMessages();
 	
 private:
 	class Private;
