@@ -4,7 +4,7 @@
     Logic for exporting data acquired from messaging systems to the 
     KDE address book
 
-    Copyright (c) 2004 by Will Stephenson <lists@stevello.free-online.co.uk>
+    Copyright (c) 2004 by Will Stephenson <wstephenson@kde.org>
 
     Kopete    (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
 
@@ -24,12 +24,13 @@
 #include <kabc/stdaddressbook.h>
 #include <kabc/addressee.h>
 
-#include "kopetecontactproperty.h"
+#include "kopeteproperty.h"
+#include "ui_kopeteaddrbookexportui.h"
+//Added by qt3to4:
+#include <QPixmap>
 
-class AddressBookExportUI;
-class KDialogBase;
-class KListBox;
-class KComboBox;
+class KDialog;
+class K3ListBox;
 
 namespace Kopete
 {
@@ -37,7 +38,7 @@ class Contact;
 class MetaContact;
 }
 
-class KopeteAddressBookExport : public QObject
+class KopeteAddressBookExport : public QObject, private Ui::AddressBookExportUI
 {
 public:
 	KopeteAddressBookExport( QWidget *parent, Kopete::MetaContact *mc );
@@ -65,7 +66,7 @@ protected:
 	/**
 	 * Populate a listbox with a given type of phone number
 	 */
-	void fetchPhoneNumbers( KListBox * listBox, int type, uint& counter );
+	void fetchPhoneNumbers( K3ListBox * listBox, KABC::PhoneNumber::Type type, uint& counter );
 	/**
 	 * Populate the GUI with data from IM systems
 	 */
@@ -74,20 +75,20 @@ protected:
 	 * Populate a combobox with a contact's IM data
 	 */
 	void populateIM( const Kopete::Contact *contact, const QPixmap &icon, 
-			QComboBox *combo, const Kopete::ContactPropertyTmpl &property );
+			QComboBox *combo, const Kopete::PropertyTmpl &property );
 	/**
 	 * Populate a listbox with a contact's IM data
 	 */
 	void populateIM( const Kopete::Contact *contact, const QPixmap &icon, 
-			KListBox *combo, const Kopete::ContactPropertyTmpl &property );
+			K3ListBox *combo, const Kopete::PropertyTmpl &property );
 	
 	/** Check the selected item is not the first (existing KABC) item, or the same as it */
 	bool newValue( QComboBox *combo );
-	QStringList newValues( KListBox *listBox, uint counter );
+	QStringList newValues( K3ListBox *listBox, uint counter );
 	
 	// the GUI
 	QWidget *mParent;
-	KDialogBase * mDialog;
+	KDialog * mDialog;
 	QPixmap mAddrBookIcon;
 	AddressBookExportUI *mUI;
 	Kopete::MetaContact *mMetaContact;
