@@ -5,7 +5,7 @@
     Copyright (c) 2001-2002 by Stefan Gehn            <metz AT gehn.net>
     Copyright (c) 2002-2003 by Martijn Klingens       <klingens@kde.org>
 
-    Kopete    (c) 2002-2003 by the Kopete developers  <kopete-devel@kde.org>
+    Kopete    (c) 2002-2008 by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -20,50 +20,37 @@
 #ifndef KOPETEWINDOW_H
 #define KOPETEWINDOW_H
 
-#include <qptrdict.h>
+// Qt includes
+#include <QtGui/QLabel>
 
-#include <kmainwindow.h>
-#include <qlabel.h>
+// KDE includes
+#include <kxmlguiwindow.h>
 
-class QHBox;
-class QTimer;
-class QSignalMapper;
+class QCloseEvent;
+class QEvent;
+class QShowEvent;
 
-class QMouseEvent;
-class QPoint;
-
-class KAction;
-class KActionMenu;
-
-class KGlobalAccel;
-class KSelectAction;
-class KSqueezedTextLabel;
-class KToggleAction;
-
-class KopeteAccountStatusBarIcon;
-class KopeteContactListView;
-class KopetePluginConfig;
-class KopeteSystemTray;
-class KopeteEditGlobalIdentityWidget;
+class KMenu;
 
 namespace Kopete
 {
-class AwayAction;
-class Account;
-class Contact;
-class Plugin;
-class Protocol;
+	class Identity;
+	class Account;
+	class Contact;
+	class Plugin;
+	class StatusMessage;
+	class StatusRootAction;
 }
 
 /**
  * @author Duncan Mac-Vicar P. <duncan@kde.org>
  */
-class KopeteWindow : public KMainWindow
+class KopeteWindow : public KXmlGuiWindow
 {
 	Q_OBJECT
 
 public:
-	KopeteWindow ( QWidget *parent = 0, const char *name = 0 );
+	explicit KopeteWindow ( QWidget *parent = 0 );
 	~KopeteWindow();
 
 	virtual bool eventFilter( QObject* o, QEvent* e );
@@ -72,34 +59,41 @@ protected:
 	virtual void closeEvent( QCloseEvent *ev );
 	virtual void leaveEvent( QEvent* ev );
 	virtual void showEvent( QShowEvent* ev );
+	virtual void hideEvent( QHideEvent* ev );
 
 private slots:
-	void showMenubar();
-	void showStatusbar();
-	void slotToggleShowOffliners();
+	void slotToggleShowAllOfflineEmpty( bool toggled );
+	void slotToggleShowOfflineUsers();
 	void slotToggleShowEmptyGroups();
 	void slotConfigChanged();
 	void slotConfNotifications();
 	void slotConfToolbar();
 	void slotUpdateToolbar();
-	void slotConfigurePlugins();
 	void slotConfGlobalKeys();
 	void slotShowHide();
 	void slotToggleAway();
 
-	/* show the global status message selector menu
-	 */
-	void setStatusMessage( const QString & );
-	
+
+	void setStatusMessage( const Kopete::StatusMessage& );
+
+	void globalStatusChanged();
+
 	/**
 	 * Checks if the mousecursor is in the contact list.
 	 * If not, the window will be hidden.
 	 */
 	void slotAutoHide();
+	
+	/**
+	 * Resize window to fit size of contact list nicely.
+	 */
+	void slotUpdateSize();
+
+	void slotStartAutoResizeTimer();
 
 	/**
 	 * This slot will apply settings that change the
-	 * contactlist's appearance. Only autohiding is
+	 * contact list's appearance. Only autohiding is
 	 * handled here at the moment
 	 */
 	void slotContactListAppearanceChanged();
@@ -122,39 +116,48 @@ private slots:
 	void slotPluginLoaded( Kopete::Plugin *p );
 
 	/**
-	 * Get a notification when an account is created, so we can add a status bar
+	 * Get a notification when an identity is created, so we can add a status bar
 	 * icon
+	 * @param identity the registered identity
 	 */
-	void slotAccountRegistered( Kopete::Account *a );
+	void slotIdentityRegistered( Kopete::Identity *identity );
 
 	/**
-	 * Cleanup the status bar icon when the account is destroyed
+	 * Cleanup the status bar icon when the identity is destroyed
+	 * @param identity the unregistered identity
 	 */
-	void slotAccountUnregistered( const Kopete::Account *a);
+	void slotIdentityUnregistered( const Kopete::Identity *identity );
+
+	/**
+	 * The tooltip got changed, update it.
+	 * @param identity the identity that has changed
+	 */
+	void slotIdentityToolTipChanged( Kopete::Identity *identity );
 
 	/**
 	 * The status icon got changed, update it.
-	 * @param contact The account's contact that changed.
+	 * @param identity the identity that has changed
 	 */
-	void slotAccountStatusIconChanged( Kopete::Contact * contact);
+	void slotIdentityStatusIconChanged( Kopete::Identity *identity );
 
 	/**
-	 * The status icon of some account changed. Must be sent by the account in question.
+	 * Show a in-place widget for an identity
 	 */
-	void slotAccountStatusIconChanged();
-
-	/**
-	 * Show a context menu for a protocol
-	 */
-//	void slotProtocolStatusIconRightClicked( Kopete::Protocol *proto, const QPoint &p );
-
-	/**
-	 * Show a context menu for an account
-	 */
-	void slotAccountStatusIconRightClicked( Kopete::Account *a,
+	void slotIdentityStatusIconLeftClicked( Kopete::Identity *i,
 		const QPoint &p );
 
-	void slotTrayAboutToShowMenu(KPopupMenu *);
+
+	/**
+	 * This is used to add the account to the "Add Contact" submenu
+	 */
+	void slotAccountRegistered( Kopete::Account *account );
+
+	/**
+	 * This is used to add the account to the "Add Contact" submenu
+	 */
+	void slotAccountUnregistered( const Kopete::Account *account );
+
+	void slotTrayAboutToShowMenu(KMenu *);
 
 	/**
 	 * Show the Add Contact wizard
@@ -172,18 +175,21 @@ private slots:
 	 * signals.
 	 */
 	void slotAllPluginsLoaded();
-	
-	/**
-	 * Protected slot to setup the Set Global Status Message menu.
-	 */
-	void slotBuildStatusMessageMenu();
-	void slotStatusMessageSelected( int i );
-	void slotNewStatusMessageEntered();
 
-        /**
-         * Show the set global status message menu when clicking on the icon in the status bar.
-         */
-        void slotGlobalStatusMessageIconClicked( const QPoint &position );
+	/**
+	 * Show the set global status message menu when clicking on the icon in the status bar.
+	 */
+	void slotGlobalStatusMessageIconClicked( const QPoint &position );
+
+	/**
+	 * Show Info Event widget and if necessary raise the Kopete window.
+	 */
+	void slotShowInfoEventWidget();
+
+	/**
+	 * Show/hide Info Event widget.
+	 */
+	void slotInfoIconClicked();
 
 	/**
 	 * Extracts protocolId and accountId from the single QString argument signalled by a QSignalMapper,
@@ -192,36 +198,9 @@ private slots:
 	 * We need both to uniquely identify an account, but QSignalMapper only emits one QString.
 	 */
 	void slotAddContactDialogInternal( const QString & accountIdentifier );
-	
-public:
-	KopeteContactListView *contactlist;
 
-	// Some Actions
-	KActionMenu* actionAddContact;
+	void updateStatusMenuMessage( Kopete::StatusRootAction *statusRootAction );
 
-	//KActionMenu* actionConnectionMenu;
-	//KAction* actionConnect;
-	KAction* actionDisconnect;
-	KAction* actionExportContacts;
-
-	KActionMenu* actionAwayMenu;
-	KActionMenu* actionDockMenu;
-	KAction* selectAway;
-	KAction* selectBusy;
-	KAction* actionSetAvailable;
-	KAction* actionSetInvisible;
-
-
-	KAction* actionPrefs;
-	KAction* actionQuit;
-	KAction* actionSave;
-	KToggleAction *menubarAction;
-	KToggleAction *statusbarAction;
-	KToggleAction *actionShowOffliners;
-	KToggleAction *actionShowEmptyGroups;
-	KGlobalAccel *globalAccel;
-
-	KopeteEditGlobalIdentityWidget *editGlobalIdentityWidget;
 private:
 	void initView();
 	void initActions();
@@ -234,31 +213,10 @@ private:
 
 	virtual bool queryClose();
 	virtual bool queryExit();
+
 private:
-	int docked;
-	bool hidden;
-	int deskRight;
-	QPoint position;
-	QHBox *m_statusBarWidget;
-	KopeteSystemTray *m_tray;
-	bool m_autoHide;
-	unsigned int m_autoHideTimeout;
-	QTimer* m_autoHideTimer;
-	QSignalMapper* addContactMapper;
-
-	KopetePluginConfig *m_pluginConfig;
-
-	/**
-	 * This is really a dictionary of KopeteAccountStatusBarIcon objects, but
-	 * QPtrDict requires a full class definition to be known to make
-	 * that work. And since I don't want to include that whole file here,
-	 * use QObject instead.
-	 */
-	QPtrDict<QObject> m_accountStatusBarIcons;
-	KSqueezedTextLabel * m_globalStatusMessage;
-	KPopupMenu * m_globalStatusMessageMenu;
-	QLineEdit * m_newMessageEdit;
-	QString m_globalStatusMessageStored;
+	class Private;
+	Private *d;
 };
 
 
@@ -266,7 +224,7 @@ class GlobalStatusMessageIconLabel : public QLabel
 {
       Q_OBJECT
 public:
-      GlobalStatusMessageIconLabel(QWidget *parent = 0, const char *name = 0);
+      GlobalStatusMessageIconLabel(QWidget *parent = 0);
 
 protected:
       void mouseReleaseEvent(QMouseEvent *event);
@@ -276,5 +234,22 @@ signals:
 
 };
 
+class InfoEventIconLabel : public QLabel
+{
+	Q_OBJECT
+public:
+	InfoEventIconLabel( QWidget *parent = 0 );
+
+protected:
+	void mouseReleaseEvent( QMouseEvent *event );
+
+signals:
+	void clicked();
+
+private slots:
+	void updateIcon();
+
+};
+
 #endif
 // vim: set noet ts=4 sts=4 sw=4:
