@@ -1,7 +1,7 @@
 /*
     kopeteplugindataobject.h - Kopete Plugin Data Object
 
-    Copyright (c) 2003-2004 by Olivier Goffart       <ogoffart@ tiscalinet.be>
+    Copyright (c) 2003-2005 by Olivier Goffart       <ogoffart@kde.org>
     Copyright (c) 2003      by Martijn Klingens      <klingens@kde.org>
     Copyright (c) 2004      by Richard Smith         <kde@metafoo.co.uk>
     Kopete    (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
@@ -16,13 +16,14 @@
     *************************************************************************
 */
 
-#ifndef KOPETEPLUGINDATAOBJECT_H
-#define KOPETEPLUGINDATAOBJECT_H
+#ifndef KOPETECONTACTLISTELEMENT_H
+#define KOPETECONTACTLISTELEMENT_H
 
-#include <qobject.h>
-#include <qdom.h>
+#include <QtCore/QList>
+#include <QtCore/QMap>
 
 #include "kopete_export.h"
+#include "kopetepropertycontainer.h"
 
 namespace Kopete {
 
@@ -30,28 +31,41 @@ class Plugin;
 
 
 /**
- * @author Olivier Goffart  <ogoffart@ tiscalinet.be>
+ * @author Olivier Goffart
  *
- * This is the base class for  base elements of the contactlist.
+ * This is the base class for base elements of the contact list.
  * His purpose is to share the code between @ref Group and @ref MetaContact
  *
- * It handle the saving and loading of plugin data from the contactlist.
- * Plugins may set custom datas to metaocntacts or groups by calling @ref setPluginData
- * and may retreive them with @ref pluginData
+ * It handle the saving and loading of plugin data from the contact list.
+ * Plugins may set custom data to metaocntacts or groups by calling @ref setPluginData
+ * and may retrieve them with @ref pluginData
  *
  * It also allow to store an icon for this element.
  */
-class KOPETE_EXPORT ContactListElement : public QObject  /* public KopeteNotifyDataObject */
+class KOPETE_EXPORT ContactListElement
+	: public PropertyContainer  /* public KopeteNotifyDataObject */
 {
 	Q_OBJECT
 
 protected:
-	ContactListElement( QObject *parent = 0L, const char *name = 0L );
+	ContactListElement( QObject *parent = 0L );
 	~ContactListElement();
 
 
 public:
 
+	/**
+	 * @brief Set if we are in loading stage.
+	 */
+	void setLoading( bool value );
+
+	/**
+	 * @brief Check if we are in loading stage.
+	 *
+	 * @return true if we are in loading stage.
+	 */
+	bool loading() const;
+
 	/**
 	 * Set the plugin-specific data.
 	 * The data in the provided QMap is a set of key/value pairs.
@@ -64,6 +78,8 @@ public:
 	 *          that takes a single field as parameter.
 	 */
 	void setPluginData( Plugin *plugin, const QMap<QString, QString> &value );
+	
+	void setPluginData( const QString &pluginId, const QMap<QString, QString> &pluginData );
 
 	/**
 	 * Convenience method to store or change only a single field of the
@@ -92,6 +108,13 @@ public:
 	 * constructors).
 	 */
 	QString pluginData( Plugin *plugin, const QString &key ) const;
+	
+	typedef QMap<QString, QMap<QString, QString> > PluginDataMap;
+	
+	/**
+	 * return plugin-specific data for all plugins
+	 */
+	const PluginDataMap pluginData() const;
 
 	/**
 	 * The various icon states. Some state are reserved for Groups,
@@ -99,6 +122,12 @@ public:
 	 * 'None' is the default icon.
 	 */
 	enum IconState { None, Open, Closed, Online, Away, Offline, Unknown };
+	typedef QMap<IconState, QString> IconMap;
+	
+	/**
+	 * return all registered icons
+	 */
+	const IconMap icons() const;
 
 	/**
 	 * return the icon for this object, in the given state.
@@ -109,7 +138,7 @@ public:
 
 	/**
 	 * Set the icon in the given state
-	 * To clear an entry, set a QString::null
+	 * To clear an entry, set a QString()
 	 */
 	void setIcon( const QString &icon, IconState = None );
 
@@ -146,19 +175,6 @@ signals:
 	 */
 	void useCustomIconChanged( bool useCustomIcon );
 
-protected:
-	/**
-	 * Return a XML representation of plugin data
-	 */
-	const QValueList<QDomElement> toXML();
-
-	/**
-	 * Load plugin data from one Dom Element:
-	 * It should be a <plugin-data> element or a <custom-icons> element. if not, nothing will happen
-	 * @return true if something has ben loaded. false if the element was not a fine
-	 */
-	bool fromXML( const QDomElement &element );
-
 private:
 	class Private;
 	Private *d;
@@ -166,7 +182,6 @@ private:
 
 } //END namespace Kopete
 
-#endif
+#endif // KOPETECONTACTLISTELEMENT_H
 
 // vim: set noet ts=4 sts=4 sw=4:
-
