@@ -16,32 +16,29 @@
 
 #include "kopeteuiglobal.h"
 #include "kopetepassword.h"
-#include "kopetepassworddialog.h"
 #include "kopetewalletmanager.h"
 
 #include <kwallet.h>
 
-#include <qapplication.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qcheckbox.h>
-
-#include <kactivelabel.h>
-#include <kapplication.h>
+#include <QApplication>
+#include <QLabel>
+#include <QLineEdit>
+#include <QCheckBox>
+#include <k3activelabel.h>
 #include <kconfig.h>
 #include <kdebug.h>
-#include <kdialogbase.h>
+#include <kdialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kiconloader.h>
-#include <kpassdlg.h>
 #include <kstringhandler.h>
+#include <kpassworddialog.h>
 
 class Kopete::Password::Private
 {
 public:
-	Private( const QString &group, uint maxLen, bool blanksAllowed )
-	 : refCount( 1 ), configGroup( group ), remembered( false ), maximumLength( maxLen ),
+	Private( const QString &group, bool blanksAllowed )
+	 : refCount( 1 ), configGroup( group ), remembered( false ),
 	 isWrong( false ), allowBlankPassword( blanksAllowed )
 	{
 	}
@@ -61,10 +58,8 @@ public:
 	const QString configGroup;
 	/** Is the password being remembered? */
 	bool remembered;
-	/** The current password in the KConfig file, or QString::null if no password there */
+	/** The current password in the KConfig file, or QString() if no password there */
 	QString passwordFromKConfig;
-	/** The maximum length allowed for this password, or -1 if there is no limit */
-	uint maximumLength;
 	/** Is the current password known to be wrong? */
 	bool isWrong;
 	/** Are we allowed to have blank passwords? */
@@ -91,13 +86,14 @@ public:
 	 */
 	void begin()
 	{
-		kdDebug( 14010 ) << k_funcinfo << endl;
+		kDebug( 14010 );
+
 		Kopete::WalletManager::self()->openWallet( this, SLOT( walletReceived( KWallet::Wallet* ) ) );
 	}
 
 	void walletReceived( KWallet::Wallet *wallet )
 	{
-		kdDebug( 14010 ) << k_funcinfo << endl;
+		kDebug( 14010 ) ;
 		mWallet = wallet;
 		processRequest();
 	}
@@ -107,7 +103,7 @@ public:
 	 */
 	virtual void processRequest() = 0;
 
-	void slotOkPressed() {}
+	void gotPassword(const QString&, bool) {}
 	void slotCancelPressed() {}
 
 protected:
@@ -133,6 +129,7 @@ public:
 		// Before trying to read from the wallet, check if the config file holds a password.
 		// If so, remove it from the config and set it through KWallet instead.
 		QString pwd;
+
 		if ( mPassword.d->remembered && !mPassword.d->passwordFromKConfig.isNull() )
 		{
 			pwd = mPassword.d->passwordFromKConfig;
@@ -140,13 +137,13 @@ public:
 			return pwd;
 		}
 
-		if ( mWallet && mWallet->readPassword( mPassword.d->configGroup, pwd ) == 0 && !pwd.isNull() )
+		if ( mWallet && mWallet->readPassword( mPassword.d->configGroup, pwd ) == 0 && !pwd.isEmpty() )
 			return pwd;
 
-		if ( mPassword.d->remembered && !mPassword.d->passwordFromKConfig.isNull() )
+		if ( mPassword.d->remembered && !mPassword.d->passwordFromKConfig.isEmpty() )
 			return mPassword.d->passwordFromKConfig;
 
-		return QString::null;
+		return QString();
 	}
 
 	void finished( const QString &result )
@@ -176,54 +173,37 @@ public:
 
 	void doPasswordDialog()
 	{
-		kdDebug( 14010 ) << k_funcinfo << endl;
+		kDebug( 14010 ) ;
 
-		KDialogBase *passwdDialog = new KDialogBase( Kopete::UI::Global::mainWidget(), "passwdDialog", true, i18n( "Password Required" ),
-			KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, true );
+		KPasswordDialog *passwdDialog = new KPasswordDialog( Kopete::UI::Global::mainWidget(), KPasswordDialog::ShowKeepPassword );
+		passwdDialog->setWindowTitle( i18n( "Password Required" ) );
+		passwdDialog->setPrompt( mPrompt );
+		passwdDialog->setPixmap( mImage );
 
-		mView = new KopetePasswordDialog( passwdDialog );
-		passwdDialog->setMainWidget( mView );
-
-		mView->m_text->setText( mPrompt );
-		mView->m_image->setPixmap( mImage );
-		/* Do not put the default password, or it will confuse those which doesn't echo anything for the password
-		mView->m_password->insert( password );
-		*/
-		int maxLength = mPassword.maximumLength();
-		if ( maxLength != 0 )
-			mView->m_password->setMaxLength( maxLength );
-		mView->m_password->setFocus();
-
-		// FIXME: either document what these are for or remove them - lilac
-		mView->adjustSize();
-		passwdDialog->adjustSize();
-
-		connect( passwdDialog, SIGNAL( okClicked() ), SLOT( slotOkPressed() ) );
-		connect( passwdDialog, SIGNAL( cancelClicked() ), SLOT( slotCancelPressed() ) );
+		connect( passwdDialog, SIGNAL( gotPassword(const QString&, bool) ), SLOT( gotPassword( const QString&, bool) )) ;
+		connect( passwdDialog, SIGNAL( rejected() ), SLOT( slotCancelPressed() ) );
 		connect( this, SIGNAL( destroyed() ), passwdDialog, SLOT( deleteLater() ) );
 		passwdDialog->show();
 	}
 
-	void slotOkPressed()
+	void gotPassword(const QString& pass, bool keep)
 	{
-		QString result = QString::fromLocal8Bit( mView->m_password->password() );
-		if ( mView->m_save_passwd->isChecked() )
-			mPassword.set( result );
+		if ( keep )
+			mPassword.set( pass );
 
-		finished( result );
+		finished( pass );
 	}
 
 	void slotCancelPressed()
 	{
-		finished( QString::null );
+		finished( QString::null );	//krazy:exclude=nullstrassign for old broken gcc
 	}
 
 private:
 	QPixmap mImage;
 	QString mPrompt;
 	Kopete::Password::PasswordSource mSource;
-	unsigned int mMaxLength;
-	KopetePasswordDialog *mView;
+	QWidget *mView;
 };
 
 class KopetePasswordGetRequestNoPrompt : public KopetePasswordGetRequest
@@ -251,14 +231,12 @@ public:
 	KopetePasswordSetRequest( Kopete::Password &pass, const QString &newPass )
 	 : KopetePasswordRequest( 0, pass ), mNewPass( newPass )
 	{
-		if ( KApplication *app = KApplication::kApplication() )
-			app->ref();
+		KGlobal::ref();
 	}
 	~KopetePasswordSetRequest()
 	{
-		if ( KApplication *app = KApplication::kApplication() )
-			app->deref();
-		kdDebug( 14010 ) << k_funcinfo << "job complete" << endl;
+		KGlobal::deref();
+		kDebug( 14010 ) << "job complete";
 	}
 	void processRequest()
 	{
@@ -271,12 +249,12 @@ public:
 	}
 	bool setPassword()
 	{
-		kdDebug( 14010 ) << k_funcinfo << " setting password for " << mPassword.d->configGroup << endl;
+		kDebug( 14010 ) << " setting password for " << mPassword.d->configGroup;
 
 		if ( mWallet && mWallet->writePassword( mPassword.d->configGroup, mNewPass ) == 0 )
 		{
 			mPassword.d->remembered = true;
-			mPassword.d->passwordFromKConfig = QString::null;
+			mPassword.d->passwordFromKConfig = QString();
 			mPassword.writeConfig();
 			return true;
 		}
@@ -290,10 +268,10 @@ public:
 			// call after this point is in Kopete::Password, so as long as we've not been deleted
 			// everything should work out OK. We have no parent QObject, so we should survive.
 			if ( KMessageBox::warningContinueCancel( Kopete::UI::Global::mainWidget(),
-			        i18n( "<qt>Kopete is unable to save your password securely in your wallet;<br>"
+			        i18n( "<qt>Kopete is unable to save your password securely in your wallet;<br />"
 			              "do you want to save the password in the <b>unsafe</b> configuration file instead?</qt>" ),
 			        i18n( "Unable to Store Secure Password" ),
-			        KGuiItem( i18n( "Store &Unsafe" ), QString::fromLatin1( "unlock" ) ),
+			        KGuiItem( i18n( "Store &Unsafe" ), QString::fromLatin1( "unlock" ) ), KStandardGuiItem::cancel(),
 			        QString::fromLatin1( "KWalletFallbackToKConfig" ) ) != KMessageBox::Continue )
 			{
 				return false;
@@ -315,31 +293,29 @@ public:
 	KopetePasswordClearRequest( Kopete::Password &pass )
 	 : KopetePasswordRequest( 0, pass )
 	{
-		if ( KApplication *app = KApplication::kApplication() )
-			app->ref();
+		KGlobal::ref();
 	}
 	~KopetePasswordClearRequest()
 	{
-		if ( KApplication *app = KApplication::kApplication() )
-			app->deref();
-		kdDebug( 14010 ) << k_funcinfo << "job complete" << endl;
+		KGlobal::deref();
+		kDebug( 14010 ) << "job complete";
 	}
 	void processRequest()
 	{
 		if ( clearPassword() )
 		{
 			mPassword.setWrong( true );
-			mPassword.d->cachedValue = QString::null;
+			mPassword.d->cachedValue = QString();
 		}
 
 		delete this;
 	}
 	bool clearPassword()
 	{
-		kdDebug( 14010 ) << k_funcinfo << " clearing password" << endl;
+		kDebug( 14010 ) << " clearing password";
 
 		mPassword.d->remembered = false;
-		mPassword.d->passwordFromKConfig = QString::null;
+		mPassword.d->passwordFromKConfig = QString();
 		mPassword.writeConfig();
 		if ( mWallet )
 			mWallet->removeEntry( mPassword.d->configGroup );
@@ -347,21 +323,15 @@ public:
 	}
 };
 
-Kopete::Password::Password( const QString &configGroup, uint maximumLength, const char *name )
- : QObject( 0, name ), d( new Private( configGroup, maximumLength, false ) )
+
+Kopete::Password::Password( const QString &configGroup, bool allowBlankPassword )
+ : QObject( 0 ), d( new Private( configGroup, allowBlankPassword ) )
 {
 	readConfig();
 }
 
-Kopete::Password::Password( const QString &configGroup, uint maximumLength,
-	bool allowBlankPassword, const char *name )
- : QObject( 0, name ), d( new Private( configGroup, maximumLength, allowBlankPassword ) )
-{
-	readConfig();
-}
-
-Kopete::Password::Password( Password &other, const char *name )
- : QObject( 0, name ), d( other.d->incRef() )
+Kopete::Password::Password( const Password &other )
+ : QObject( 0 ), d( other.d->incRef() )
 {
 }
 
@@ -380,22 +350,21 @@ Kopete::Password &Kopete::Password::operator=( Password &other )
 
 void Kopete::Password::readConfig()
 {
-	KConfig *config = KGlobal::config();
-	config->setGroup( d->configGroup );
+	KConfigGroup config(KGlobal::config(), d->configGroup );
 
-	QString passwordCrypted = config->readEntry( "Password" );
+	QString passwordCrypted = config.readEntry( "Password", QString() );
 	if ( passwordCrypted.isNull() )
-		d->passwordFromKConfig = QString::null;
+		d->passwordFromKConfig = QString();
 	else
 		d->passwordFromKConfig = KStringHandler::obscure( passwordCrypted );
 
-	d->remembered = config->readBoolEntry( "RememberPassword", false );
-	d->isWrong = config->readBoolEntry( "PasswordIsWrong", false );
+	d->remembered = config.readEntry( "RememberPassword", false );
+	d->isWrong = config.readEntry( "PasswordIsWrong", false );
 }
 
 void Kopete::Password::writeConfig()
 {
-	KConfig *config = KGlobal::config();
+	KSharedConfig::Ptr config = KGlobal::config();
 	if(!config->hasGroup(d->configGroup))
 	{
 		//### (KOPETE)
@@ -407,20 +376,20 @@ void Kopete::Password::writeConfig()
 		return;
 	}
 		  
-	config->setGroup( d->configGroup );
+	KConfigGroup group = config->group( d->configGroup );
 
 	if ( d->remembered && !d->passwordFromKConfig.isNull() )
-		config->writeEntry( "Password", KStringHandler::obscure( d->passwordFromKConfig ) );
+		group.writeEntry( "Password", KStringHandler::obscure( d->passwordFromKConfig ) );
 	else
-		config->deleteEntry( "Password" );
+		group.deleteEntry( "Password" );
 
-	config->writeEntry( "RememberPassword", d->remembered );
-	config->writeEntry( "PasswordIsWrong", d->isWrong );
+	group.writeEntry( "RememberPassword", d->remembered );
+	group.writeEntry( "PasswordIsWrong", d->isWrong );
 }
 
 int Kopete::Password::preferredImageSize()
 {
-	return IconSize(KIcon::Toolbar);
+	return IconSize(KIconLoader::Toolbar);
 }
 
 bool Kopete::Password::allowBlankPassword()
@@ -428,16 +397,6 @@ bool Kopete::Password::allowBlankPassword()
 	return d->allowBlankPassword;
 }
 
-uint Kopete::Password::maximumLength()
-{
-	return d->maximumLength;
-}
-
-void Kopete::Password::setMaximumLength( uint max )
-{
-	d->maximumLength = max;
-}
-
 bool Kopete::Password::isWrong()
 {
 	return d->isWrong;
@@ -448,7 +407,7 @@ void Kopete::Password::setWrong( bool bWrong )
 	d->isWrong = bWrong;
 	writeConfig();
 
-	if ( bWrong ) d->cachedValue = QString::null;
+	if ( bWrong ) d->cachedValue = QString();
 }
 
 void Kopete::Password::requestWithoutPrompt( QObject *returnObj, const char *slot )
