@@ -17,7 +17,7 @@
     *************************************************************************
 */
 
-#include "config.h"
+#include "config-kopete.h"
 
 #include "kopetepluginmanager.h"
 
@@ -27,20 +27,20 @@
 #include <valgrind/valgrind.h>
 #endif
 
-#include <qapplication.h>
-#include <qfile.h>
-#include <qregexp.h>
-#include <qtimer.h>
-#include <qvaluestack.h>
+#include <QApplication>
+#include <QFile>
+#include <QRegExp>
+#include <QTimer>
+#include <QStack>
 
-#include <kapplication.h>
+#include <ksharedconfig.h>
 #include <kdebug.h>
 #include <kparts/componentfactory.h>
 #include <kplugininfo.h>
-#include <ksimpleconfig.h>
+#include <kconfig.h>
 #include <kstandarddirs.h>
-#include <kstaticdeleter.h>
 #include <kurl.h>
+#include <kservicetypetrader.h>
 
 #include "kopeteplugin.h"
 #include "kopetecontactlist.h"
@@ -49,18 +49,36 @@
 namespace Kopete
 {
 
-
-class PluginManager::Private
+class PluginManagerPrivate
 {
 public:
-	Private() : shutdownMode( StartingUp ), isAllPluginsLoaded(false) {}
+	PluginManagerPrivate() : shutdownMode( StartingUp ), isAllPluginsLoaded(false)
+	{
+		plugins = KPluginInfo::fromServices( KServiceTypeTrader::self()->query( QLatin1String( "Kopete/Plugin" ), QLatin1String( "[X-Kopete-Version] == 1000900" ) ) );
+	}
+
+	~PluginManagerPrivate()
+	{
+		if ( shutdownMode != DoneShutdown )
+			kWarning( 14010 ) << "Destructing plugin manager without going through the shutdown process! Backtrace is: " << endl << kBacktrace();
+
+		// Quick cleanup of the remaining plugins, hope it helps
+		// Note that deleting it.value() causes slotPluginDestroyed to be called, which
+		// removes the plugin from the list of loaded plugins.
+		while ( !loadedPlugins.empty() )
+		{
+			InfoToPluginMap::ConstIterator it = loadedPlugins.begin();
+			kWarning( 14010 ) << "Deleting stale plugin '" << it.value()->objectName() << "'";
+			delete it.value();
+		}
+	}
 
 	// All available plugins, regardless of category, and loaded or not
-	QValueList<KPluginInfo *> plugins;
+	QList<KPluginInfo> plugins;
 
 	// Dict of all currently loaded plugins, mapping the KPluginInfo to
 	// a plugin
-	typedef QMap<KPluginInfo *, Plugin *> InfoToPluginMap;
+	typedef QMap<KPluginInfo, Plugin *> InfoToPluginMap;
 	InfoToPluginMap loadedPlugins;
 
 	// The plugin manager's mode. The mode is StartingUp until loadAllPlugins()
@@ -71,64 +89,42 @@ public:
 	ShutdownMode shutdownMode;
 
 	// Plugins pending for loading
-	QValueStack<QString> pluginsToLoad;
-
-	static KStaticDeleter<PluginManager> deleter;
+	QStack<QString> pluginsToLoad;
 
 	bool isAllPluginsLoaded;
+	PluginManager instance;
 };
 
-KStaticDeleter<PluginManager> PluginManager::Private::deleter;
-PluginManager* PluginManager::s_self = 0L;
+K_GLOBAL_STATIC(PluginManagerPrivate, _kpmp)
 
 PluginManager* PluginManager::self()
 {
-	if ( !s_self )
-		Private::deleter.setObject( s_self, new PluginManager() );
-
-	return s_self;
+	return &_kpmp->instance;
 }
 
-PluginManager::PluginManager() : QObject( qApp ), d( new Private )
+PluginManager::PluginManager() : QObject( 0 )
 {
-	d->plugins = KPluginInfo::fromServices( KTrader::self()->query( QString::fromLatin1( "Kopete/Plugin" ),
-		QString::fromLatin1( "[X-Kopete-Version] == 1000900" ) ) );
-
 	// We want to add a reference to the application's event loop so we
 	// can remain in control when all windows are removed.
 	// This way we can unload plugins asynchronously, which is more
 	// robust if they are still doing processing.
-	kapp->ref();
+	KGlobal::ref();
 }
 
 PluginManager::~PluginManager()
 {
-	if ( d->shutdownMode != Private::DoneShutdown )
-		kdWarning( 14010 ) << k_funcinfo << "Destructing plugin manager without going through the shutdown process! Backtrace is: " << endl << kdBacktrace() << endl;
-
-	// Quick cleanup of the remaining plugins, hope it helps
-	// Note that deleting it.data() causes slotPluginDestroyed to be called, which
-	// removes the plugin from the list of loaded plugins.
-	while ( !d->loadedPlugins.empty() )
-	{
-		Private::InfoToPluginMap::ConstIterator it = d->loadedPlugins.begin();
-		kdWarning( 14010 ) << k_funcinfo << "Deleting stale plugin '" << it.data()->name() << "'" << endl;
-		delete it.data();
-	}
-
-	delete d;
 }
 
-QValueList<KPluginInfo *> PluginManager::availablePlugins( const QString &category ) const
+QList<KPluginInfo> PluginManager::availablePlugins( const QString &category ) const
 {
 	if ( category.isEmpty() )
-		return d->plugins;
+		return _kpmp->plugins;
 
-	QValueList<KPluginInfo *> result;
-	QValueList<KPluginInfo *>::ConstIterator it;
-	for ( it = d->plugins.begin(); it != d->plugins.end(); ++it )
+	QList<KPluginInfo> result;
+	QList<KPluginInfo>::ConstIterator it;
+	for ( it = _kpmp->plugins.begin(); it != _kpmp->plugins.end(); ++it )
 	{
-		if ( ( *it )->category() == category )
+		if ( it->category() == category )
 			result.append( *it );
 	}
 
@@ -138,39 +134,39 @@ QValueList<KPluginInfo *> PluginManager::availablePlugins( const QString &catego
 PluginList PluginManager::loadedPlugins( const QString &category ) const
 {
 	PluginList result;
-	
-	for ( Private::InfoToPluginMap::ConstIterator it = d->loadedPlugins.begin();
-	      it != d->loadedPlugins.end(); ++it )
+
+	for ( PluginManagerPrivate::InfoToPluginMap::ConstIterator it = _kpmp->loadedPlugins.begin();
+	      it != _kpmp->loadedPlugins.end(); ++it )
 	{
-		if ( category.isEmpty() || it.key()->category() == category )
-			result.append( it.data() );
+		if ( category.isEmpty() || it.key().category() == category )
+			result.append( it.value() );
 	}
-	
+
 	return result;
 }
 
 
-KPluginInfo *PluginManager::pluginInfo( const Plugin *plugin ) const
+KPluginInfo PluginManager::pluginInfo( const Plugin *plugin ) const
 {
-	for ( Private::InfoToPluginMap::ConstIterator it = d->loadedPlugins.begin();
-	      it != d->loadedPlugins.end(); ++it )
+	for ( PluginManagerPrivate::InfoToPluginMap::ConstIterator it = _kpmp->loadedPlugins.begin();
+	      it != _kpmp->loadedPlugins.end(); ++it )
 	{
-		if ( it.data() == plugin )
+		if ( it.value() == plugin )
 			return it.key();
 	}
-	return 0;
+	return KPluginInfo();
 }
 
 void PluginManager::shutdown()
 {
-	if(d->shutdownMode != Private::Running)
+	if(_kpmp->shutdownMode != PluginManagerPrivate::Running)
 	{
-		kdDebug( 14010 ) << k_funcinfo << "called when not running.  / state = " << d->shutdownMode << endl;
+		kDebug( 14010 ) << "called when not running.  / state = " << _kpmp->shutdownMode;
 		return;
 	}
 
-	d->shutdownMode = Private::ShuttingDown;
-	
+	_kpmp->shutdownMode = PluginManagerPrivate::ShuttingDown;
+
 
 	/* save the contact list now, just in case a change was made very recently
 	   and it hasn't autosaved yet
@@ -179,30 +175,30 @@ void PluginManager::shutdown()
 	*/
 	Kopete::ContactList::self()->save();
 	Kopete::AccountManager::self()->save();
-	
+
 	// Remove any pending plugins to load, we're shutting down now :)
-	d->pluginsToLoad.clear();
-	
+	_kpmp->pluginsToLoad.clear();
+
 	// Ask all plugins to unload
-	for ( Private::InfoToPluginMap::ConstIterator it = d->loadedPlugins.begin();
-	      it != d->loadedPlugins.end(); /* EMPTY */ )
+	for ( PluginManagerPrivate::InfoToPluginMap::ConstIterator it = _kpmp->loadedPlugins.begin();
+	      it != _kpmp->loadedPlugins.end(); /* EMPTY */ )
 	{
 		// Plugins could emit their ready for unload signal directly in response to this,
 		// which would invalidate the current iterator. Therefore, we copy the iterator
 		// and increment it beforehand.
-		Private::InfoToPluginMap::ConstIterator current( it );
+		PluginManagerPrivate::InfoToPluginMap::ConstIterator current( it );
 		++it;
 		// FIXME: a much cleaner approach would be to just delete the plugin now. if it needs
 		//  to do some async processing, it can grab a reference to the app itself and create
 		//  another object to do it.
-		current.data()->aboutToUnload();
+		current.value()->aboutToUnload();
 	}
-	
+
 	// When running under valgrind, don't enable the timer because it will almost
 	// certainly fire due to valgrind's much slower processing
 #if defined(HAVE_VALGRIND_H) && !defined(NDEBUG) && defined(__i386__)
 	if ( RUNNING_ON_VALGRIND )
-		kdDebug(14010) << k_funcinfo << "Running under valgrind, disabling plugin unload timeout guard" << endl;
+		kDebug(14010) << "Running under valgrind, disabling plugin unload timeout guard";
 	else
 #endif
 		QTimer::singleShot( 3000, this, SLOT( slotShutdownTimeout() ) );
@@ -216,13 +212,13 @@ void PluginManager::slotPluginReadyForUnload()
 	// FIXME: I don't buy the above argument. Add a Kopete::Plugin::emitReadyForUnload(void),
 	//        and make readyForUnload be passed a plugin. - Richard
 	Plugin *plugin = dynamic_cast<Plugin *>( const_cast<QObject *>( sender() ) );
-	kdDebug( 14010 ) << k_funcinfo << plugin->pluginId() << "ready for unload" << endl;
 	if ( !plugin )
 	{
-		kdWarning( 14010 ) << k_funcinfo << "Calling object is not a plugin!" << endl;
+		kWarning( 14010 ) << "Calling object is not a plugin!";
 		return;
 	}
-	
+	kDebug( 14010 ) << plugin->pluginId() << "ready for unload";
+
 	plugin->deleteLater();
 }
 
@@ -231,15 +227,15 @@ void PluginManager::slotShutdownTimeout()
 {
 	// When we were already done the timer might still fire.
 	// Do nothing in that case.
-	if ( d->shutdownMode == Private::DoneShutdown )
+	if ( _kpmp->shutdownMode == PluginManagerPrivate::DoneShutdown )
 		return;
 
 	QStringList remaining;
-	for ( Private::InfoToPluginMap::ConstIterator it = d->loadedPlugins.begin(); it != d->loadedPlugins.end(); ++it )
-		remaining.append( it.data()->pluginId() );
+	for ( PluginManagerPrivate::InfoToPluginMap::ConstIterator it = _kpmp->loadedPlugins.begin(); it != _kpmp->loadedPlugins.end(); ++it )
+		remaining.append( it.value()->pluginId() );
 
-	kdWarning( 14010 ) << k_funcinfo << "Some plugins didn't shutdown in time!" << endl
-		<< "Remaining plugins: " << remaining.join( QString::fromLatin1( ", " ) ) << endl
+	kWarning( 14010 ) << "Some plugins didn't shutdown in time!" << endl
+		<< "Remaining plugins: " << remaining.join( QLatin1String( ", " ) ) << endl
 		<< "Forcing Kopete shutdown now." << endl;
 
 	slotShutdownDone();
@@ -247,46 +243,45 @@ void PluginManager::slotShutdownTimeout()
 
 void PluginManager::slotShutdownDone()
 {
-	kdDebug( 14010 ) << k_funcinfo << endl;
+	kDebug( 14010 ) ;
 
-	d->shutdownMode = Private::DoneShutdown;
+	_kpmp->shutdownMode = PluginManagerPrivate::DoneShutdown;
 
-	kapp->deref();
+	KGlobal::deref();
 }
 
 void PluginManager::loadAllPlugins()
 {
 	// FIXME: We need session management here - Martijn
 
-	KConfig *config = KGlobal::config();
-	if ( config->hasGroup( QString::fromLatin1( "Plugins" ) ) )
+	KSharedConfig::Ptr config = KGlobal::config();
+	if ( config->hasGroup( QLatin1String( "Plugins" ) ) )
 	{
 		QMap<QString, bool> pluginsMap;
 
-		QMap<QString, QString> entries = config->entryMap( QString::fromLatin1( "Plugins" ) );
+		QMap<QString, QString> entries = config->entryMap( QLatin1String( "Plugins" ) );
 		QMap<QString, QString>::Iterator it;
 		for ( it = entries.begin(); it != entries.end(); ++it )
 		{
 			QString key = it.key();
-			if ( key.endsWith( QString::fromLatin1( "Enabled" ) ) )
-				pluginsMap.insert( key.left( key.length() - 7 ), (it.data() == QString::fromLatin1( "true" )) );
+			if ( key.endsWith( QLatin1String( "Enabled" ) ) )
+				pluginsMap.insert( key.left(key.length() - 7), (it.value() == QLatin1String( "true" )) );
 		}
 
-		QValueList<KPluginInfo *> plugins = availablePlugins( QString::null );
-		QValueList<KPluginInfo *>::ConstIterator it2 = plugins.begin();
-		QValueList<KPluginInfo *>::ConstIterator end = plugins.end();
+		QList<KPluginInfo> plugins = availablePlugins( QString::null );	//krazy:exclude=nullstrassign for old broken gcc
+		QList<KPluginInfo>::ConstIterator it2 = plugins.begin();
+		QList<KPluginInfo>::ConstIterator end = plugins.end();
 		for ( ; it2 != end; ++it2 )
 		{
 			// Protocols are loaded automatically so they aren't always in Plugins group. (fixes bug 167113)
-			if ( (*it2)->category() == QString::fromLatin1( "Protocols" ) )
+			if ( it2->category() == QLatin1String( "Protocols" ) )
 				continue;
 
-			QString pluginName = (*it2)->pluginName();
-			bool inMap = pluginsMap.contains( pluginName );
-			if ( (inMap && pluginsMap[pluginName]) || (!inMap && (*it2)->isPluginEnabledByDefault()) )
+			QString pluginName = it2->pluginName();
+			if ( pluginsMap.value( pluginName, it2->isPluginEnabledByDefault() ) )
 			{
 				if ( !plugin( pluginName ) )
-					d->pluginsToLoad.push( pluginName );
+					_kpmp->pluginsToLoad.push( pluginName );
 			}
 			else
 			{
@@ -301,13 +296,13 @@ void PluginManager::loadAllPlugins()
 	else
 	{
 		// we had no config, so we load any plugins that should be loaded by default.
-		QValueList<KPluginInfo *> plugins = availablePlugins( QString::null );
-		QValueList<KPluginInfo *>::ConstIterator it = plugins.begin();
-		QValueList<KPluginInfo *>::ConstIterator end = plugins.end();
+		QList<KPluginInfo> plugins = availablePlugins( QString::null );	//krazy:exclude=nullstrassign for old broken gcc
+		QList<KPluginInfo>::ConstIterator it = plugins.begin();
+		QList<KPluginInfo>::ConstIterator end = plugins.end();
 		for ( ; it != end; ++it )
 		{
-			if ( (*it)->isPluginEnabledByDefault() )
-				d->pluginsToLoad.push( (*it)->pluginName() );
+			if ( it->isPluginEnabledByDefault() )
+				_kpmp->pluginsToLoad.push( it->pluginName() );
 		}
 	}
 	// Schedule the plugins to load
@@ -316,18 +311,18 @@ void PluginManager::loadAllPlugins()
 
 void PluginManager::slotLoadNextPlugin()
 {
-	if ( d->pluginsToLoad.isEmpty() )
+	if ( _kpmp->pluginsToLoad.isEmpty() )
 	{
-		if ( d->shutdownMode == Private::StartingUp )
+		if ( _kpmp->shutdownMode == PluginManagerPrivate::StartingUp )
 		{
-			d->shutdownMode = Private::Running;
-			d->isAllPluginsLoaded = true;
+			_kpmp->shutdownMode = PluginManagerPrivate::Running;
+			_kpmp->isAllPluginsLoaded = true;
 			emit allPluginsLoaded();
 		}
 		return;
 	}
 
-	QString key = d->pluginsToLoad.pop();
+	QString key = _kpmp->pluginsToLoad.pop();
 	loadPluginInternal( key );
 
 	// Schedule the next run unconditionally to avoid code duplication on the
@@ -343,10 +338,10 @@ Plugin * PluginManager::loadPlugin( const QString &_pluginId, PluginLoadMode mod
 
 	// Try to find legacy code
 	// FIXME: Find any cases causing this, remove them, and remove this too - Richard
-	if ( pluginId.endsWith( QString::fromLatin1( ".desktop" ) ) )
+	if ( pluginId.endsWith( QLatin1String( ".desktop" ) ) )
 	{
-		kdWarning( 14010 ) << "Trying to use old-style API!" << endl << kdBacktrace() << endl;
-		pluginId = pluginId.remove( QRegExp( QString::fromLatin1( ".desktop$" ) ) );
+		kWarning( 14010 ) << "Trying to use old-style API!" << endl << kBacktrace();
+		pluginId = pluginId.remove( QRegExp( QLatin1String( ".desktop$" ) ) );
 	}
 
 	if ( mode == LoadSync )
@@ -355,7 +350,7 @@ Plugin * PluginManager::loadPlugin( const QString &_pluginId, PluginLoadMode mod
 	}
 	else
 	{
-		d->pluginsToLoad.push( pluginId );
+		_kpmp->pluginsToLoad.push( pluginId );
 		QTimer::singleShot( 0, this, SLOT( slotLoadNextPlugin() ) );
 		return 0L;
 	}
@@ -363,62 +358,36 @@ Plugin * PluginManager::loadPlugin( const QString &_pluginId, PluginLoadMode mod
 
 Plugin *PluginManager::loadPluginInternal( const QString &pluginId )
 {
-	//kdDebug( 14010 ) << k_funcinfo << pluginId << endl;
+	//kDebug( 14010 ) << pluginId;
 
-	KPluginInfo *info = infoForPluginId( pluginId );
-	if ( !info )
+	KPluginInfo info = infoForPluginId( pluginId );
+	if ( !info.isValid() )
 	{
-		kdWarning( 14010 ) << k_funcinfo << "Unable to find a plugin named '" << pluginId << "'!" << endl;
+		kWarning( 14010 ) << "Unable to find a plugin named '" << pluginId << "'!";
 		return 0L;
 	}
 
-	if ( d->loadedPlugins.contains( info ) )
-		return d->loadedPlugins[ info ];
+	if ( _kpmp->loadedPlugins.contains( info ) )
+		return _kpmp->loadedPlugins[ info ];
 
-	int error = 0;
-	Plugin *plugin = KParts::ComponentFactory::createInstanceFromQuery<Plugin>( QString::fromLatin1( "Kopete/Plugin" ),
-		QString::fromLatin1( "[X-KDE-PluginInfo-Name]=='%1'" ).arg( pluginId ), this, 0, QStringList(), &error );
+	QString error;
+        Plugin *plugin = KServiceTypeTrader::createInstanceFromQuery<Plugin>( QString::fromLatin1( "Kopete/Plugin" ), QString::fromLatin1( "[X-KDE-PluginInfo-Name]=='%1'" ).arg( pluginId ), this, QVariantList(), &error );
 
 	if ( plugin )
 	{
-		d->loadedPlugins.insert( info, plugin );
-		info->setPluginEnabled( true );
+		_kpmp->loadedPlugins.insert( info, plugin );
+		info.setPluginEnabled( true );
 
 		connect( plugin, SIGNAL( destroyed( QObject * ) ), this, SLOT( slotPluginDestroyed( QObject * ) ) );
 		connect( plugin, SIGNAL( readyForUnload() ), this, SLOT( slotPluginReadyForUnload() ) );
 
-		kdDebug( 14010 ) << k_funcinfo << "Successfully loaded plugin '" << pluginId << "'" << endl;
+		kDebug( 14010 ) << "Successfully loaded plugin '" << pluginId << "'";
 
 		emit pluginLoaded( plugin );
 	}
 	else
 	{
-		switch( error )
-		{
-		case KParts::ComponentFactory::ErrNoServiceFound:
-			kdDebug( 14010 ) << k_funcinfo << "No service implementing the given mimetype "
-				<< "and fullfilling the given constraint expression can be found." << endl;
-			break;
-
-		case KParts::ComponentFactory::ErrServiceProvidesNoLibrary:
-			kdDebug( 14010 ) << "the specified service provides no shared library." << endl;
-			break;
-
-		case KParts::ComponentFactory::ErrNoLibrary:
-			kdDebug( 14010 ) << "the specified library could not be loaded." << endl;
-			break;
-
-		case KParts::ComponentFactory::ErrNoFactory:
-			kdDebug( 14010 ) << "the library does not export a factory for creating components." << endl;
-			break;
-
-		case KParts::ComponentFactory::ErrNoComponent:
-			kdDebug( 14010 ) << "the factory does not support creating components of the specified type." << endl;
-			break;
-		}
-
-		kdDebug( 14010 ) << k_funcinfo << "Loading plugin '" << pluginId << "' failed, KLibLoader reported error: '" << endl <<
-			KLibLoader::self()->lastErrorMessage() << "'" << endl;
+		kDebug( 14010 ) << "Loading plugin " << pluginId << " failed, KServiceTypeTrader reported error: " << error ;
 	}
 
 	return plugin;
@@ -426,7 +395,7 @@ Plugin *PluginManager::loadPluginInternal( const QString &pluginId )
 
 bool PluginManager::unloadPlugin( const QString &spec )
 {
-	//kdDebug(14010) << k_funcinfo << spec << endl;
+	//kDebug(14010) << spec;
 	if( Plugin *thePlugin = plugin( spec ) )
 	{
 		thePlugin->aboutToUnload();
@@ -440,17 +409,17 @@ bool PluginManager::unloadPlugin( const QString &spec )
 
 void PluginManager::slotPluginDestroyed( QObject *plugin )
 {
-	for ( Private::InfoToPluginMap::Iterator it = d->loadedPlugins.begin();
-	      it != d->loadedPlugins.end(); ++it )
+	for ( PluginManagerPrivate::InfoToPluginMap::Iterator it = _kpmp->loadedPlugins.begin();
+	      it != _kpmp->loadedPlugins.end(); ++it )
 	{
-		if ( it.data() == plugin )
+		if ( it.value() == plugin )
 		{
-			d->loadedPlugins.erase( it );
+			_kpmp->loadedPlugins.erase( it );
 			break;
 		}
 	}
 
-	if ( d->shutdownMode == Private::ShuttingDown && d->loadedPlugins.isEmpty() )
+	if ( _kpmp->shutdownMode == PluginManagerPrivate::ShuttingDown && _kpmp->loadedPlugins.isEmpty() )
 	{
 		// Use a timer to make sure any pending deleteLater() calls have
 		// been handled first
@@ -471,30 +440,30 @@ Plugin* PluginManager::plugin( const QString &_pluginId ) const
 	// FIXME: In the future we'll need to change this nevertheless to unify
 	//        the handling - Martijn
 	QString pluginId = _pluginId;
-	if ( pluginId.endsWith( QString::fromLatin1( "Protocol" ) ) )
-		pluginId = QString::fromLatin1( "kopete_" ) + _pluginId.lower().remove( QString::fromLatin1( "protocol" ) );
+	if ( pluginId.endsWith( QLatin1String( "Protocol" ) ) )
+		pluginId = QLatin1String( "kopete_" ) + _pluginId.toLower().remove( QString::fromLatin1( "protocol" ) );
 	// End hack
 
-	KPluginInfo *info = infoForPluginId( pluginId );
-	if ( !info )
+	KPluginInfo info = infoForPluginId( pluginId );
+	if ( !info.isValid() )
 		return 0L;
 
-	if ( d->loadedPlugins.contains( info ) )
-		return d->loadedPlugins[ info ];
+	if ( _kpmp->loadedPlugins.contains( info ) )
+		return _kpmp->loadedPlugins[ info ];
 	else
 		return 0L;
 }
 
-KPluginInfo * PluginManager::infoForPluginId( const QString &pluginId ) const
+KPluginInfo PluginManager::infoForPluginId( const QString &pluginId ) const
 {
-	QValueList<KPluginInfo *>::ConstIterator it;
-	for ( it = d->plugins.begin(); it != d->plugins.end(); ++it )
+	QList<KPluginInfo>::ConstIterator it;
+	for ( it = _kpmp->plugins.begin(); it != _kpmp->plugins.end(); ++it )
 	{
-		if ( ( *it )->pluginName() == pluginId )
+		if ( it->pluginName() == pluginId )
 			return *it;
 	}
 
-	return 0L;
+	return KPluginInfo();
 }
 
 
@@ -502,25 +471,24 @@ bool PluginManager::setPluginEnabled( const QString &_pluginId, bool enabled /*
 {
 	QString pluginId = _pluginId;
 
-	KConfig *config = KGlobal::config();
-	config->setGroup( "Plugins" );
+	KConfigGroup config(KGlobal::config(), "Plugins");
 
 	// FIXME: What is this for? This sort of thing is kconf_update's job - Richard
-	if ( !pluginId.startsWith( QString::fromLatin1( "kopete_" ) ) )
-		pluginId.prepend( QString::fromLatin1( "kopete_" ) );
+	if ( !pluginId.startsWith( QLatin1String( "kopete_" ) ) )
+		pluginId.prepend( QLatin1String( "kopete_" ) );
 
-	if ( !infoForPluginId( pluginId ) )
+	if ( !infoForPluginId( pluginId ).isValid() )
 		return false;
 
-	config->writeEntry( pluginId + QString::fromLatin1( "Enabled" ), enabled );
-	config->sync();
+	config.writeEntry( pluginId + QLatin1String( "Enabled" ), enabled );
+	config.sync();
 
 	return true;
 }
 
 bool PluginManager::isAllPluginsLoaded() const
 {
-	return d->isAllPluginsLoaded;
+	return _kpmp->isAllPluginsLoaded;
 }
 
 } //END namespace Kopete
