@@ -19,13 +19,13 @@
 #ifndef KOPETE_LISTVIEWITEM_H
 #define KOPETE_LISTVIEWITEM_H
 
-#include <klistview.h>
+#include <k3listview.h>
 #include <kopetecontact.h>
+#include <kopete_export.h>
 
 #include <utility>
-#include <qimage.h>
 
-class QPixmap;
+#include <QtGui/QPixmap>
 
 namespace Kopete {
 namespace UI {
@@ -33,7 +33,7 @@ namespace ListView {
 
 class Component;
 
-class ComponentBase
+class KOPETE_EXPORT ComponentBase
 {
 public:
 	ComponentBase();
@@ -80,9 +80,10 @@ private:
 /**
  * @author Richard Smith <kde@metafoo.co.uk>
  */
-class ToolTipSource
+class KOPETE_EXPORT ToolTipSource
 {
 public:
+	virtual ~ToolTipSource(){}
 	/**
 	 * Get the tooltip string and rect for a component
 	 *
@@ -99,7 +100,7 @@ public:
  *
  * @author Richard Smith <kde@metafoo.co.uk>
  */
-class Component : public ComponentBase
+class KOPETE_EXPORT Component : public ComponentBase
 {
 protected:
 	Component( ComponentBase *parent );
@@ -118,7 +119,7 @@ public:
 	 * Paint this item, inside the rectangle returned by rect().
 	 * The default implementation calls paint on all children.
 	 */
-	virtual void paint( QPainter *painter, const QColorGroup &cg );
+	virtual void paint( QPainter *painter, const QPalette &pal );
 
 	void repaint();
 	void relayout();
@@ -229,11 +230,11 @@ private:
 	Private *d;
 };
 
-class BoxComponent : public Component
+class KOPETE_EXPORT BoxComponent : public Component
 {
 public:
 	enum Direction { Horizontal, Vertical };
-	BoxComponent( ComponentBase *parent, Direction dir = Horizontal );
+	explicit BoxComponent( ComponentBase *parent, Direction dir = Horizontal );
 	~BoxComponent();
 
 	void layout( const QRect &rect );
@@ -256,10 +257,10 @@ private:
 	Private *d;
 };
 
-class TextComponent : public Component
+class KOPETE_EXPORT TextComponent : public Component
 {
 public:
-	TextComponent( ComponentBase *parent, const QFont &font = QFont(), const QString &text = QString::null );
+	explicit TextComponent( ComponentBase *parent, const QFont &font = QFont(), const QString &text = QString() );
 	~TextComponent();
 
 	QString text();
@@ -274,7 +275,7 @@ public:
 
 	int widthForHeight( int );
 
-	void paint( QPainter *painter, const QColorGroup &cg );
+	void paint( QPainter *painter, const QPalette &pal );
 
 	static int RTTI;
 	virtual int rtti() const { return RTTI; }
@@ -286,19 +287,19 @@ private:
 	Private *d;
 };
 
-class ImageComponent : public Component
+class KOPETE_EXPORT ImageComponent : public Component
 {
 public:
-	ImageComponent( ComponentBase *parent );
+	explicit ImageComponent( ComponentBase *parent );
 	ImageComponent( ComponentBase *parent, int minW, int minH );
 	~ImageComponent();
 
 	void setPixmap( const QPixmap &img, bool adjustSize = true);
 	QPixmap pixmap( void );
 
-	void paint( QPainter *painter, const QColorGroup &cg );
+	void paint( QPainter *painter, const QPalette &pal );
 
-	void scale( int w, int h, QImage::ScaleMode );
+	void scale( int w, int h, Qt::AspectRatioMode );
 	static int RTTI;
 	virtual int rtti() const { return RTTI; }
 private:
@@ -309,7 +310,7 @@ private:
 /**
  * ContactComponent
  */
-class ContactComponent : public ImageComponent
+class KOPETE_EXPORT ContactComponent : public ImageComponent
 {
 public:
 	ContactComponent( ComponentBase *parent, Kopete::Contact *contact, int iconSize);
@@ -325,7 +326,7 @@ protected:
 /**
  * SpacerComponent
  */
-class SpacerComponent : public Component
+class KOPETE_EXPORT SpacerComponent : public Component
 {
 public:
 	SpacerComponent( ComponentBase *parent, int w, int h );
@@ -335,13 +336,13 @@ public:
  * DisplayNameComponent
  */
 
-class DisplayNameComponent : public BoxComponent
+class KOPETE_EXPORT DisplayNameComponent : public BoxComponent
 {
 public:
 	/**
 	 * Constructor
 	 */
-	DisplayNameComponent( ComponentBase *parent );
+	explicit DisplayNameComponent( ComponentBase *parent );
 
 	/**
 	 * Dtor
@@ -366,20 +367,20 @@ private:
 	Private *d;
 };
 
-class HSpacerComponent : public Component
+class KOPETE_EXPORT HSpacerComponent : public Component
 {
 public:
-	HSpacerComponent( ComponentBase *parent );
+	explicit HSpacerComponent( ComponentBase *parent );
 	int widthForHeight( int );
 
 	static int RTTI;
 	virtual int rtti() const { return RTTI; }
 };
 
-class VSpacerComponent : public Component
+class KOPETE_EXPORT VSpacerComponent : public Component
 {
 public:
-	VSpacerComponent( ComponentBase *parent );
+	explicit VSpacerComponent( ComponentBase *parent );
 	int heightForWidth( int );
 
 	static int RTTI;
@@ -392,12 +393,12 @@ public:
  *
  * @author Richard Smith <kde@metafoo.co.uk>
  */
-class Item : public QObject, public KListViewItem, public ComponentBase
+class KOPETE_EXPORT Item : public QObject, public K3ListViewItem, public ComponentBase
 {
 	Q_OBJECT
 public:
-	Item( QListView *parent, QObject *owner = 0, const char *name = 0 );
-	Item( QListViewItem *parent, QObject *owner = 0, const char *name = 0  );
+	explicit Item( Q3ListView *parent, QObject *owner = 0 );
+	explicit Item( Q3ListViewItem *parent, QObject *owner = 0 );
 	~Item();
 
 	void repaint();
@@ -421,7 +422,7 @@ public:
 	 */
 	static void setEffects( bool animation, bool fading, bool folding );
 
-	int width( const QFontMetrics & fm, const QListView * lv, int c ) const;
+	int width( const QFontMetrics & fm, const Q3ListView * lv, int c ) const;
 
 	/**
 	 * Show or hide this item in a clean way depending on whether it matches
@@ -436,11 +437,15 @@ protected:
 	void componentResized( Component *component );
 
 	void setHeight( int );
+	
+signals:
+	void visibilityChanged (bool visibility);
 
 private:
-	void initLVI();
+	void initLVI(QObject* parent);
 	void recalcHeight();
 	void scheduleLayout();
+	void mySetVisible ( bool b );
 
 private slots:
 	void slotColumnResized();
