@@ -1,14 +1,20 @@
-/***************************************************************************
+/*
+ 
+ Kopete    (c) 2003-2004 by the Kopete developers  <kopete-devel@kde.org>
+
+ ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- ***************************************************************************/
+ ***************************************************************************
+*/
 
+#define QT3_SUPPORT
 #include <kpushbutton.h>
-#include <klistview.h>
+#include <k3listview.h>
 #include <klocale.h>
 #include <klineedit.h>
 #include <kglobal.h>
@@ -17,6 +23,7 @@
 #include <kconfig.h>
 #include <qregexp.h>
 #include <qlayout.h>
+
 #include <kplugininfo.h>
 #include <kiconloader.h>
 #include <qpainter.h>
@@ -26,20 +33,21 @@
 #include "kopeteaccount.h"
 #include "kopeteprotocol.h"
 
-#include "aliasdialogbase.h"
+#include "ui_aliasdialogbase.h"
 #include "editaliasdialog.h"
 #include "aliaspreferences.h"
 
-typedef KGenericFactory<AliasPreferences> AliasPreferencesFactory;
+K_PLUGIN_FACTORY( AliasPreferencesFactory, registerPlugin<AliasPreferences>(); )
+K_EXPORT_PLUGIN( AliasPreferencesFactory( "kcm_kopete_alias" ) )
 
-class AliasItem : public QListViewItem
+class AliasItem : public Q3ListViewItem
 {
 	public:
-		AliasItem( QListView *parent,
+		AliasItem( Q3ListView *parent,
 			uint number,
 			const QString &alias,
 			const QString &command, const ProtocolList &p ) :
-		QListViewItem( parent, alias, command )
+		Q3ListViewItem( parent, alias, command )
 		{
 			protocolList = p;
 			id = number;
@@ -58,26 +66,25 @@ class AliasItem : public QListViewItem
 				if ( cellWidth < 0 )
 					cellWidth = 0;
 
-				QListViewItem::paintCell( p, cg, column, cellWidth, align );
+				Q3ListViewItem::paintCell( p, cg, column, cellWidth, align );
 
 				// Draw the rest of the background
-				QListView *lv = listView();
+				Q3ListView *lv = listView();
 				if ( !lv )
 					return;
 
 				int marg = lv->itemMargin();
 				int r = marg;
-				const BackgroundMode bgmode = lv->viewport()->backgroundMode();
-				const QColorGroup::ColorRole crole =
-					QPalette::backgroundRoleFromMode( bgmode );
+				// QPalette(backgroundRole(())
+				QPalette bgmode = QPalette( lv->viewport()->backgroundRole() );
 				p->fillRect( cellWidth, 0, width - cellWidth, height(),
-					cg.brush( crole ) );
+					cg.brush( bgmode.currentColorGroup(), QPalette::Background ) );
 
 				if ( isSelected() && ( column == 0 || listView()->allColumnsShowFocus() ) )
 				{
-					p->fillRect( QMAX( cellWidth, r - marg ), 0,
+					p->fillRect( qMax( cellWidth, r - marg ), 0,
 						width - cellWidth - r + marg, height(),
-						cg.brush( QColorGroup::Highlight ) );
+						cg.brush( QPalette::Highlight ) );
 					if ( isEnabled() || !lv )
 						p->setPen( cg.highlightedText() );
 					else if ( !isEnabled() && lv )
@@ -99,31 +106,32 @@ class AliasItem : public QListViewItem
 			else
 			{
 				// Use Qt's own drawing
-				QListViewItem::paintCell( p, cg, column, width, align );
+				Q3ListViewItem::paintCell( p, cg, column, width, align );
 			}
 		}
 };
 
-class ProtocolItem : public QListViewItem
+class ProtocolItem : public Q3ListViewItem
 {
 	public:
-		ProtocolItem( QListView *parent, KPluginInfo *p ) :
-		QListViewItem( parent, p->name() )
+		ProtocolItem( Q3ListView *parent, const KPluginInfo &p ) :
+		Q3ListViewItem( parent, p.name() )
 		{
-			this->setPixmap( 0, SmallIcon( p->icon() ) );
-			id = p->pluginName();
+			this->setPixmap( 0, SmallIcon( p.icon() ) );
+			id = p.pluginName();
 		}
 
 		QString id;
 };
 
-K_EXPORT_COMPONENT_FACTORY( kcm_kopete_alias, AliasPreferencesFactory( "kcm_kopete_alias" ) )
-
-AliasPreferences::AliasPreferences( QWidget *parent, const char *, const QStringList &args )
-	: KCModule( AliasPreferencesFactory::instance(), parent, args )
+AliasPreferences::AliasPreferences( QWidget *parent, const QVariantList &args )
+	: KCModule( AliasPreferencesFactory::componentData(), parent, args )
 {
-	( new QVBoxLayout( this ) )->setAutoAdd( true );
-	preferencesDialog = new AliasDialogBase( this );
+	QVBoxLayout* l = new QVBoxLayout( this );
+	QWidget* w = new QWidget;
+	preferencesDialog = new Ui::AliasDialogBase;
+	preferencesDialog->setupUi( w );
+	l->addWidget( w );
 
 	connect( preferencesDialog->addButton, SIGNAL(clicked()), this, SLOT( slotAddAlias() ) );
 	connect( preferencesDialog->editButton, SIGNAL(clicked()), this, SLOT( slotEditAlias() ) );
@@ -133,13 +141,11 @@ AliasPreferences::AliasPreferences( QWidget *parent, const char *, const QString
 
 	connect( preferencesDialog->aliasList, SIGNAL(selectionChanged()),
 		this, SLOT( slotCheckAliasSelected() ) );
-
-	load();
 }
 
 AliasPreferences::~AliasPreferences()
 {
-	QListViewItem *myChild = preferencesDialog->aliasList->firstChild();
+	Q3ListViewItem *myChild = preferencesDialog->aliasList->firstChild();
         while( myChild )
 	{
 		ProtocolList protocols = static_cast<AliasItem*>( myChild )->protocolList;
@@ -153,21 +159,21 @@ AliasPreferences::~AliasPreferences()
 
 		myChild = myChild->nextSibling();
 	}
+	delete preferencesDialog;
 }
 
 // reload configuration reading it from kopeterc
 void AliasPreferences::load()
 {
-	KConfig *config = KGlobal::config();
-	if( config->hasGroup( "AliasPlugin" ) )
+	KConfigGroup config(KGlobal::config(), "AliasPlugin");
+	if( config.exists() )
 	{
-		config->setGroup("AliasPlugin");
-		QStringList aliases = config->readListEntry("AliasNames");
+		QStringList aliases = config.readEntry("AliasNames", QStringList() );
 		for( QStringList::Iterator it = aliases.begin(); it != aliases.end(); ++it )
 		{
-			uint aliasNumber = config->readUnsignedNumEntry( (*it) + "_id" );
-			QString aliasCommand = config->readEntry( (*it) + "_command" );
-			QStringList protocols = config->readListEntry( (*it) + "_protocols" );
+			int aliasNumber = config.readEntry( (*it) + "_id", 0 );
+			QString aliasCommand = config.readEntry( (*it) + "_command", QString() );
+			QStringList protocols = config.readEntry( (*it) + "_protocols", QStringList() );
 
 			ProtocolList protocolList;
 			for( QStringList::Iterator it2 = protocols.begin(); it2 != protocols.end(); ++it2 )
@@ -189,16 +195,15 @@ void AliasPreferences::slotPluginLoaded( Kopete::Plugin *plugin )
 	Kopete::Protocol *protocol = static_cast<Kopete::Protocol*>( plugin );
 	if( protocol )
 	{
-		KConfig *config = KGlobal::config();
-		if( config->hasGroup( "AliasPlugin" ) )
+		KConfigGroup config(KGlobal::config(), "AliasPlugin");
+		if( config.exists() )
 		{
-			config->setGroup("AliasPlugin");
-			QStringList aliases = config->readListEntry("AliasNames");
+			QStringList aliases = config.readEntry("AliasNames", QStringList());
 			for( QStringList::Iterator it = aliases.begin(); it != aliases.end(); ++it )
 			{
-				uint aliasNumber = config->readUnsignedNumEntry( (*it) + "_id" );
-				QString aliasCommand = config->readEntry( (*it) + "_command" );
-				QStringList protocols = config->readListEntry( (*it) + "_protocols" );
+				uint aliasNumber = config.readEntry( (*it) + "_id", 0 );
+				QString aliasCommand = config.readEntry( (*it) + "_command", QString() );
+				QStringList protocols = config.readEntry( (*it) + "_protocols", QStringList() );
 
 				for( QStringList::iterator it2 = protocols.begin(); it2 != protocols.end(); ++it2 )
 				{
@@ -240,9 +245,8 @@ void AliasPreferences::slotPluginLoaded( Kopete::Plugin *plugin )
 // save list to kopeterc and creates map out of it
 void AliasPreferences::save()
 {
-	KConfig *config = KGlobal::config();
-	config->deleteGroup( QString::fromLatin1("AliasPlugin") );
-	config->setGroup( QString::fromLatin1("AliasPlugin") );
+	KConfigGroup config = KGlobal::config()->group("AliasPlugin");
+	config.deleteGroup();
 
 	QStringList aliases;
 	AliasItem *item = (AliasItem*)preferencesDialog->aliasList->firstChild();
@@ -257,15 +261,15 @@ void AliasPreferences::save()
 
 		aliases += item->text(0);
 
-		config->writeEntry( item->text(0) + "_id", item->id );
-		config->writeEntry( item->text(0) + "_command", item->text(1) );
-		config->writeEntry( item->text(0) + "_protocols", protocols );
+		config.writeEntry( item->text(0) + "_id", item->id );
+		config.writeEntry( item->text(0) + "_command", item->text(1) );
+		config.writeEntry( item->text(0) + "_protocols", protocols );
 
 		item = (AliasItem*)item->nextSibling();
         }
 
-	config->writeEntry( "AliasNames", aliases );
-	config->sync();
+	config.writeEntry( "AliasNames", aliases );
+	config.sync();
 	emit KCModule::changed(false);
 }
 
@@ -306,7 +310,7 @@ void AliasPreferences::addAlias( QString &alias, QString &command, const Protoco
 
 void AliasPreferences::slotAddAlias()
 {
-	EditAliasDialog addDialog;
+	EditAliasDialog addDialog(this);
 	loadProtocols( &addDialog );
 	addDialog.addButton->setText( i18n("&Add") );
 
@@ -320,7 +324,7 @@ void AliasPreferences::slotAddAlias()
 		{
 			KMessageBox::error( this, i18n("<qt>Could not add alias <b>%1</b>. An"
 					" alias name cannot contain the characters \"_\" or \"=\"."
-					"</qt>").arg(alias),i18n("Invalid Alias Name") );
+					"</qt>", alias),i18n("Invalid Alias Name") );
 		}
 		else
 		{
@@ -337,8 +341,8 @@ void AliasPreferences::slotAddAlias()
 				if( Kopete::CommandHandler::commandHandler()->commandHandledByProtocol( alias, *it ) )
 				{
 					KMessageBox::error( this, i18n("<qt>Could not add alias <b>%1</b>. This "
-						"command is already being handled by either another alias or "
-						"Kopete itself.</qt>").arg(alias), i18n("Could Not Add Alias") );
+						"command is already being handled either by another alias or "
+						"Kopete itself.</qt>", alias), i18n("Could Not Add Alias") );
 					return;
 				}
 			}
@@ -352,14 +356,14 @@ void AliasPreferences::slotAddAlias()
 const ProtocolList AliasPreferences::selectedProtocols( EditAliasDialog *dialog )
 {
 	ProtocolList protocolList;
-	QListViewItem *item = dialog->protocolList->firstChild();
+	Q3ListViewItem *item = dialog->protocolList->firstChild();
 
 	while( item )
 	{
 		if( item->isSelected() )
 		{
 
-			// If you dont have the selected protocol enabled, Kopete::PluginManager::self()->plugin
+			// If you don't have the selected protocol enabled, Kopete::PluginManager::self()->plugin
 			// will return NULL, check for that
 
 			if(Kopete::PluginManager::self()->plugin( static_cast<ProtocolItem*>(item)->id) )
@@ -375,20 +379,20 @@ const ProtocolList AliasPreferences::selectedProtocols( EditAliasDialog *dialog
 
 void AliasPreferences::loadProtocols( EditAliasDialog *dialog )
 {
-	QValueList<KPluginInfo*> plugins = Kopete::PluginManager::self()->availablePlugins("Protocols");
-	for( QValueList<KPluginInfo*>::Iterator it = plugins.begin(); it != plugins.end(); ++it )
+	foreach(const KPluginInfo &pluginInfo, Kopete::PluginManager::self()->availablePlugins("Protocols"))
 	{
-		ProtocolItem *item = new ProtocolItem( dialog->protocolList, *it );
-		itemMap[ (Kopete::Protocol*)Kopete::PluginManager::self()->plugin( (*it)->pluginName() ) ] = item;
+		ProtocolItem *item = new ProtocolItem( dialog->protocolList, pluginInfo );
+		itemMap[ (Kopete::Protocol*)Kopete::PluginManager::self()->plugin( pluginInfo.pluginName() ) ] = item;
 	}
 }
 
 void AliasPreferences::slotEditAlias()
 {
 	EditAliasDialog editDialog;
+
 	loadProtocols( &editDialog );
 
-	QListViewItem *item = preferencesDialog->aliasList->selectedItems().first();
+	Q3ListViewItem *item = preferencesDialog->aliasList->selectedItems().first();
 	if( item )
 	{
 		QString oldAlias = item->text(0);
@@ -409,7 +413,7 @@ void AliasPreferences::slotEditAlias()
 			{
 				KMessageBox::error( this, i18n("<qt>Could not add alias <b>%1</b>. An"
 						" alias name cannot contain the characters \"_\" or \"=\"."
-						"</qt>").arg(alias),i18n("Invalid Alias Name") );
+						"</qt>", alias),i18n("Invalid Alias Name") );
 			}
 			else
 			{
@@ -434,7 +438,7 @@ void AliasPreferences::slotEditAlias()
 						{
 							KMessageBox::error( this, i18n("<qt>Could not add alias <b>%1</b>. This "
 							"command is already being handled by either another alias or "
-							"Kopete itself.</qt>").arg(alias), i18n("Could Not Add Alias") );
+							"Kopete itself.</qt>", alias), i18n("Could Not Add Alias") );
 						return;
 						}
 					}
@@ -451,10 +455,12 @@ void AliasPreferences::slotEditAlias()
 
 void AliasPreferences::slotDeleteAliases()
 {
-	if( KMessageBox::warningContinueCancel(this, i18n("Are you sure you want to delete the selected aliases?"), i18n("Delete Aliases"), KGuiItem(i18n("Delete"), "editdelete") ) == KMessageBox::Continue )
+        QList< Q3ListViewItem* > items = preferencesDialog->aliasList->selectedItems();
+        if( items.isEmpty())
+            return;
+	if( KMessageBox::warningContinueCancel(this, i18n("Are you sure you want to delete the selected aliases?"), i18n("Delete Aliases"), KGuiItem(i18n("Delete"), "edit-delete") ) == KMessageBox::Continue )
 	{
-		QPtrList< QListViewItem > items = preferencesDialog->aliasList->selectedItems();
-		for( QListViewItem *i = items.first(); i; i = items.next() )
+		foreach( Q3ListViewItem *i, items)
 		{
 			ProtocolList protocols = static_cast<AliasItem*>( i )->protocolList;
 			for( ProtocolList::Iterator it = protocols.begin(); it != protocols.end(); ++it )
@@ -464,16 +470,17 @@ void AliasPreferences::slotDeleteAliases()
 					i->text(0)
 				);
 
-				protocolMap.erase( QPair<Kopete::Protocol*,QString>( *it, i->text(0) ) );
+				protocolMap.remove( QPair<Kopete::Protocol*,QString>( *it, i->text(0) ) );
 			}
 
-			aliasMap.erase( i->text(0) );
+			aliasMap.remove( i->text(0) );
 			delete i;
 			emit KCModule::changed(true);
 		}
 
 		save();
 	}
+        slotCheckAliasSelected();
 }
 
 void AliasPreferences::slotCheckAliasSelected()
