@@ -15,31 +15,34 @@
  *                                                                         *
  ***************************************************************************/
 
+#define QT3_SUPPORT
 #include <qlayout.h>
 #include <qpushbutton.h>
-#include <qgroupbox.h>
-#include <qheader.h>
-#include <qlistview.h>
+#include <q3header.h>
+#include <q3listview.h>
 
 #include <klocale.h>
 #include <klineedit.h>
 #include <kglobal.h>
 #include <kgenericfactory.h>
-#include <kautoconfig.h>
 
-#include "autoreplaceprefs.h"
+#include "ui_autoreplaceprefs.h"
 #include "autoreplacepreferences.h"
 #include "autoreplaceconfig.h"
 
-typedef KGenericFactory<AutoReplacePreferences> AutoReplacePreferencesFactory;
+K_PLUGIN_FACTORY(AutoReplacePreferencesFactory, registerPlugin<AutoReplacePreferences>();)
+K_EXPORT_PLUGIN(AutoReplacePreferencesFactory( "kcm_kopete_autoreplace" ))
 
-K_EXPORT_COMPONENT_FACTORY( kcm_kopete_autoreplace, AutoReplacePreferencesFactory( "kcm_kopete_autoreplace" ) )
 
-AutoReplacePreferences::AutoReplacePreferences( QWidget *parent, const char * /* name */, const QStringList &args )
-: KCAutoConfigModule( AutoReplacePreferencesFactory::instance(), parent, args )
+// TODO: Use KConfigXT
+AutoReplacePreferences::AutoReplacePreferences( QWidget *parent, const QVariantList &args )
+: KCModule( AutoReplacePreferencesFactory::componentData(), parent, args )
 {
-	( new QVBoxLayout( this ) )->setAutoAdd( true );
-	preferencesDialog = new AutoReplacePrefsUI( this );
+	QVBoxLayout* l = new QVBoxLayout( this );
+	QWidget* w = new QWidget;
+	preferencesDialog = new Ui::AutoReplacePrefsUI;
+	preferencesDialog->setupUi( w );
+	l->addWidget( w );
 
 	// creates table columns (avoids new columns every time)
 	preferencesDialog->m_list->addColumn( i18n("Text" ) );
@@ -58,17 +61,24 @@ AutoReplacePreferences::AutoReplacePreferences( QWidget *parent, const char * /*
 	connect( preferencesDialog->m_key, SIGNAL(textChanged ( const QString & )),
 		SLOT( slotEnableAddEdit( const QString & )) ); 
 
-	m_wordListChanged = false;
+	connect( preferencesDialog->AutoReplaceIncoming, SIGNAL(toggled ( bool )),
+		SLOT( slotWidgetModified()) ); 
+	connect( preferencesDialog->AutoReplaceOutgoing, SIGNAL(toggled ( bool )),
+		SLOT( slotWidgetModified()) ); 
+	connect( preferencesDialog->DotEndSentence, SIGNAL(toggled ( bool )),
+		SLOT( slotWidgetModified()) ); 
+	connect( preferencesDialog->CapitalizeBeginningSentence, SIGNAL(toggled ( bool )),
+		SLOT( slotWidgetModified()) ); 
 
-	setMainWidget( preferencesDialog->gb_options, "AutoReplace Plugin" );
+	//setMainWidget( preferencesDialog->gb_options, "AutoReplace Plugin" );
 
 	m_config = new AutoReplaceConfig;
-	load();
 }
 
 AutoReplacePreferences::~AutoReplacePreferences()
 {
 	delete m_config;
+	delete preferencesDialog;
 }
 
 // reload configuration reading it from kopeterc
@@ -85,11 +95,13 @@ void AutoReplacePreferences::load()
 	for ( it = map.begin(); it != map.end(); ++it )
 	{
 		// notice: insertItem is called automatically by the constructor
-		new QListViewItem( preferencesDialog->m_list, it.key(), it.data() );
+		new Q3ListViewItem( preferencesDialog->m_list, it.key(), it.value() );
 	}
 
-	m_wordListChanged = false;
-	KCAutoConfigModule::load();
+	preferencesDialog->AutoReplaceIncoming->setChecked(m_config->autoReplaceIncoming());
+	preferencesDialog->AutoReplaceOutgoing->setChecked(m_config->autoReplaceOutgoing());
+	preferencesDialog->DotEndSentence->setChecked(m_config->dotEndSentence());
+	preferencesDialog->CapitalizeBeginningSentence->setChecked(m_config->capitalizeBeginningSentence());
 }
 
 // save list to kopeterc and creates map out of it
@@ -97,15 +109,18 @@ void AutoReplacePreferences::save()
 {
 	// make a list reading all values from gui
 	AutoReplaceConfig::WordsToReplace newWords;
-	for ( QListViewItem * i = preferencesDialog->m_list->firstChild(); i != 0; i = i->nextSibling() )
+	for ( Q3ListViewItem * i = preferencesDialog->m_list->firstChild(); i != 0; i = i->nextSibling() )
 		newWords[ i->text( 0 ) ] = i->text( 1 );
 
 	// save the words list
 	m_config->setMap( newWords );
-	m_config->save();
 
-	m_wordListChanged = false;
-	KCAutoConfigModule::save();
+	m_config->setAutoReplaceIncoming(preferencesDialog->AutoReplaceIncoming->isChecked());
+	m_config->setAutoReplaceOutgoing(preferencesDialog->AutoReplaceOutgoing->isChecked());
+	m_config->setDotEndSentence(preferencesDialog->DotEndSentence->isChecked());
+	m_config->setCapitalizeBeginningSentence(preferencesDialog->CapitalizeBeginningSentence->isChecked());
+
+	m_config->save();
 }
 
 // read m_key m_value, create a QListViewItem
@@ -115,12 +130,12 @@ void AutoReplacePreferences::slotAddCouple()
 	QString v = preferencesDialog->m_value->text();
 	if ( !k.isEmpty() && !k.isNull() && !v.isEmpty() && !v.isNull() )
 	{
-		QListViewItem * lvi;
-		QListViewItem * oldLvi = 0;
+		Q3ListViewItem * lvi;
+		Q3ListViewItem * oldLvi = 0;
 		// see if we are replacing an existing entry
 		if ( ( oldLvi = preferencesDialog->m_list->findItem( k, 0 ) ) )
 			delete oldLvi;
-		lvi = new QListViewItem( preferencesDialog->m_list, k, v );
+		lvi = new Q3ListViewItem( preferencesDialog->m_list, k, v );
 		// Triggers a size, geometry and content update
 		// during the next iteration of the event loop
 		preferencesDialog->m_list->triggerUpdate();
@@ -128,7 +143,6 @@ void AutoReplacePreferences::slotAddCouple()
 		preferencesDialog->m_list->setSelected( lvi, true );
 	}
 
-	m_wordListChanged = true;
 	slotWidgetModified();
 }
 
@@ -137,13 +151,12 @@ void AutoReplacePreferences::slotEditCouple()
 {
 	QString k = preferencesDialog->m_key->text();
 	QString v = preferencesDialog->m_value->text();
-	QListViewItem * lvi;
+	Q3ListViewItem * lvi;
 	if ( ( lvi = preferencesDialog->m_list->selectedItem() ) && !k.isEmpty() && !k.isNull() && !v.isEmpty() && !v.isNull() )
 	{
 		lvi->setText( 0, k );
 		lvi->setText( 1, v );
 		preferencesDialog->m_list->triggerUpdate();
-		m_wordListChanged = true;
 		slotWidgetModified();
 	}
 }
@@ -154,7 +167,6 @@ void AutoReplacePreferences::slotRemoveCouple()
 {
 	delete preferencesDialog->m_list->selectedItem();
 
-	m_wordListChanged = true;
 	slotWidgetModified();
 }
 
@@ -166,7 +178,7 @@ void AutoReplacePreferences::slotEnableAddEdit( const QString & keyText )
 
 void AutoReplacePreferences::slotSelectionChanged()
 {
-	QListViewItem *selection = 0;
+	Q3ListViewItem *selection = 0;
 	if ( ( selection = preferencesDialog->m_list->selectedItem() ) )
 	{
 		// enable the remove button
@@ -185,12 +197,11 @@ void AutoReplacePreferences::slotSelectionChanged()
 
 void AutoReplacePreferences::slotWidgetModified()
 {
-	emit KCModule::changed( m_wordListChanged || autoConfig()->hasChanged() );
+	emit KCModule::changed( true );
 }
 
 void AutoReplacePreferences::defaults()
 {
-    KCAutoConfigModule::defaults();
     preferencesDialog->m_list->clear();
     m_config->loadDefaultAutoReplaceList();
     AutoReplaceConfig::WordsToReplace::Iterator it;
@@ -198,9 +209,14 @@ void AutoReplacePreferences::defaults()
     for ( it = map.begin(); it != map.end(); ++it )
     {
         // notice: insertItem is called automatically by the constructor
-        new QListViewItem( preferencesDialog->m_list, it.key(), it.data() );
+        new Q3ListViewItem( preferencesDialog->m_list, it.key(), it.value() );
     }
-    m_wordListChanged = true;
+
+	preferencesDialog->AutoReplaceIncoming->setChecked(false);
+	preferencesDialog->AutoReplaceOutgoing->setChecked(true);
+	preferencesDialog->DotEndSentence->setChecked(false);
+	preferencesDialog->CapitalizeBeginningSentence->setChecked(false);
+
     slotWidgetModified();
 }
 
