@@ -3,7 +3,7 @@
                              -------------------
     begin                : lun sep 16 2002
     copyright            : (C) 2002 by Olivier Goffart
-    email                : ogoffart@tiscalinet.be
+    email                : ogoffart@kde.org
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef BABELFISHPLUGIN_H
-#define BABELFISHPLUGIN_H
+#ifndef CONTACTNOTESPLUGIN_H
+#define CONTACTNOTESPLUGIN_H
 
 #include <qobject.h>
 #include <qmap.h>
@@ -26,12 +26,11 @@
 
 class QString;
 class KAction;
-class KActionCollection;
 
 namespace Kopete { class MetaContact; }
 
 /**
-  * @author Olivier Goffart <ogoffart@tiscalinet.be>
+  * @author Olivier Goffart <ogoffart@kde.org>
   *
   * Kopete Contact Notes Plugin
   *
@@ -44,7 +43,7 @@ class ContactNotesPlugin : public Kopete::Plugin
 public:
     static ContactNotesPlugin  *plugin();
 
-	ContactNotesPlugin( QObject *parent, const char *name, const QStringList &args );
+	ContactNotesPlugin( QObject *parent, const QVariantList &args );
 	~ContactNotesPlugin();
 
 	QString notes(Kopete::MetaContact *m);
@@ -61,6 +60,4 @@ private slots: // Private slots
   void slotEditInfo();
 };
 
-#endif
-
-
+#endif // CONTACTNOTESPLUGIN_H
