@@ -3,6 +3,7 @@
 
     Copyright (c) 2003-2004 by Marc Cramdal        <marc.cramdal@gmail.com>
 
+    Copyright (c) 2007      by the Kopete Developers <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -16,8 +17,7 @@
 
 #include <stdlib.h>
 
-#include <qvaluelist.h>
-#include <quuid.h>
+#include <q3valuelist.h>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -32,64 +32,13 @@ StatisticsContact::StatisticsContact(Kopete::MetaContact *mc, StatisticsDB *db)
 {
 	m_isChatWindowOpen = false;
 	m_oldStatusDateTime = QDateTime::currentDateTime();
-	
+
 	// Last*Changed are always false at start
 	m_timeBetweenTwoMessagesChanged  = false;
 	m_lastTalkChanged = false;
 	m_lastPresentChanged  = false;
 	m_messageLengthChanged = false;
-}
 
-/**
- * \brief saves contact statistics
- */
-StatisticsContact::~StatisticsContact()
-{
-	if (m_statisticsContactId.isEmpty())
-		return;
-	
-	commonStatsSave("timebetweentwomessages",QString::number(m_timeBetweenTwoMessages), 
-	QString::number(m_timeBetweenTwoMessagesOn), m_timeBetweenTwoMessagesChanged);	 
-	commonStatsSave("messagelength",QString::number(m_messageLength), QString::number(m_messageLengthOn), m_messageLengthChanged); 
-	commonStatsSave("lasttalk", m_lastTalk.toString(), "", m_lastTalkChanged);
-	commonStatsSave("lastpresent", m_lastPresent.toString(), "", m_lastPresentChanged);
-}
-
-void StatisticsContact::initialize(Kopete::Contact *c)
-{
-	// Generate statisticsContactId or get it from database
-	QStringList buffer = m_db->query(QString("SELECT statisticid FROM contacts "
-						"WHERE contactid LIKE '%1';"
-						).arg(c->contactId()));
-
-	if (buffer.isEmpty())
-	{
-		// Check if we don't have old data
-		if ( !c->metaContact()->metaContactId().isEmpty() &&
-			!m_db->query(QString("SELECT metacontactid FROM commonstats "
-						"WHERE metacontactid LIKE '%1';"
-						).arg(c->metaContact()->metaContactId())).isEmpty())
-		{
-			// Use old style id
-			m_statisticsContactId = c->metaContact()->metaContactId();
-		}
-		else
-		{
-			// Create new id
-			m_statisticsContactId = QUuid::createUuid().toString();
-		}
-		
-		// Assign contactId to m_statisticsContactId
-		m_db->query(QString("INSERT INTO contacts (statisticid, contactid) VALUES('%1', '%2');"
-				).arg(m_statisticsContactId).arg(c->contactId()));
-	}
-	else
-	{
-		m_statisticsContactId = buffer[0];
-	}
-	
-	kdDebug() << k_funcinfo << " m_statisticsContactId: " << m_statisticsContactId << endl;
-	
 	commonStatsCheck("timebetweentwomessages", m_timeBetweenTwoMessages, m_timeBetweenTwoMessagesOn, 0, -1);
 	commonStatsCheck("messagelength", m_messageLength, m_messageLengthOn, 0, 0);
 	
@@ -122,61 +71,25 @@ void StatisticsContact::initialize(Kopete::Contact *c)
 		m_lastPresent = QDateTime::fromString(lastPresent);
 }
 
-void StatisticsContact::contactAdded( Kopete::Contact *c )
+/**
+ * \brief saves contact statistics
+ */
+StatisticsContact::~StatisticsContact()
 {
-	if ( !m_statisticsContactId.isEmpty() )
-	{
-		// Check if contact is allready in database if not add it
-		if (m_db->query(QString("SELECT id FROM contacts "
-					"WHERE statisticid LIKE '%1' AND contactid LIKE '%2';"
-					).arg(m_statisticsContactId).arg(c->contactId())).isEmpty())
-		{
-			// Assign contactId to m_statisticsContactId
-			m_db->query(QString("INSERT INTO contacts (statisticid, contactid) VALUES('%1', '%2');"
-				   ).arg(m_statisticsContactId).arg(c->contactId()));
-		}
-		kdDebug() << k_funcinfo << " m_statisticsContactId: " << m_statisticsContactId << endl;
-	}
-	else
-	{
-		// This is first contact, we need to initialize this object
-		initialize(c);
-	}
-}
-
-void StatisticsContact::contactRemoved( Kopete::Contact *c )
-{
-	if (m_statisticsContactId.isEmpty())
-		return;
-	
-	kdDebug() << k_funcinfo << " m_statisticsContactId: " << m_statisticsContactId << endl;
-	m_db->query(QString("DELETE FROM contacts WHERE statisticid LIKE '%1' AND contactid LIKE '%2';"
-			   ).arg(m_statisticsContactId).arg(c->contactId()));
-}
-
-void StatisticsContact::removeFromDB()
-{
-	if (m_statisticsContactId.isEmpty())
-		return;
-	
-	kdDebug() << k_funcinfo << " m_statisticsContactId: " << m_statisticsContactId << endl;
-	m_db->query(QString("DELETE FROM contacts WHERE statisticid LIKE '%1';").arg(m_statisticsContactId));
-	m_db->query(QString("DELETE FROM contactstatus WHERE metacontactid LIKE '%1';").arg(m_statisticsContactId));
-	m_db->query(QString("DELETE FROM commonstats WHERE metacontactid LIKE '%1';").arg(m_statisticsContactId));
-	
-	m_statisticsContactId = QString::null;
+	commonStatsSave("timebetweentwomessages",QString::number(m_timeBetweenTwoMessages), 
+	QString::number(m_timeBetweenTwoMessagesOn), m_timeBetweenTwoMessagesChanged);	 
+	commonStatsSave("messagelength",QString::number(m_messageLength), QString::number(m_messageLengthOn), m_messageLengthChanged); 
+	commonStatsSave("lasttalk", m_lastTalk.toString(), "", m_lastTalkChanged);
+	commonStatsSave("lastpresent", m_lastPresent.toString(), "", m_lastPresentChanged);
 }
 
 void StatisticsContact::commonStatsSave(const QString name, const QString statVar1, const QString statVar2, const bool statVarChanged)
 {
 	// Only update the database if there was a change
 	if (!statVarChanged) return;
-	
-	if (m_statisticsContactId.isEmpty())
-		return;
-	
+
 	m_db->query(QString("UPDATE commonstats SET statvalue1 = '%1', statvalue2='%2'"
-			"WHERE statname LIKE '%3' AND metacontactid LIKE '%4';").arg(statVar1).arg(statVar2).arg(name).arg(m_statisticsContactId));
+			"WHERE statname LIKE '%3' AND metacontactid LIKE '%4';").arg(statVar1).arg(statVar2).arg(name).arg(metaContact()->metaContactId()));
 	
 }
 
@@ -193,10 +106,7 @@ void StatisticsContact::commonStatsCheck(const QString name, int& statVar1, int&
 
 void StatisticsContact::commonStatsCheck(const QString name, QString& statVar1, QString& statVar2, const QString defaultValue1, const QString defaultValue2)
 {
-	if (m_statisticsContactId.isEmpty())
-		return;
-	
-	QStringList buffer = m_db->query(QString("SELECT statvalue1,statvalue2 FROM commonstats WHERE statname LIKE '%1' AND metacontactid LIKE '%2';").arg(name, m_statisticsContactId));
+	QStringList buffer = m_db->query(QString("SELECT statvalue1,statvalue2 FROM commonstats WHERE statname LIKE '%1' AND metacontactid LIKE '%2';").arg(name, metaContact()->metaContactId()));
 	if (!buffer.isEmpty())
 	{
 		statVar1 = buffer[0];
@@ -204,14 +114,14 @@ void StatisticsContact::commonStatsCheck(const QString name, QString& statVar1,
 	}
 	else
 	{
-		m_db->query(QString("INSERT INTO commonstats (metacontactid, statname, statvalue1, statvalue2) VALUES('%1', '%2', 0, 0);").arg(m_statisticsContactId, name));
+		m_db->query(QString("INSERT INTO commonstats (metacontactid, statname, statvalue1, statvalue2) VALUES('%1', '%2', 0, 0);").arg(metaContact()->metaContactId(), name));
 		statVar1 = defaultValue1;
 		statVar2 = defaultValue2;
 	}
 }
 
 /**
- * \brief records informations from the new message
+ * \brief records information from the new message
  *
  * Currently it does :
  * <ul>
@@ -225,7 +135,7 @@ void StatisticsContact::commonStatsCheck(const QString name, QString& statVar1,
  *
  *	Then it is only a question of some calculations.
  *
- * 	<li>Recalculate the average message lenght
+ * 	<li>Recalculate the average message length
  * 
  *	<li>Change last-talk datetime
  * </ul>
@@ -233,7 +143,7 @@ void StatisticsContact::commonStatsCheck(const QString name, QString& statVar1,
  */
 void StatisticsContact::newMessageReceived(Kopete::Message& m)
 {
-	kdDebug() << "statistics: new message received" << endl;
+	kDebug(14315) << "statistics: new message received";
 	QDateTime currentDateTime = QDateTime::currentDateTime();
 	
 	if (m_timeBetweenTwoMessagesOn != -1 && m_isChatWindowOpen)
@@ -248,7 +158,7 @@ void StatisticsContact::newMessageReceived(Kopete::Message& m)
 	m_lastMessageReceived = currentDateTime;
 	
 	
-	// Message lenght
+	// Message length
 	m_messageLength= (m.plainBody().length() + m_messageLength * m_messageLengthOn)/(1 + m_messageLengthOn);
 	m_messageLengthOn++;
 	
@@ -266,9 +176,6 @@ void StatisticsContact::newMessageReceived(Kopete::Message& m)
  */
 void StatisticsContact::onlineStatusChanged(Kopete::OnlineStatus::StatusType status)
 {
-	if (m_statisticsContactId.isEmpty())
-		return;
-	
 	QDateTime currentDateTime = QDateTime::currentDateTime();
 	
 	/// We don't want to log if oldStatus is unknown
@@ -276,10 +183,10 @@ void StatisticsContact::onlineStatusChanged(Kopete::OnlineStatus::StatusType sta
 	if (m_oldStatus != Kopete::OnlineStatus::Unknown)
 	{
 		
-		kdDebug() << "statistics - status change for "<< metaContact()->metaContactId() << " : "<< QString::number(m_oldStatus) << endl;
+		kDebug(14315) << "statistics - status change for "<< metaContact()->metaContactId() << " : "<< QString::number(m_oldStatus);
 		m_db->query(QString("INSERT INTO contactstatus "
 		"(metacontactid, status, datetimebegin, datetimeend) "
-				"VALUES('%1', '%2', '%3', '%4'" ");").arg(m_statisticsContactId).arg(Kopete::OnlineStatus::statusTypeToString(m_oldStatus)).arg(QString::number(m_oldStatusDateTime.toTime_t())).arg(QString::number(currentDateTime.toTime_t())));
+				"VALUES('%1', '%2', '%3', '%4'" ");").arg(m_metaContact->metaContactId()).arg(Kopete::OnlineStatus::statusTypeToString(m_oldStatus)).arg(QString::number(m_oldStatusDateTime.toTime_t())).arg(QString::number(currentDateTime.toTime_t())));
 	}
 	
 	if (m_oldStatus == Kopete::OnlineStatus::Online || m_oldStatus == Kopete::OnlineStatus::Away)
@@ -296,14 +203,11 @@ void StatisticsContact::onlineStatusChanged(Kopete::OnlineStatus::StatusType sta
 
 bool StatisticsContact::wasStatus(QDateTime dt, Kopete::OnlineStatus::StatusType status)
 {
-	if (m_statisticsContactId.isEmpty())
-		return false;
-	
 	QStringList values = m_db->query(QString("SELECT status, datetimebegin, datetimeend "
 			"FROM contactstatus WHERE metacontactid LIKE '%1' AND datetimebegin <= %2 AND datetimeend >= %3 "
 			"AND status LIKE '%4' "
 			"ORDER BY datetimebegin;"
-		).arg(m_statisticsContactId).arg(dt.toTime_t()).arg(dt.toTime_t()).arg(Kopete::OnlineStatus::statusTypeToString(status)));	
+		).arg(metaContact()->metaContactId()).arg(dt.toTime_t()).arg(dt.toTime_t()).arg(Kopete::OnlineStatus::statusTypeToString(status)));	
 	
 	if (!values.isEmpty()) return true;
 	
@@ -312,13 +216,10 @@ bool StatisticsContact::wasStatus(QDateTime dt, Kopete::OnlineStatus::StatusType
 
 QString StatisticsContact::statusAt(QDateTime dt)
 {
-	if (m_statisticsContactId.isEmpty())
-		return "";
-	
 	QStringList values = m_db->query(QString("SELECT status, datetimebegin, datetimeend "
 			"FROM contactstatus WHERE metacontactid LIKE '%1' AND datetimebegin <= %2 AND datetimeend >= %3 "
 			"ORDER BY datetimebegin;"
-			).arg(m_statisticsContactId).arg(dt.toTime_t()).arg(dt.toTime_t()));	
+			).arg(metaContact()->metaContactId()).arg(dt.toTime_t()).arg(dt.toTime_t()));	
 	
 	if (!values.isEmpty()) return Kopete::OnlineStatus(Kopete::OnlineStatus::statusStringToType(values[0])).description();
 	else return "";
@@ -326,26 +227,23 @@ QString StatisticsContact::statusAt(QDateTime dt)
 
 QString StatisticsContact::mainStatusDate(const QDate& date)
 {
-	if (m_statisticsContactId.isEmpty())
-		return "";
-	
 	QDateTime dt1(date, QTime(0,0,0));
 	QDateTime dt2(date.addDays(1), QTime(0,0,0));
-	kdDebug() << "dt1:" << dt1.toString() << " dt2:" << dt2.toString() << endl;
+	kDebug(14315) << "dt1:" << dt1.toString() << " dt2:" << dt2.toString();
 	QString request = QString("SELECT status, datetimebegin, datetimeend, metacontactid "
 			"FROM contactstatus WHERE metacontactid = '%1' AND "
 			"(datetimebegin >= %2 AND datetimebegin <= %3 OR "
 			"datetimeend >= %4 AND datetimeend <= %5) "
 			"ORDER BY datetimebegin;"
-							 ).arg(m_statisticsContactId).arg(dt1.toTime_t()).arg(dt2.toTime_t()).arg(dt1.toTime_t()).arg(dt2.toTime_t());
-	kdDebug() << request << endl;
+							 ).arg(metaContact()->metaContactId()).arg(dt1.toTime_t()).arg(dt2.toTime_t()).arg(dt1.toTime_t()).arg(dt2.toTime_t());
+	kDebug(14315) << request;
 	QStringList values = m_db->query(request);
 	
 	unsigned int online = 0, offline = 0, away = 0;
-	for(uint i=0; i<values.count(); i+=4)
+	for(int i=0; i<values.count(); i+=4)
 	{
 		unsigned int datetimebegin = values[i+1].toInt(), datetimeend = values[i+2].toInt();
-		kdDebug() << "statistics: id "<< values[i+3]<< " status " << values[i] << " datetimeend " << QString::number(datetimeend) << " datetimebegin " << QString::number(datetimebegin) << endl;
+		kDebug(14315) << "statistics: id "<< values[i+3]<< " status " << values[i] << " datetimeend " << QString::number(datetimeend) << " datetimebegin " << QString::number(datetimebegin);
 		if (datetimebegin <= dt1.toTime_t()) datetimebegin = dt1.toTime_t();
 		if (datetimeend >= dt2.toTime_t()) datetimeend = dt2.toTime_t();
 		
@@ -381,21 +279,19 @@ QString StatisticsContact::mainStatusDate(const QDate& date)
 // 	
 // }
 
-QValueList<QTime> StatisticsContact::mainEvents(const Kopete::OnlineStatus::StatusType& status)
+Q3ValueList<QTime> StatisticsContact::mainEvents(const Kopete::OnlineStatus::StatusType& status)
 {
 	QStringList buffer;
-	QValueList<QTime> mainEvents;
+	Q3ValueList<QTime> mainEvents;
 	
-	if (m_statisticsContactId.isEmpty())
-		return mainEvents;
 	
 	QDateTime currentDateTime = QDateTime::currentDateTime();
-	buffer = m_db->query(QString("SELECT datetimebegin, datetimeend, status FROM contactstatus WHERE metacontactid LIKE '%1' ORDER BY datetimebegin").arg(m_statisticsContactId));
+	buffer = m_db->query(QString("SELECT datetimebegin, datetimeend, status FROM contactstatus WHERE metacontactid LIKE '%1' ORDER BY datetimebegin").arg(metaContact()->metaContactId()));
 	
 	
 	// Only select the events for which the previous is not Unknown AND the status is status.
 	QStringList values;
-	for (uint i=0; i<buffer.count(); i += 3)
+	for (int i=0; i<buffer.count(); i += 3)
 	{
 		if (buffer[i+2] == Kopete::OnlineStatus::statusTypeToString(status)
 			&& abs(buffer[i+1].toInt()-buffer[i].toInt()) > 120)
@@ -414,11 +310,11 @@ QValueList<QTime> StatisticsContact::mainEvents(const Kopete::OnlineStatus::Stat
 	dt2.setTime_t(values[values.count()-1].toInt());
 	
 	avEventsPerDay = qRound((double)values.count()/(double)dt1.daysTo(dt2));
-	kdDebug() << "statistics: average events per day : " <<avEventsPerDay << endl;
+	kDebug(14315) << "statistics: average events per day : " <<avEventsPerDay;
 	
 	// We want to work on hours
-	QValueList<int> hoursValues;
-	for (uint i=0; i<values.count(); i++)
+	Q3ValueList<int> hoursValues;
+	for (int i=0; i<values.count(); i++)
 	{
 		QDateTime dt;
 		dt.setTime_t(values[i].toInt());
@@ -426,16 +322,16 @@ QValueList<QTime> StatisticsContact::mainEvents(const Kopete::OnlineStatus::Stat
 	}
 	
 	// Sort the list
-	qHeapSort(hoursValues);
+	//qSort(hoursValues);
 	
 	// Then we put some centroids (centroids in [0..24[)
-	QValueList<int> centroids;
+	Q3ValueList<int> centroids;
 	int incr=qRound((double)hoursValues.count()/(double)avEventsPerDay);
 	incr = incr ? incr : 1;
-	for (uint i=0; i<hoursValues.count(); i+=incr)
+	for (int i=0; i<hoursValues.count(); i+=incr)
 	{
 		centroids.push_back(hoursValues[i]);
-		kdDebug() << "statistics: add a centroid : " << centroids[centroids.count()-1] << endl;
+		kDebug(14315) << "statistics: add a centroid : " << centroids[centroids.count()-1];
 	}
 	
 	
@@ -443,9 +339,9 @@ QValueList<QTime> StatisticsContact::mainEvents(const Kopete::OnlineStatus::Stat
 	centroids = computeCentroids(centroids, hoursValues);
 	
 	// Convert to QDateTime
-	for (uint i=0; i<centroids.count(); i++)
+	for (int i=0; i<centroids.count(); i++)
 	{
-		kdDebug() << "statistics: new centroid : " << centroids[i] << endl;
+		kDebug(14315) << "statistics: new centroid : " << centroids[i];
 
 		QTime dt(0, 0, 0);
 		dt = dt.addSecs(centroids[i]);
@@ -456,19 +352,19 @@ QValueList<QTime> StatisticsContact::mainEvents(const Kopete::OnlineStatus::Stat
 	return mainEvents;
 }
 
-QValueList<int> StatisticsContact::computeCentroids(const QValueList<int>& centroids, const QValueList<int>& values)
+Q3ValueList<int> StatisticsContact::computeCentroids(const Q3ValueList<int>& centroids, const Q3ValueList<int>& values)
 {
-	kdDebug() << "statistics: enter compute centroids"<< endl;
+	kDebug(14315) << "statistics: enter compute centroids";
 
-	QValueList<int> whichCentroid; // whichCentroid[i] = j <=> values[i] has centroid j for closest one
-	QValueList<int> newCentroids;
-	for (uint i=0; i<values.count(); i++)
+	Q3ValueList<int> whichCentroid; // whichCentroid[i] = j <=> values[i] has centroid j for closest one
+	Q3ValueList<int> newCentroids;
+	for (int i=0; i<values.count(); i++)
 	// Iterates over the values. For each one we need to get the closest centroid.
 	{
 		int value = values[i];
 		int distanceToNearestCentroid = abs(centroids[0]-value);
 		int nearestCentroid = 0;
-		for (uint j=1; j<centroids.count(); j++)
+		for (int j=1; j<centroids.count(); j++)
 		{
 			if (abs(centroids[j]-value) < distanceToNearestCentroid)
 			{
@@ -482,11 +378,11 @@ QValueList<int> StatisticsContact::computeCentroids(const QValueList<int>& centr
 	// Recompute centroids
 	newCentroids = centroids;
 	
-	for (uint i=0; i<newCentroids.count(); i++)
+	for (int i=0; i<newCentroids.count(); i++)
 	{
-		kdDebug() << "statistics: compute new centroids"<< i << endl;
+		kDebug(14315) << "statistics: compute new centroids"<< i;
 		int weight = 0;
-		for (uint j=0; j<values.count(); j++)
+		for (int j=0; j<values.count(); j++)
 		{
 			int value = values[j];
 			if (whichCentroid[j] == i)
@@ -502,7 +398,7 @@ QValueList<int> StatisticsContact::computeCentroids(const QValueList<int>& centr
 	
 	// Should we recompute or are we OK ?
 	int dist = 0;
-	for (uint i=0; i < newCentroids.count(); i++)
+	for (int i=0; i < newCentroids.count(); i++)
 		dist += abs(newCentroids[i]-centroids[i]);
 	
 	if (dist > 10) 
