@@ -3,10 +3,10 @@
 
    Kopete Web Presence plugin
 
-   Copyright (c) 2005      by Tommi Rantala   <tommi.rantala@cs.helsinki.fi>
+   Copyright     2005-2006 by Tommi Rantala   <tommi.rantala@cs.helsinki.fi>
    Copyright (c) 2002,2003 by Will Stephenson <will@stevello.free-online.co.uk>
 
-   Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
+   Kopete    (c) 2002-2006 by the Kopete developers  <kopete-devel@kde.org>
 
  *************************************************************************
  *                                                                    	 *
@@ -18,17 +18,21 @@
  *************************************************************************
  */
 
-#include "config.h"
+#include "config-kopete.h"
 
 #include <qdom.h>
 #include <qtimer.h>
 #include <qfile.h>
+#include <QTextCodec>
+#include <QTextStream>
+#include <QList>
+#include <QDateTime>
 
 #include <kdebug.h>
 #include <kconfig.h>
 #include <kgenericfactory.h>
 #include <kmessagebox.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <kstandarddirs.h>
 
 #ifdef HAVE_XSLT
@@ -48,11 +52,12 @@
 
 #include "webpresenceplugin.h"
 
-typedef KGenericFactory<WebPresencePlugin> WebPresencePluginFactory;
-K_EXPORT_COMPONENT_FACTORY( kopete_webpresence, WebPresencePluginFactory( "kopete_webpresence" )  )
+K_PLUGIN_FACTORY(WebPresencePluginFactory, registerPlugin<WebPresencePlugin>();)
+K_EXPORT_PLUGIN(WebPresencePluginFactory( "kopete_webpresence" ))
 
-WebPresencePlugin::WebPresencePlugin( QObject *parent, const char *name, const QStringList& /*args*/ )
-	: Kopete::Plugin( WebPresencePluginFactory::instance(), parent, name ),
+
+WebPresencePlugin::WebPresencePlugin( QObject *parent, const QVariantList& /*args*/ )
+	: Kopete::Plugin( WebPresencePluginFactory::componentData(), parent ),
 	shuttingDown( false ), resultFormatting( WEB_HTML )
 {
 	m_writeScheduler = new QTimer( this );
@@ -73,33 +78,32 @@ WebPresencePlugin::~WebPresencePlugin()
 
 void WebPresencePlugin::loadSettings()
 {
-	KConfig *kconfig = KGlobal::config();
-	kconfig->setGroup( "Web Presence Plugin" );
+	KConfigGroup kconfig(KGlobal::config(), "Web Presence Plugin");
 
-	frequency = kconfig->readNumEntry("UploadFrequency", 15);
-	resultURL = kconfig->readPathEntry("uploadURL");
+	frequency = kconfig.readEntry("UploadFrequency", 15);
+	resultURL = kconfig.readEntry("uploadURL");
 
 	resultFormatting = WEB_UNDEFINED;
 
-	if ( kconfig->readBoolEntry( "formatHTML", false ) ) {
+	if ( kconfig.readEntry( "formatHTML", false ) ) {
 		resultFormatting = WEB_HTML;
-	} else if ( kconfig->readBoolEntry( "formatXHTML", false ) ) {
+	} else if ( kconfig.readEntry( "formatXHTML", false ) ) {
 		resultFormatting = WEB_XHTML;
-	} else if ( kconfig->readBoolEntry( "formatXML", false ) ) {
+	} else if ( kconfig.readEntry( "formatXML", false ) ) {
 		resultFormatting = WEB_XML;
-	} else if ( kconfig->readBoolEntry( "formatStylesheet", false ) ) {
+	} else if ( kconfig.readEntry( "formatStylesheet", false ) ) {
 		resultFormatting = WEB_CUSTOM;
-		userStyleSheet = kconfig->readEntry("formatStylesheetURL");
+		userStyleSheet = kconfig.readEntry("formatStylesheetURL", QString() );
 	}
 
-	// Default to HTML if we dont get anything useful from config file.
+	// Default to HTML, if we don't get anything useful from config file.
 	if ( resultFormatting == WEB_UNDEFINED )
 		resultFormatting = WEB_HTML;
 
-	useImagesInHTML = kconfig->readBoolEntry( "useImagesHTML", false );
-	useImName = kconfig->readBoolEntry("showName", true);
-	userName = kconfig->readEntry("showThisName");
-	showAddresses = kconfig->readBoolEntry("includeIMAddress", false);
+	useImagesInHTML = kconfig.readEntry( "useImagesHTML", false );
+	useImName = kconfig.readEntry("showName", true);
+	userName = kconfig.readEntry("showThisName", QString());
+	showAddresses = kconfig.readEntry("includeIMAddress", false);
 
 	// Update file when settings are changed.
 	slotWriteFile();
@@ -107,16 +111,14 @@ void WebPresencePlugin::loadSettings()
 
 void WebPresencePlugin::listenToAllAccounts()
 {
-	// connect to signals notifying of all accounts' status changes
+	// Connect to signals notifying of all accounts' status changes.
 	ProtocolList protocols = allProtocols();
 
 	for ( ProtocolList::Iterator it = protocols.begin();
 			it != protocols.end(); ++it )
 	{
-		QDict<Kopete::Account> accounts = Kopete::AccountManager::self()->accounts( *it );
-		QDictIterator<Kopete::Account> acIt( accounts );
-
-		for( ; Kopete::Account *account = acIt.current(); ++acIt )
+		QList<Kopete::Account*> accounts = Kopete::AccountManager::self()->accounts( *it );
+		foreach(Kopete::Account *account, accounts)
 		{
 			listenToAccount( account );
 		}
@@ -155,17 +157,17 @@ void WebPresencePlugin::slotWriteFile()
 {
 	m_writeScheduler->stop();
 
-	// generate the (temporary) XML file representing the current contactlist
-	KURL dest( resultURL );
+	// generate the (temporary) XML file representing the current contact list
+	KUrl dest( resultURL );
 	if ( resultURL.isEmpty() || !dest.isValid() )
 	{
-		kdDebug(14309) << "url is empty or not valid. NOT UPDATING!" << endl;
+		kDebug(14309) << "url is empty or not valid. NOT UPDATING!";
 		return;
 	}
 
-	KTempFile* xml = generateFile();
-	xml->setAutoDelete( true );
-	kdDebug(14309) << k_funcinfo << " " << xml->name() << endl;
+	KTemporaryFile* xml = generateFile();
+	xml->setAutoRemove( true );
+	kDebug(14309) << " " << xml->fileName();
 
 	switch( resultFormatting ) {
 	case WEB_XML:
@@ -175,8 +177,8 @@ void WebPresencePlugin::slotWriteFile()
 	case WEB_HTML:
 	case WEB_XHTML:
 	case WEB_CUSTOM:
-		m_output = new KTempFile();
-		m_output->setAutoDelete( true );
+		m_output = new KTemporaryFile();
+		m_output->open();
 
 		if ( !transform( xml, m_output ) )
 		{
@@ -191,31 +193,30 @@ void WebPresencePlugin::slotWriteFile()
 		delete xml; // might make debugging harder!
 		break;
 	default:
-		delete xml;
 		return;
 	}
 
 	// upload it to the specified URL
-	KURL src( m_output->name() );
-	KIO::FileCopyJob *job = KIO::file_move( src, dest, -1, true, false, false );
-	connect( job, SIGNAL( result( KIO::Job * ) ),
-			SLOT(  slotUploadJobResult( KIO::Job * ) ) );
+	KUrl src( m_output->fileName() );
+	KIO::FileCopyJob *job = KIO::file_move( src, dest, -1, KIO::Overwrite | KIO::HideProgressInfo );
+	connect( job, SIGNAL( result( KJob * ) ),
+			SLOT(  slotUploadJobResult( KJob * ) ) );
 }
 
-void WebPresencePlugin::slotUploadJobResult( KIO::Job *job )
+void WebPresencePlugin::slotUploadJobResult( KJob *job )
 {
 	if ( job->error() ) {
-		kdDebug(14309) << "Error uploading presence info." << endl;
+		kDebug(14309) << "Error uploading presence info.";
 		KMessageBox::queuedDetailedError( 0, i18n("An error occurred when uploading your presence page.\nCheck the path and write permissions of the destination."), 0, displayName() );
 		delete m_output;
 		m_output = 0L;
 	}
 }
 
-KTempFile* WebPresencePlugin::generateFile()
+KTemporaryFile* WebPresencePlugin::generateFile()
 {
-	// generate the (temporary) XML file representing the current contactlist
-	kdDebug( 14309 ) << k_funcinfo << endl;
+	// generate the (temporary) XML file representing the current contact list
+	kDebug( 14309 ) ;
 	QString notKnown = i18n( "Not yet known" );
 
 	QDomDocument doc;
@@ -228,7 +229,7 @@ KTempFile* WebPresencePlugin::generateFile()
 
 	// insert the current date/time
 	QDomElement date = doc.createElement( "listdate" );
-	QDomText t = doc.createTextNode( 
+	QDomText t = doc.createTextNode(
 			KGlobal::locale()->formatDateTime( QDateTime::currentDateTime() ) );
 	date.appendChild( t );
 	root.appendChild( date );
@@ -247,13 +248,11 @@ KTempFile* WebPresencePlugin::generateFile()
 	QDomElement accounts = doc.createElement( "accounts" );
 	root.appendChild( accounts );
 
-	QPtrList<Kopete::Account> list = Kopete::AccountManager::self()->accounts();
+	QList<Kopete::Account*> list = Kopete::AccountManager::self()->accounts();
 	// If no accounts, stop here
 	if ( !list.isEmpty() )
 	{
-		for( QPtrListIterator<Kopete::Account> it( list );
-			 Kopete::Account *account=it.current();
-			 ++it )
+		foreach(Kopete::Account *account, list)
 		{
 			QDomElement acc = doc.createElement( "account" );
 			//output += h.openTag( "account" );
@@ -279,7 +278,7 @@ KTempFile* WebPresencePlugin::generateFile()
 					: notKnown ) ;
 			accStatus.appendChild( statusText );
 
-			// Dont add these if we're shutting down, because the result
+			// Do not add these if we're shutting down, because the result
 			// would be quite weird.
 			if ( !shuttingDown ) {
 
@@ -313,15 +312,16 @@ KTempFile* WebPresencePlugin::generateFile()
 	}
 
 	// write the XML to a temporary file
-	KTempFile* file = new KTempFile();
-	QTextStream *stream = file->textStream();
-	stream->setEncoding( QTextStream::UnicodeUTF8 );
-	doc.save( *stream, 4 );
-	file->close();
+	KTemporaryFile* file = new KTemporaryFile();
+	file->setAutoRemove(false);
+	QTextStream stream ( file );
+	stream.setCodec(QTextCodec::codecForName("UTF-8"));
+	doc.save( stream, 4 );
+	stream.flush();
 	return file;
 }
 
-bool WebPresencePlugin::transform( KTempFile * src, KTempFile * dest )
+bool WebPresencePlugin::transform( KTemporaryFile * src, KTemporaryFile * dest )
 {
 #ifdef HAVE_XSLT
 	bool retval = true;
@@ -336,20 +336,20 @@ bool WebPresencePlugin::transform( KTempFile * src, KTempFile * dest )
 		return false;
 	case WEB_HTML:
 		if ( useImagesInHTML ) {
-			sheet.setName( locate( "appdata", "webpresence/webpresence_html_images.xsl" ) );
+			sheet.setFileName( KStandardDirs::locate( "appdata", "webpresence/webpresence_html_images.xsl" ) );
 		} else {
-			sheet.setName( locate( "appdata", "webpresence/webpresence_html.xsl" ) );
+			sheet.setFileName( KStandardDirs::locate( "appdata", "webpresence/webpresence_html.xsl" ) );
 		}
 		break;
 	case WEB_XHTML:
 		if ( useImagesInHTML ) {
-			sheet.setName( locate( "appdata", "webpresence/webpresence_xhtml_images.xsl" ) );
+			sheet.setFileName( KStandardDirs::locate( "appdata", "webpresence/webpresence_xhtml_images.xsl" ) );
 		} else {
-			sheet.setName( locate( "appdata", "webpresence/webpresence_xhtml.xsl" ) );
+			sheet.setFileName( KStandardDirs::locate( "appdata", "webpresence/webpresence_xhtml.xsl" ) );
 		}
 		break;
 	case WEB_CUSTOM:
-		sheet.setName( userStyleSheet );
+		sheet.setFileName( userStyleSheet );
 		break;
 	default:
 		// Shouldn't ever reach here.
@@ -362,35 +362,36 @@ bool WebPresencePlugin::transform( KTempFile * src, KTempFile * dest )
 	xmlDocPtr res = 0;
 
 	if ( !sheet.exists() ) {
-		kdDebug(14309) << k_funcinfo << "ERROR: Style sheet not found" << endl;
+		kDebug(14309) << "ERROR: Style sheet not found";
 		retval = false;
 		goto end;
 	}
 
 	// is the cast safe?
-	cur = xsltParseStylesheetFile( (const xmlChar *) sheet.name().latin1() );
+	cur = xsltParseStylesheetFile( (const xmlChar *) sheet.fileName().toLatin1().data() );
 	if ( !cur ) {
-		kdDebug(14309) << k_funcinfo << "ERROR: Style sheet parsing failed" << endl;
+		kDebug(14309) << "ERROR: Style sheet parsing failed";
 		retval = false;
 		goto end;
 	}
 
-	doc = xmlParseFile( QFile::encodeName( src->name() ) );
+	doc = xmlParseFile( QFile::encodeName( src->fileName() ) );
 	if ( !doc ) {
-		kdDebug(14309) << k_funcinfo << "ERROR: XML parsing failed" << endl;
+		kDebug(14309) << "ERROR: XML parsing failed";
 		retval = false;
 		goto end;
 	}
 
 	res = xsltApplyStylesheet( cur, doc, 0 );
 	if ( !res ) {
-		kdDebug(14309) << k_funcinfo << "ERROR: Style sheet apply failed" << endl;
+		kDebug(14309) << "ERROR: Style sheet apply failed";
 		retval = false;
 		goto end;
 	}
 
-	if ( xsltSaveResultToFile(dest->fstream(), res, cur) == -1 ) {
-		kdDebug(14309) << k_funcinfo << "ERROR: Style sheet apply failed" << endl;
+
+	if ( xsltSaveResultToFd(dest->handle(), res, cur) == -1 ) {
+		kDebug(14309) << "ERROR: Style sheet apply failed";
 		retval = false;
 		goto end;
 	}
@@ -417,7 +418,7 @@ end:
 
 ProtocolList WebPresencePlugin::allProtocols()
 {
-	kdDebug( 14309 ) << k_funcinfo << endl;
+	kDebug( 14309 ) ;
 
 	Kopete::PluginList plugins = Kopete::PluginManager::self()->loadedPlugins( "Protocols" );
 	Kopete::PluginList::ConstIterator it;
@@ -458,7 +459,7 @@ QString WebPresencePlugin::statusAsString( const Kopete::OnlineStatus &newStatus
 
 void WebPresencePlugin::aboutToUnload()
 {
-	// Stop timer. Dont need it anymore.
+	// Stop timer. Do not need it anymore.
 	m_writeScheduler->stop();
 
 	// Force statusAsString() report all accounts as OFFLINE.
