@@ -1,12 +1,13 @@
 /*
     gwaccount.h - Kopete GroupWise Protocol
 
+    Copyright (c) 2006,2007 Novell, Inc	 	 	 http://www.opensuse.org
     Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
 
     Based on Testbed
-    Copyright (c) 2003      by Will Stephenson		 <will@stevello.free-online.co.uk>
+    Copyright (c) 2003-2007 by Will Stephenson		 <wstephenson@kde.org>
 
-    Kopete    (c) 2002-2003 by the Kopete developers <kopete-devel@kde.org>
+    Kopete    (c) 2002-2007 by the Kopete developers <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -21,18 +22,22 @@
 #ifndef GW_ACCOUNT_H
 #define GW_ACCOUNT_H
 
+#include <QtCrypto>
+
 #include <kaction.h>
 
 #include <kopetechatsessionmanager.h>
+#include <kopetecontact.h>
 
 #include "gwerror.h"
 
-#include <managedconnectionaccount.h>
+#include <kopetepasswordedaccount.h>
+//Added by qt3to4:
+#include <Q3ValueList>
 
 class KActionMenu;
 
 namespace Kopete {
-	class Contact;
 	class Group;
 	class MetaContact; 
 }
@@ -54,7 +59,7 @@ using namespace GroupWise;
 /**
  * This represents an account on a Novell GroupWise Messenger Server
  */
-class GroupWiseAccount : public Kopete::ManagedConnectionAccount
+class GroupWiseAccount : public Kopete::PasswordedAccount
 {
 	Q_OBJECT
 public:
@@ -64,7 +69,7 @@ public:
 	/**
 	 * Construct the context menu used for the status bar icon
 	 */
-	virtual KActionMenu* actionMenu();
+	virtual void fillActionMenu( KActionMenu *actionMenu );
 
 	// DEBUG ONLY
 	void dumpManagers();
@@ -146,14 +151,19 @@ public slots:
 	void slotTestRTFize();
 
 	/* Connects to the server. */
-	void performConnectWithPassword ( const QString &password );
+	void connectWithPassword ( const QString &password );
 
 	/* Disconnects from the server. */
 	virtual void disconnect();
 	virtual void disconnect( Kopete::Account::DisconnectReason reason );
 
 	/** Set the online status for the account. Reimplemented from Kopete::Account */
-	void setOnlineStatus( const Kopete::OnlineStatus& status , const QString &reason = QString::null);
+	void setOnlineStatus( const Kopete::OnlineStatus& status , const Kopete::StatusMessage &reason = Kopete::StatusMessage() );
+	/**
+	 * Set the status message for the account. Reimplemented from Kopete::Account
+	 */
+	void setStatusMessage( const Kopete::StatusMessage &statusMessage );
+
 signals:
 	void conferenceCreated( const int mmId, const GroupWise::ConferenceGuid & guid );
 	void conferenceCreationFailed( const int mmId, const int statusCode );
@@ -201,7 +211,7 @@ protected slots:
 	void receiveContact( const ContactItem & );
 	/**
 	 * Called when we receive a CONTACT'S METADATA (including initial status) from the server side contact list,
-	 * or in response to an explicity query.  This is necessary to handle some events from the server.
+	 * or in response to an explicitly query.  This is necessary to handle some events from the server.
 	 * These events are queued in the account until the data arrives and then we handle the event.
 	 */
 	void receiveContactUserDetails( const GroupWise::ContactDetails & );
@@ -224,7 +234,7 @@ protected slots:
 	/**
 	 * A contact changed status
 	 */
-	void receiveStatus( const QString &, Q_UINT16, const QString & );
+	void receiveStatus( const QString &, quint16, const QString & );
 	/**
 	 * Our status changed on the server
 	 */
@@ -306,9 +316,10 @@ protected:
 	/**
 	 * Sends a status message to the server - called by the status specific slotGoAway etc
 	 */
-	//void setStatus( GroupWise::Status status, const QString & reason = QString::null );
+	//void setStatus( GroupWise::Status status, const QString & reason = QString() );
 
-	int handleTLSWarning (int warning, QString server, QString accountId);
+	int handleTLSWarning (QCA::TLS::IdentityResult identityResult,
+		QCA::Validity validityResult, QString server, QString accountId);
 
 	GroupWiseChatSession * findChatSessionByGuid( const GroupWise::ConferenceGuid & guid );
 	/**
@@ -321,20 +332,21 @@ protected:
 	void cleanup();
 private:
 	// action menu and its actions
-	KActionMenu * m_actionMenu;
 	KAction * m_actionAutoReply;
 	KAction * m_actionManagePrivacy;
 	KAction * m_actionJoinChatRoom;
 	// Network code
 	KNetworkConnector * m_connector;
+	QCA::Initializer * m_qcaInit;
 	QCA::TLS * m_QCATLS;
 	QCATLSHandler *	m_tlsHandler;
 	ClientStream * m_clientStream;
 	// Client, entry point of libgroupwise
 	Client * m_client;
 
+	QString m_password;
 	QString m_initialReason;
-	QValueList<GroupWiseChatSession*> m_chatSessions;
+	Q3ValueList<GroupWiseChatSession*> m_chatSessions;
 	bool m_dontSync;
 	GWContactList * m_serverListModel;
 };
@@ -347,7 +359,7 @@ private:
 {
 	Q_OBJECT
   public:
-	OnlineStatusMessageAction ( const Kopete::OnlineStatus& status, const QString &text, const QString &message, const QIconSet &pix, QObject *parent=0, const char *name=0);
+	OnlineStatusMessageAction ( const Kopete::OnlineStatus& status, const QString &text, const QString &message, const QIcon &pix, QObject *parent=0, const char *name=0);
   signals:
 	void activated( const Kopete::OnlineStatus& status, const QString & );
   private slots:
