@@ -1,25 +1,38 @@
-//
-// C++ Implementation: gwmessagemanager
-//
-// Description: 
-//
-//
-// Author: SUSE AG <>, (C) 2004
-//
-// Copyright: See COPYING file that comes with this distribution
-//
-//
+/*
+    gwmessagemanager.cpp - Kopete GroupWise Protocol
+
+    Copyright (c) 2006,2007 Novell, Inc	 	 	 http://www.opensuse.org
+    Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
+
+    Based on Testbed
+    Copyright (c) 2003-2007 by Will Stephenson		 <wstephenson@kde.org>
+
+    Kopete    (c) 2002-2007 by the Kopete developers <kopete-devel@kde.org>
+
+    *************************************************************************
+    *                                                                       *
+    * This library is free software; you can redistribute it and/or         *
+    * modify it under the terms of the GNU General Public                   *
+    * License as published by the Free Software Foundation; either          *
+    * version 2 of the License, or (at your option) any later version.      *
+    *                                                                       *
+    *************************************************************************
+*/
 
 #include <qlabel.h>
 #include <qvalidator.h>
+#include <QList>
+#include <QPainter>
+
+#include <kactioncollection.h>
+#include <kactionmenu.h>
 #include <kdebug.h>
-#include <kdialogbase.h>
 #include <kiconloader.h>
 #include <kinputdialog.h>
 #include <klocale.h>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 #include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kshortcut.h>
 
 #include <kopetecontact.h>
@@ -39,47 +52,51 @@
 
 #include "gwmessagemanager.h"
 
-GroupWiseChatSession::GroupWiseChatSession(const Kopete::Contact* user, Kopete::ContactPtrList others, Kopete::Protocol* protocol, const GroupWise::ConferenceGuid & guid, int id, const char* name): Kopete::ChatSession(user, others, protocol, name), m_guid( guid ), m_flags( 0 ), m_searchDlg( 0 ), m_memberCount( others.count() )
+GroupWiseChatSession::GroupWiseChatSession(const Kopete::Contact* user, Kopete::ContactPtrList others, Kopete::Protocol* protocol, const GroupWise::ConferenceGuid & guid, int id ): Kopete::ChatSession( user, others, protocol ), m_guid( guid ), m_flags( 0 ), m_searchDlg( 0 ), m_memberCount( others.count() )
 {
 	Q_UNUSED( id );
 	static uint s_id=0;
 	m_mmId=++s_id;
-	
-	kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << "New message manager for " << user->contactId() << endl;
+
+	kDebug () << "New message manager for " << user->contactId();
 
 	// Needed because this is (indirectly) a KXMLGuiClient, so it can find the gui description .rc file
-	setInstance( protocol->instance() );
-	
+	setComponentData( protocol->componentData() );
+
 	// make sure Kopete knows about this instance
 	Kopete::ChatSessionManager::self()->registerChatSession ( this );
 
 	connect ( this, SIGNAL( messageSent ( Kopete::Message &, Kopete::ChatSession * ) ),
 			  SLOT( slotMessageSent ( Kopete::Message &, Kopete::ChatSession * ) ) );
 	connect( this, SIGNAL( myselfTyping ( bool ) ), SLOT( slotSendTypingNotification ( bool ) ) );
-	connect( account(), SIGNAL( contactTyping( const ConferenceEvent & ) ), 
+	connect( account(), SIGNAL( contactTyping( const ConferenceEvent & ) ),
 						SLOT( slotGotTypingNotification( const ConferenceEvent & ) ) );
-	connect( account(), SIGNAL( contactNotTyping( const ConferenceEvent & ) ), 
+	connect( account(), SIGNAL( contactNotTyping( const ConferenceEvent & ) ),
 						SLOT( slotGotNotTypingNotification( const ConferenceEvent & ) ) );
-	
+
 	// Set up the Invite menu
-	m_actionInvite = new KActionMenu( i18n( "&Invite" ), actionCollection() , "gwInvite" );
-	connect( m_actionInvite->popupMenu(), SIGNAL( aboutToShow() ), this, SLOT(slotActionInviteAboutToShow() ) ) ;
-	
-	m_secure = new KAction( i18n( "Security Status" ), "encrypted", KShortcut(), this, SLOT( slotShowSecurity() ), actionCollection(), "gwSecureChat" );
+	m_actionInvite = new KActionMenu( i18n( "&Invite" ), this );
+	actionCollection()->addAction( "gwInvite", m_actionInvite );
+	connect( m_actionInvite->menu(), SIGNAL( aboutToShow() ), this, SLOT(slotActionInviteAboutToShow() ) ) ;
+
+	m_secure = new KAction( KIcon( "security-high" ), i18n( "Security Status" ), 0 ); // "gwSecureChat"
+	QObject::connect( m_secure, SIGNAL( triggered( bool ) ), SLOT( slotShowSecurity() ) );
 	m_secure->setToolTip( i18n( "Conversation is secure" ) );
-	
-	m_logging = new KAction( i18n( "Archiving Status" ), "logchat", KShortcut(), this, SLOT( slotShowArchiving() ), actionCollection(), "gwLoggingChat" );
+
+	m_logging = new KAction( KIcon( "utilities-log-viewer" ), i18n( "Archiving Status" ), 0 ); // "gwLoggingChat"
+	QObject::connect( m_secure, SIGNAL( triggered( bool ) ),  SLOT( slotShowArchiving() ) );
 	updateArchiving();
-	
+
 	setXMLFile("gwchatui.rc");
 	setMayInvite( true );
-
-	m_invitees.setAutoDelete( true );
 }
 
 GroupWiseChatSession::~GroupWiseChatSession()
 {
+	qDeleteAll(m_inviteActions);
 	emit leavingConference( this );
+	foreach (Kopete::Contact * contact, m_invitees )
+		delete contact;
 }
 
 uint GroupWiseChatSession::mmId() const
@@ -91,11 +108,11 @@ void GroupWiseChatSession::setGuid( const GroupWise::ConferenceGuid & guid )
 {
 	if ( m_guid.isEmpty() )
 	{
-		kdDebug( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << "setting GUID to: " << guid << endl;
+		kDebug() << "setting GUID to: " << guid;
 		m_guid = guid;
 	}
 	else
-		kdDebug( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << "attempted to change the conference's GUID when already set!" << endl;
+		kDebug() << "attempted to change the conference's GUID when already set!";
 }
 
 bool GroupWiseChatSession::closed()
@@ -115,8 +132,8 @@ bool GroupWiseChatSession::secure()
 
 void GroupWiseChatSession::setClosed()
 {
-	kdDebug( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << " Conference " << m_guid << " is now Closed " << endl;
-	m_guid = QString::null;
+	kDebug() << " Conference " << m_guid << " is now Closed ";
+	m_guid.clear();
 	m_flags = m_flags | GroupWise::Closed;
 }
 
@@ -145,44 +162,38 @@ void GroupWiseChatSession::createConference()
 {
 	if ( m_guid.isEmpty() )
 	{
-		kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << endl;
+		kDebug () ;
 		// form a list of invitees
 		QStringList invitees;
-		Kopete::ContactPtrList chatMembers = members();
-		for ( Kopete::Contact * contact = chatMembers.first(); contact; contact = chatMembers.next() )
+		foreach ( Kopete::Contact * contact, members() )
 		{
 			invitees.append( static_cast< GroupWiseContact * >( contact )->dn() );
 		}
 		// this is where we will set the GUID and send any pending messages
 		connect( account(), SIGNAL( conferenceCreated( const int, const GroupWise::ConferenceGuid & ) ), SLOT( receiveGuid( const int, const GroupWise::ConferenceGuid & ) ) );
 		connect( account(), SIGNAL( conferenceCreationFailed( const int, const int ) ), SLOT( slotCreationFailed( const int, const int ) ) );
-		
+
 		// create the conference
 		account()->createConference( mmId(), invitees );
 	}
 	else
-		kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << " tried to create conference on the server when it was already instantiated" << endl;
+		kDebug () << " tried to create conference on the server when it was already instantiated";
 }
 
 void GroupWiseChatSession::receiveGuid( const int newMmId, const GroupWise::ConferenceGuid & guid )
 {
 	if ( newMmId == mmId() )
 	{
-		kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << " got GUID from server" << endl;
+		kDebug () << " got GUID from server";
 		m_memberCount = members().count();
 		setGuid( guid );
-		// re-add all the members.  This is because when the last member leaves the conference, 
+		// re-add all the members.  This is because when the last member leaves the conference,
 		// they are removed from the chat member list GUI.  By re-adding them here, we guarantee they appear
 		// in the UI again, at the price of a debug message when starting up a new chatwindow
-		
-		QPtrListIterator< Kopete::Contact > it( members() );
-		Kopete::Contact * contact;
-		while ( ( contact = it.current() ) )
-		{
-			++it;
+
+		foreach( Kopete::Contact * contact, members() )
 			addContact( contact, true );
-		}
-		
+
 		// notify the contact(s) using this message manager that it's been instantiated on the server
 		emit conferenceCreated();
 		// TODO: send invitations if we're not inviting in the conf create...
@@ -194,9 +205,10 @@ void GroupWiseChatSession::slotCreationFailed( const int failedId, const int sta
 {
 	if ( failedId == mmId() )
 	{
-		kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << " couldn't start a chat, no GUID.\n" << endl;
+		kDebug () << " couldn't start a chat, no GUID.\n";
 		//emit creationFailed();
-		Kopete::Message failureNotify = Kopete::Message( myself(), members(), i18n("An error occurred when trying to start a chat: %1").arg( statusCode ), Kopete::Message::Internal, Kopete::Message::PlainText);
+		Kopete::Message failureNotify( myself(), members());
+		failureNotify.setPlainBody( i18n("An error occurred when trying to start a chat: %1", statusCode ) );
 		appendMessage( failureNotify );
 		setClosed();
 	}
@@ -212,7 +224,7 @@ void GroupWiseChatSession::slotSendTypingNotification( bool typing )
 
 void GroupWiseChatSession::slotMessageSent( Kopete::Message & message, Kopete::ChatSession * )
 {
-	kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << endl;
+	kDebug () ;
 	if( account()->isConnected() )
 	{
 		/*if ( closed() )
@@ -223,7 +235,8 @@ void GroupWiseChatSession::slotMessageSent( Kopete::Message & message, Kopete::C
 		}
 		else*/ if ( account()->myself()->onlineStatus() == ( static_cast<GroupWiseProtocol *>( protocol() ) )->groupwiseAppearOffline )
 		{
-			Kopete::Message failureNotify = Kopete::Message( myself(), members(), i18n("Your message could not be sent. You cannot send messages while your status is Appear Offline. "), Kopete::Message::Internal, Kopete::Message::PlainText);
+			Kopete::Message failureNotify( myself(), members() );
+			failureNotify.setPlainBody( i18n("Your message could not be sent. You cannot send messages while your status is Appear Offline. ") );
 			appendMessage( failureNotify );
 			messageSucceeded();
 		}
@@ -232,27 +245,27 @@ void GroupWiseChatSession::slotMessageSent( Kopete::Message & message, Kopete::C
 			// if the conference has not been instantiated yet, or if all the members have left
 			if ( m_guid.isEmpty() || m_memberCount == 0 )
 			{
-				// if there are still invitees, the conference is instantiated, and there are only 
+				// if there are still invitees, the conference is instantiated, and there are only
 				if ( m_invitees.count() )
 				{
-					// the message won't go anywhere, as there's noone there except invitees, but we warn the user
+					// the message won't go anywhere, as there's none there except invitees, but we warn the user
 					// when the last participant leaves.
 					messageSucceeded();
 				}
 				else
 				{
-					kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << "waiting for server to create a conference, queuing message" << endl;
+					kDebug () << "waiting for server to create a conference, queuing message";
 					// the conference hasn't been instantiated on the server yet, so queue the message
 					m_guid = ConferenceGuid();
 					createConference();
 					m_pendingOutgoingMessages.append( message );
 				}
 			}
-			else 
+			else
 			{
-				kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << "sending message" << endl;
+				kDebug () << "sending message";
 				account()->sendMessage( guid(), message );
-				// we could wait until the server acks our send, 
+				// we could wait until the server acks our send,
 				// but we'd need a UID for outgoing messages and a list to track them
 				appendMessage( message );
 				messageSucceeded();
@@ -275,21 +288,17 @@ void GroupWiseChatSession::slotGotNotTypingNotification( const ConferenceEvent&
 
 void GroupWiseChatSession::dequeueMessagesAndInvites()
 {
-	kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << endl;
-	for ( QValueListIterator< Kopete::Message > it = m_pendingOutgoingMessages.begin();
+	kDebug () ;
+	for ( QList< Kopete::Message >::Iterator it = m_pendingOutgoingMessages.begin();
 		  it != m_pendingOutgoingMessages.end();
 		  ++it )
 	{
 		slotMessageSent( *it, this );
 	}
 	m_pendingOutgoingMessages.clear();
-	QPtrListIterator< Kopete::Contact > it( m_pendingInvites );
-	Kopete::Contact * contact;
-	while ( ( contact = it.current() ) )
-	{
-		++it;
+
+	foreach( Kopete::Contact * contact, m_pendingInvites )
 		slotInviteContact( contact );
-	}
 	m_pendingInvites.clear();
 }
 
@@ -298,26 +307,30 @@ void GroupWiseChatSession::slotActionInviteAboutToShow()
 	// We can't simply insert  KAction in this menu bebause we don't know when to delete them.
 	//  items inserted with insert items are automatically deleted when we call clear
 
-	m_inviteActions.setAutoDelete(true);
+	qDeleteAll(m_inviteActions);
 	m_inviteActions.clear();
 
-	m_actionInvite->popupMenu()->clear();
+	m_actionInvite->menu()->clear();
 
-	
-	QDictIterator<Kopete::Contact> it( account()->contacts() );
-	for( ; it.current(); ++it )
+
+	foreach( Kopete::Contact * contact, account()->contacts() )
 	{
-		if( !members().contains( it.current() ) && it.current()->isOnline() && it.current() != myself() )
+		if( !members().contains( contact ) && contact->isOnline() && contact != myself() )
 		{
-			KAction *a=new KopeteContactAction( it.current(), this,
-				SLOT( slotInviteContact( Kopete::Contact * ) ), m_actionInvite );
-			m_actionInvite->insert( a );
+			KAction *a = new Kopete::UI::ContactAction( contact,
+			                                            actionCollection() );
+			m_actionInvite->addAction( a );
+			QObject::connect( a, SIGNAL(triggered(Kopete::Contact*,bool)),
+					this, SLOT(slotInviteContact(Kopete::Contact*)) );
 			m_inviteActions.append( a ) ;
 		}
 	}
 	// Invite someone off-list
-	KAction *b=new KAction( i18n ("&Other..."), 0, this, SLOT( slotInviteOtherContact() ), m_actionInvite, "actionOther" );
-	m_actionInvite->insert( b );
+	KAction *b = new KAction( i18n("&Other..."), this );
+	actionCollection()->addAction( "actionOther", b );
+	QObject::connect( b, SIGNAL( triggered( bool ) ),
+	                  this, SLOT( slotInviteOtherContact() ) );
+	m_actionInvite->addAction( b );
 	m_inviteActions.append( b ) ;
 }
 
@@ -331,15 +344,14 @@ void GroupWiseChatSession::slotInviteContact( Kopete::Contact * contact )
 	else
 	{
 		QWidget * w = view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) : 0L;
-		
+
 		bool ok;
 		QRegExp rx( ".*" );
 		QRegExpValidator validator( rx, this );
 		QString inviteMessage = KInputDialog::getText( i18n( "Enter Invitation Message" ),
-		    i18n( "Enter the reason for the invitation, or leave blank for no reason:" ), QString(),
-				&ok, w ? w : Kopete::UI::Global::mainWidget(), "invitemessagedlg", &validator );
+		    i18n( "Enter the reason for the invitation, or leave blank for no reason:" ), QString(), &ok, w ? w : Kopete::UI::Global::mainWidget(), &validator );
 		if ( ok )
-		{	
+		{
 			GroupWiseContact * gwc = static_cast< GroupWiseContact *>( contact );
 			static_cast< GroupWiseAccount * >(account())->sendInvitation( m_guid, gwc->dn(), inviteMessage );
 		}
@@ -358,13 +370,16 @@ void GroupWiseChatSession::slotInviteOtherContact()
 	if ( !m_searchDlg )
 	{
 		// show search dialog
-		QWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) : 
+		QWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
 					Kopete::UI::Global::mainWidget() );
-		m_searchDlg = new KDialogBase( w, "invitesearchdialog", false, i18n( "Search for Contact to Invite" ), KDialogBase::Ok|KDialogBase::Cancel );
-		m_search = new GroupWiseSearch( account(), QListView::Single, true, m_searchDlg, "invitesearchwidget" );
+		m_searchDlg = new KDialog( w);
+		m_searchDlg->setCaption(i18n( "Search for Contact to Invite" ));
+		m_searchDlg->setButtons(KDialog::Ok|KDialog::Cancel );
+		m_searchDlg->setDefaultButton(KDialog::Ok);
+		m_search = new GroupWiseContactSearch( account(), QAbstractItemView::SingleSelection, true, m_searchDlg );
 		m_searchDlg->setMainWidget( m_search );
-		connect( m_search, SIGNAL( selectionValidates( bool ) ), m_searchDlg, SLOT( enableButtonOK( bool ) ) );
-		m_searchDlg->enableButtonOK( false );
+		connect( m_search, SIGNAL( selectionValidates( bool ) ), m_searchDlg, SLOT( enableButtonOk( bool ) ) );
+		m_searchDlg->enableButtonOk( false );
 	}
 	m_searchDlg->show();
 }
@@ -372,20 +387,19 @@ void GroupWiseChatSession::slotInviteOtherContact()
 void GroupWiseChatSession::slotSearchedForUsers()
 {
 	// create an item for each result, in the block list
-	QValueList< ContactDetails > selected = m_search->selectedResults();
+	Q3ValueList< ContactDetails > selected = m_search->selectedResults();
 	if ( selected.count() )
 	{
 		QWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
-				Kopete::UI::Global::mainWidget() ); 
+				Kopete::UI::Global::mainWidget() );
 		ContactDetails cd = selected.first();
 		bool ok;
 		QRegExp rx( ".*" );
 		QRegExpValidator validator( rx, this );
 		QString inviteMessage = KInputDialog::getText( i18n( "Enter Invitation Message" ),
-		    i18n( "Enter the reason for the invitation, or leave blank for no reason:" ), QString(),
-				&ok, w , "invitemessagedlg", &validator );
+		    i18n( "Enter the reason for the invitation, or leave blank for no reason:" ), QString(), &ok, w, &validator );
 		if ( ok )
-		{	
+		{
 			account()->sendInvitation( m_guid, cd.dn, inviteMessage );
 		}
 	}
@@ -394,11 +408,11 @@ void GroupWiseChatSession::slotSearchedForUsers()
 void GroupWiseChatSession::addInvitee( const Kopete::Contact * c )
 {
 	// create a placeholder contact for each invitee
-	kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << endl;
-	QString pending = i18n("label attached to contacts who have been invited but are yet to join a chat", "(pending)");
+	kDebug () ;
+	QString pending = i18nc("label attached to contacts who have been invited but are yet to join a chat", "(pending)");
 	Kopete::MetaContact * inviteeMC = new Kopete::MetaContact();
 	inviteeMC->setDisplayName( c->metaContact()->displayName() + pending );
-	GroupWiseContact * invitee = new GroupWiseContact( account(), c->contactId() + " " + pending, inviteeMC, 0, 0, 0 );
+	GroupWiseContact * invitee = new GroupWiseContact( account(), c->contactId() + ' ' + pending, inviteeMC, 0, 0, 0 );
 	invitee->setOnlineStatus( c->onlineStatus() );
 	// TODO: we could set all the placeholder's properties etc here too
 	addContact( invitee, true );
@@ -407,43 +421,43 @@ void GroupWiseChatSession::addInvitee( const Kopete::Contact * c )
 
 void GroupWiseChatSession::joined( GroupWiseContact * c )
 {
-	// we add the real contact before removing the placeholder, 
+	// we add the real contact before removing the placeholder,
 	// because otherwise KMM will delete itself when the last member leaves.
 	addContact( c );
 
 	// look for the invitee and remove it
-	Kopete::Contact * pending;
-	for ( pending = m_invitees.first(); pending; pending = m_invitees.next() )
+	Kopete::Contact * pending = 0;
+	foreach( pending, m_invitees )
 	{
 		if ( pending->contactId().startsWith( c->contactId() ) )
 		{
-			removeContact( pending, QString::null, Kopete::Message::PlainText, true );
+			removeContact( pending, QString(), Qt::PlainText, true );
 			break;
 		}
 	}
 
-	m_invitees.remove( pending );
+	m_invitees.removeAll( pending );
+	delete pending;
 
 	updateArchiving();
-	
+
 	++m_memberCount;
 }
 
 void GroupWiseChatSession::left( GroupWiseContact * c )
 {
-	kdDebug( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << endl;
+	kDebug() ;
 	removeContact( c );
 	--m_memberCount;
-	
+
 	updateArchiving();
-	
+
 	if ( m_memberCount == 0 )
 	{
 		if ( m_invitees.count() )
 		{
-			Kopete::Message failureNotify = Kopete::Message( myself(), members(), 
-						i18n("All the other participants have left, and other invitations are still pending. Your messages will not be delivered until someone else joins the chat."), 
-						Kopete::Message::Internal, Kopete::Message::PlainText );
+			Kopete::Message failureNotify( myself(), members() );
+			failureNotify.setPlainBody( i18n("All the other participants have left, and other invitations are still pending. Your messages will not be delivered until someone else joins the chat.") );
 			appendMessage( failureNotify );
 		}
 		else
@@ -454,33 +468,31 @@ void GroupWiseChatSession::left( GroupWiseContact * c )
 void GroupWiseChatSession::inviteDeclined( GroupWiseContact * c )
 {
 	// look for the invitee and remove it
-	Kopete::Contact * pending;
-	for ( pending = m_invitees.first(); pending; pending = m_invitees.next() )
+	Kopete::Contact * pending = 0;
+	foreach( pending, m_invitees )
 	{
 		if ( pending->contactId().startsWith( c->contactId() ) )
 		{
-			removeContact( pending, QString::null, Kopete::Message::PlainText, true );
+			removeContact( pending, QString(), Qt::PlainText, true );
 			break;
 		}
 	}
-	m_invitees.remove( pending );
-	
+	m_invitees.removeAll( pending );
+	delete pending;
+
 	QString from = c->metaContact()->displayName();
 
-	Kopete::Message declined = Kopete::Message( myself(), members(), 
-				i18n("%1 has rejected an invitation to join this conversation.").arg( from ), 
-				Kopete::Message::Internal, Kopete::Message::PlainText );
+	Kopete::Message declined( myself(), members() );
+	declined.setPlainBody( i18n("%1 has rejected an invitation to join this conversation.", from ) );
 	appendMessage( declined );
 }
 
 void GroupWiseChatSession::updateArchiving()
 {
 	bool archiving = false;
-	QPtrListIterator< Kopete::Contact > it( members() );
-	GroupWiseContact * contact;
-	while ( ( contact = static_cast<GroupWiseContact*>( it.current() ) ) )
+	foreach( Kopete::Contact * c, members() )
 	{
-		++it;
+		GroupWiseContact * contact = static_cast<GroupWiseContact*>( c );
 		if ( contact->archiving() )
 		{
 			archiving = true;
@@ -502,14 +514,14 @@ void GroupWiseChatSession::updateArchiving()
 void GroupWiseChatSession::slotShowSecurity()
 {
 	QWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
-				Kopete::UI::Global::mainWidget() ); 
+				Kopete::UI::Global::mainWidget() );
 	KMessageBox::queuedMessageBox( w, KMessageBox::Information, i18n( "This conversation is secured with SSL security." ), i18n("Security Status" ) );
 }
 
 void GroupWiseChatSession::slotShowArchiving()
 {
 	QWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
-				Kopete::UI::Global::mainWidget() ); 
+				Kopete::UI::Global::mainWidget() );
 	KMessageBox::queuedMessageBox( w, KMessageBox::Information, i18n( "This conversation is being logged administratively." ), i18n("Archiving Status" ) );
 }
 
