@@ -21,10 +21,13 @@
 #ifndef LIBGW_CLIENT_H
 #define LIBGW_CLIENT_H
 
-#include <qstring.h>
+
+#include <QByteArray>
+#include <QList>
 
 #include "gwclientstream.h"
 #include "gwerror.h"
+#include "libgroupwise_export.h"
 #include "rtf2html.h"
 #include "transfer.h"
 
@@ -36,7 +39,7 @@ class Task;
 
 using namespace GroupWise;
 
-class Client : public QObject
+class LIBGROUPWISE_EXPORT Client : public QObject
 {
 Q_OBJECT
 
@@ -46,7 +49,7 @@ Q_OBJECT
 		  EXTERNAL API 
 		 *************/
 		  
-		Client( QObject *parent = 0, uint protocolVersion = 2 );
+		explicit Client( QObject *parent = 0, uint protocolVersion = 2 );
 		~Client();
 		void setOSName( const QString &name );
 		void setClientName( const QString &s );
@@ -205,12 +208,12 @@ fd		 * @param password
 		/**
 		 * Host's IP address
 		 */
-		QCString ipAddress();
+		QByteArray ipAddress();
 
 		/**
 		 * Obtain the list of custom statuses stored on the server 
 		 */
-		QValueList<GroupWise::CustomStatus> customStatuses();
+		QList<GroupWise::CustomStatus> customStatuses();
 
 		/**
 		 * Get a reference to the RequestFactory for this Client. 
@@ -276,7 +279,7 @@ fd		 * @param password
 		/** 
 		 * A remote contact changed status
 		 */
-		void statusReceived( const QString & contactId, Q_UINT16 status, const QString & statusText );
+		void statusReceived( const QString & contactId, quint16 status, const QString & statusText );
 		/** 
 		 * Our status changed on the server
 		 */
@@ -304,7 +307,7 @@ fd		 * @param password
 		 */
 		void invitationReceived( const ConferenceEvent & );
 		/**
-		 * Someone joined a chat.  They may not be on our contact list if it is a group chat
+		 * Someone joined a chat.  They may not be on our contact list if it is a groupchat
 		 * and they were invited to join the chat prior to our being invited to join and joining
 		 */
 		void conferenceJoinNotifyReceived( const ConferenceEvent & );
@@ -351,6 +354,7 @@ fd		 * @param password
 		void systemBroadcastReceived ( const ConferenceEvent & );
 		/** CONTACT LIST MANAGEMENT EVENTS */
 		/** TBD! */
+        void messageSendingFailed();
 	protected:
 		/**
 		 * Instantiate all the event handling tasks
@@ -389,7 +393,8 @@ fd		 * @param password
 		 * sendout a 'ping' keepalive message so that the server does not disconnect us
 		 */
 		void sendKeepAlive();
-
+        void smt_messageSent();
+    
 	private:
 		void distribute( Transfer *transfer );
 		class ClientPrivate;
