@@ -1,6 +1,7 @@
 /*
     gwerror.h - Kopete Groupwise Protocol
   
+    Copyright (c) 2004-2007     Novell, Inc http://www.novell.com/linux
     Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
     
     Kopete (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
@@ -20,10 +21,11 @@
 
 #include <qdatetime.h>
 #include <qglobal.h>
-#include <qmap.h>
+#include <QMap>
+#include <QVariant>
 #include <qstring.h>
-
-typedef Q_UINT16 NMERR_T;
+#include "libgroupwise_export.h"
+typedef quint16 NMERR_T;
 #define GROUPWISE_DEBUG_GLOBAL 14190
 #define GROUPWISE_DEBUG_LIBGW 14191
 #define GROUPWISE_DEBUG_RAW 14192
@@ -31,7 +33,7 @@ typedef Q_UINT16 NMERR_T;
 #define BLANK_GUID "[00000000-00000000-00000000-0000-0000]"
 #define CONF_GUID_END 27
 
-//#define LIBGW_DEBUG 1
+#define LIBGW_DEBUG 1
 #define LIBGW_USE_KDEBUG 1
 
 namespace GroupWise
@@ -94,8 +96,10 @@ namespace GroupWise
 							Closed  = 0x10000000
 						 };
 	
+	QString LIBGROUPWISE_EXPORT errorCodeToString( int errorCode );
+	
 	// helpful structs used to pass data between the client library and the application using it
-	class ConferenceGuid : public QString 
+	class LIBGROUPWISE_EXPORT ConferenceGuid : public QString 
 	{
 	public:
 		ConferenceGuid();
@@ -103,9 +107,9 @@ namespace GroupWise
 		~ConferenceGuid();
 	};
 	
-	bool operator==( const ConferenceGuid & g1, const ConferenceGuid & g2 );
-	bool operator==( const QString & s, const ConferenceGuid & g );
-	bool operator==( const ConferenceGuid & g, const QString & s );
+	bool LIBGROUPWISE_EXPORT operator==( const ConferenceGuid & g1, const ConferenceGuid & g2 );
+	bool LIBGROUPWISE_EXPORT operator==( const QString & s, const ConferenceGuid & g );
+	bool LIBGROUPWISE_EXPORT operator==( const ConferenceGuid & g, const QString & s );
 	
 	struct ConferenceEvent 
 	{
@@ -113,7 +117,7 @@ namespace GroupWise
 		ConferenceGuid guid;
 		QString user;
 		QDateTime timeStamp;
-		Q_UINT32 flags;
+		quint32 flags;
 		QString message;
 	};
 	
@@ -136,16 +140,16 @@ namespace GroupWise
 
 	struct ContactDetails
 	{
-		QString cn, 
-				dn, 
-				givenName, 
-				surname, 
-				fullName, 
-				awayMessage, 
+		QString cn,
+				dn,
+				givenName,
+				surname,
+				fullName,
+				awayMessage,
 				authAttribute;
 		int status;
 		bool archive;
-		QMap< QString, QString > properties;
+		QMap< QString, QVariant > properties;
 	};
 
 	struct OutgoingMessage
@@ -157,7 +161,7 @@ namespace GroupWise
 
 	struct UserSearchQueryTerm
 	{
-		QString field;
+		QByteArray field;
 		QString argument;
 		int operation;
 	};
