@@ -2,6 +2,7 @@
     Kopete Groupwise Protocol
     logintask.cpp - Send our credentials to the server and process the contact list and privacy details that it returns.
 
+    Copyright (c) 2006      Novell, Inc	 	 	 http://www.opensuse.org
     Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
     
     Based on Iris, Copyright (C) 2003  Justin Karneges
@@ -24,6 +25,8 @@
 #include "userdetailsmanager.h"
 
 #include "logintask.h"
+//Added by qt3to4:
+#include <QByteArray>
 
 LoginTask::LoginTask( Task * parent )
  : RequestTask( parent )
@@ -39,11 +42,11 @@ void LoginTask::initialise()
 	QString command = QString::fromLatin1("login:%1:%2").arg( client()->host() ).arg( client()->port() );
 	
 	Field::FieldList lst;
-	lst.append( new Field::SingleField( NM_A_SZ_USERID, 0, NMFIELD_TYPE_UTF8, client()->userId() ) );
-	lst.append( new Field::SingleField( NM_A_SZ_CREDENTIALS, 0, NMFIELD_TYPE_UTF8, client()->password() ) );
-	lst.append( new Field::SingleField( NM_A_SZ_USER_AGENT, 0, NMFIELD_TYPE_UTF8, client()->userAgent() ) );
-	lst.append( new Field::SingleField( NM_A_UD_BUILD, 0, NMFIELD_TYPE_UDWORD, client()->protocolVersion() ) );
-	lst.append( new Field::SingleField( NM_A_IP_ADDRESS, 0, NMFIELD_TYPE_UTF8, client()->ipAddress() ) );
+	lst.append( new Field::SingleField( Field::NM_A_SZ_USERID, 0, NMFIELD_TYPE_UTF8, client()->userId() ) );
+	lst.append( new Field::SingleField( Field::NM_A_SZ_CREDENTIALS, 0, NMFIELD_TYPE_UTF8, client()->password() ) );
+	lst.append( new Field::SingleField( Field::NM_A_SZ_USER_AGENT, 0, NMFIELD_TYPE_UTF8, client()->userAgent() ) );
+	lst.append( new Field::SingleField( Field::NM_A_UD_BUILD, 0, NMFIELD_TYPE_UDWORD, client()->protocolVersion() ) );
+	lst.append( new Field::SingleField( Field::NM_A_IP_ADDRESS, 0, NMFIELD_TYPE_UTF8, client()->ipAddress() ) );
 	createTransfer( command, lst );
 }
 
@@ -74,32 +77,32 @@ bool LoginTask::take( Transfer * transfer )
 
 	// CREATE CONTACT LIST
 	// locate contact list
-	Field::MultiField * contactList = loginResponseFields.findMultiField( NM_A_FA_CONTACT_LIST );
-	if ( !contactList )
+	Field::MultiField * contactList = loginResponseFields.findMultiField( Field::NM_A_FA_CONTACT_LIST );
+	if ( contactList )
 	{
-		setError( Protocol );
-		return true;
+		Field::FieldList contactListFields = contactList->fields();
+		Field::MultiField * container;
+		// read folders
+		for ( Field::FieldListIterator it = contactListFields.find( Field::NM_A_FA_FOLDER );
+				it != contactListFields.end();
+				it = contactListFields.find( ++it, Field::NM_A_FA_FOLDER ) )
+		{
+			container = static_cast<Field::MultiField *>( *it );
+			extractFolder( container );
+		}
+
+		// read contacts
+		for ( Field::FieldListIterator it = contactListFields.find( Field::NM_A_FA_CONTACT );
+				it != contactListFields.end();
+				it = contactListFields.find( ++it, Field::NM_A_FA_CONTACT ) )
+		{
+			container = static_cast<Field::MultiField *>( *it );
+			extractContact( container );
+		}
 	}
-	Field::FieldList contactListFields = contactList->fields();
-	Field::MultiField * container;
-	// read folders
-	for ( Field::FieldListIterator it = contactListFields.find( NM_A_FA_FOLDER );
-		  it != contactListFields.end();
-		  it = contactListFields.find( ++it, NM_A_FA_FOLDER ) )
-	{
-		container = static_cast<Field::MultiField *>( *it );
-		extractFolder( container );
-	}
-		  
-	// read contacts
-	for ( Field::FieldListIterator it = contactListFields.find( NM_A_FA_CONTACT );
-		  it != contactListFields.end();
-		  it = contactListFields.find( ++it, NM_A_FA_CONTACT ) )
-	{
-		container = static_cast<Field::MultiField *>( *it );
-		extractContact( container );
-	}
-	
+
+	extractKeepalivePeriod( loginResponseFields );
+
 	setSuccess();
 	
 	return true;
@@ -111,16 +114,16 @@ void LoginTask::extractFolder( Field::MultiField * folderContainer )
 	Field::SingleField * current;
 	Field::FieldList fl = folderContainer->fields();
 	// object id
-	current = fl.findSingleField( NM_A_SZ_OBJECT_ID );
+	current = fl.findSingleField( Field::NM_A_SZ_OBJECT_ID );
 	folder.id = current->value().toInt();
 	// sequence number
-	current = fl.findSingleField( NM_A_SZ_SEQUENCE_NUMBER );
+	current = fl.findSingleField( Field::NM_A_SZ_SEQUENCE_NUMBER );
 	folder.sequence = current->value().toInt();
 	// name 
-	current = fl.findSingleField( NM_A_SZ_DISPLAY_NAME );
+	current = fl.findSingleField( Field::NM_A_SZ_DISPLAY_NAME );
 	folder.name = current->value().toString();
 	// parent
-	current = fl.findSingleField( NM_A_SZ_PARENT_ID );
+	current = fl.findSingleField( Field::NM_A_SZ_PARENT_ID );
 	folder.parentId = current->value().toInt();
 	
 	client()->debug( QString( "Got folder: %1, obj: %2, parent: %3, seq: %3." ).arg( folder.name ).arg(  folder.id ).arg( folder.parentId ).arg( folder.sequence ) );
@@ -130,24 +133,24 @@ void LoginTask::extractFolder( Field::MultiField * folderContainer )
 
 void LoginTask::extractContact( Field::MultiField * contactContainer )
 {
-	if ( contactContainer->tag() != NM_A_FA_CONTACT )
+	if ( contactContainer->tag() != Field::NM_A_FA_CONTACT )
 		return;
 	ContactItem contact;
 	Field::SingleField * current;
 	Field::FieldList fl = contactContainer->fields();
 	// sequence number, object and parent IDs are a numeric values but are stored as strings...
-	current = fl.findSingleField( NM_A_SZ_OBJECT_ID );
+	current = fl.findSingleField( Field::NM_A_SZ_OBJECT_ID );
 	contact.id = current->value().toInt();
-	current = fl.findSingleField( NM_A_SZ_PARENT_ID );
+	current = fl.findSingleField( Field::NM_A_SZ_PARENT_ID );
 	contact.parentId = current->value().toInt();
-	current = fl.findSingleField( NM_A_SZ_SEQUENCE_NUMBER );
+	current = fl.findSingleField( Field::NM_A_SZ_SEQUENCE_NUMBER );
 	contact.sequence = current->value().toInt();
-	current = fl.findSingleField( NM_A_SZ_DISPLAY_NAME );
+	current = fl.findSingleField( Field::NM_A_SZ_DISPLAY_NAME );
 	contact.displayName = current->value().toString();
-	current = fl.findSingleField( NM_A_SZ_DN );
-	contact.dn = current->value().toString().lower();
+	current = fl.findSingleField( Field::NM_A_SZ_DN );
+	contact.dn = current->value().toString().toLower();
 	emit gotContact( contact );
-	Field::MultiField * details = fl.findMultiField( NM_A_FA_USER_DETAILS );
+	Field::MultiField * details = fl.findMultiField( Field::NM_A_FA_USER_DETAILS );
 	if ( details ) // not all contact list contacts have these
 	{
 		Field::FieldList detailsFields = details->fields();
@@ -167,27 +170,27 @@ ContactDetails LoginTask::extractUserDetails( Field::FieldList & fields )
 	cd.archive = false;
 	// read the supplied fields, set metadata and status.
 	Field::SingleField * sf;
-	if ( ( sf = fields.findSingleField ( NM_A_SZ_AUTH_ATTRIBUTE ) ) )
+	if ( ( sf = fields.findSingleField ( Field::NM_A_SZ_AUTH_ATTRIBUTE ) ) )
 		cd.authAttribute = sf->value().toString();
-	if ( ( sf = fields.findSingleField ( NM_A_SZ_DN ) ) )
-		cd.dn = sf->value().toString().lower(); // HACK: lowercased DN
-	if ( ( sf = fields.findSingleField ( "CN" ) ) )
+	if ( ( sf = fields.findSingleField ( Field::NM_A_SZ_DN ) ) )
+		cd.dn = sf->value().toString().toLower(); // HACK: lowercased DN
+	if ( ( sf = fields.findSingleField ( Field::KOPETE_NM_USER_DETAILS_CN ) ) )
 		cd.cn = sf->value().toString();
-	if ( ( sf = fields.findSingleField ( "Given Name" ) ) )
+	if ( ( sf = fields.findSingleField ( Field::KOPETE_NM_USER_DETAILS_GIVEN_NAME ) ) )
 		cd.givenName = sf->value().toString();
-	if ( ( sf = fields.findSingleField ( "Surname" ) ) )
+	if ( ( sf = fields.findSingleField ( Field::KOPETE_NM_USER_DETAILS_SURNAME ) ) )
 		cd.surname = sf->value().toString();
-	if ( ( sf = fields.findSingleField ( "Full Name" ) ) )
+	if ( ( sf = fields.findSingleField ( Field::KOPETE_NM_USER_DETAILS_FULL_NAME ) ) )
 		cd.fullName = sf->value().toString();
-	if ( ( sf = fields.findSingleField ( "nnmArchive" ) ) )
+	if ( ( sf = fields.findSingleField ( Field::KOPETE_NM_USER_DETAILS_ARCHIVE_FLAG ) ) )
 		cd.archive = ( sf->value().toInt() == 1 );
-	if ( ( sf = fields.findSingleField ( NM_A_SZ_STATUS ) ) )
+	if ( ( sf = fields.findSingleField ( Field::NM_A_SZ_STATUS ) ) )
 		cd.status = sf->value().toInt();
-	if ( ( sf = fields.findSingleField ( NM_A_SZ_MESSAGE_BODY ) ) )
+	if ( ( sf = fields.findSingleField ( Field::NM_A_SZ_MESSAGE_BODY ) ) )
 		cd.awayMessage = sf->value().toString();
 	Field::MultiField * mf;
-	QMap< QString, QString > propMap;
-	if ( ( mf = fields.findMultiField ( NM_A_FA_INFO_DISPLAY_ARRAY ) ) )
+	QMap< QString, QVariant > propMap;
+	if ( ( mf = fields.findMultiField ( Field::NM_A_FA_INFO_DISPLAY_ARRAY ) ) )
 	{
 		Field::FieldList fl = mf->fields();
 		const Field::FieldListIterator end = fl.end();
@@ -215,7 +218,7 @@ ContactDetails LoginTask::extractUserDetails( Field::FieldList & fields )
 						if ( propField /*&& propField->tag() == parentName */)
 						{
 							QString propValue = propField->value().toString();
-							QString contents = propMap[ propField->tag() ];
+							QString contents = propMap[ propField->tag() ].toString();
 							if ( !contents.isEmpty() )
 								contents.append( ", " );
 							contents.append( propField->value().toString());
@@ -223,7 +226,7 @@ ContactDetails LoginTask::extractUserDetails( Field::FieldList & fields )
 						}
 					}
 				}
-			}	
+			}
 		}
 	}
 	if ( !propMap.empty() )
@@ -241,12 +244,12 @@ void LoginTask::extractPrivacy( Field::FieldList & fields )
 	QStringList denyList;
 	// read blocking
 	// may be a single field or may be an array 
-	Field::FieldListIterator it = fields.find( NM_A_LOCKED_ATTR_LIST );
+	Field::FieldListIterator it = fields.find( Field::NM_A_LOCKED_ATTR_LIST );
 	if ( it != fields.end() )
 	{
 		if ( Field::SingleField * sf = dynamic_cast<Field::SingleField *>( *it ) )
 		{
-			if ( sf->value().toString().find( NM_A_BLOCKING ) )
+			if ( sf->value().toString().indexOf( Field::NM_A_BLOCKING ) != -1 )
 				privacyLocked = true;
 		}
 		else if ( Field::MultiField * mf = dynamic_cast<Field::MultiField *>( *it ) )
@@ -256,7 +259,7 @@ void LoginTask::extractPrivacy( Field::FieldList & fields )
 			{
 				if ( Field::SingleField * sf = dynamic_cast<Field::SingleField *>( *it ) )
 				{
-					if ( sf->tag() == NM_A_BLOCKING )
+					if ( sf->tag() == Field::NM_A_BLOCKING )
 					{
 						privacyLocked = true;
 						break;
@@ -267,20 +270,20 @@ void LoginTask::extractPrivacy( Field::FieldList & fields )
 	}
 	
 	// read default privacy policy
-	Field::SingleField * sf = fields.findSingleField( NM_A_BLOCKING );
+	Field::SingleField * sf = fields.findSingleField( Field::NM_A_BLOCKING );
 	if ( sf )
 		defaultDeny = ( sf->value().toInt() != 0 );
 	
 		
 	// read deny list
-	denyList = readPrivacyItems( NM_A_BLOCKING_DENY_LIST, fields );
+	denyList = readPrivacyItems( Field::NM_A_BLOCKING_DENY_LIST, fields );
 	// read allow list
-	allowList = readPrivacyItems( NM_A_BLOCKING_ALLOW_LIST, fields );
+	allowList = readPrivacyItems( Field::NM_A_BLOCKING_ALLOW_LIST, fields );
 	emit gotPrivacySettings( privacyLocked, defaultDeny, allowList, denyList );
-	kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "locked is " << privacyLocked << ", default is " << defaultDeny << "\nallow list is: " << allowList << "\ndeny list is: " << denyList << endl;
+//	kDebug() << "locked is " << privacyLocked << ", default is " << defaultDeny << "\nallow list is: " << allowList << "\ndeny list is: " << denyList;
 }
 
-QStringList LoginTask::readPrivacyItems( const QCString & tag, Field::FieldList & fields )
+QStringList LoginTask::readPrivacyItems( const QByteArray & tag, Field::FieldList & fields )
 {
 	QStringList items;
 	
@@ -289,7 +292,7 @@ QStringList LoginTask::readPrivacyItems( const QCString & tag, Field::FieldList
 	{
 		if ( Field::SingleField * sf = dynamic_cast<Field::SingleField *>( *it ) )
 		{
-			items.append( sf->value().toString().lower() );
+			items.append( sf->value().toString().toLower() );
 		}
 		else if ( Field::MultiField * mf = dynamic_cast<Field::MultiField *>( *it ) )
 		{
@@ -298,7 +301,7 @@ QStringList LoginTask::readPrivacyItems( const QCString & tag, Field::FieldList
 			{
 				if ( Field::SingleField * sf = dynamic_cast<Field::SingleField *>( *it ) )
 				{
-					items.append( sf->value().toString().lower() );
+					items.append( sf->value().toString().toLower() );
 				}
 			}
 		}
@@ -308,7 +311,7 @@ QStringList LoginTask::readPrivacyItems( const QCString & tag, Field::FieldList
 
 void LoginTask::extractCustomStatuses( Field::FieldList & fields )
 {
-	Field::FieldListIterator it = fields.find( NM_A_FA_CUSTOM_STATUSES );
+	Field::FieldListIterator it = fields.find( Field::NM_A_FA_CUSTOM_STATUSES );
 	if ( it != fields.end() )
 	{
 		if ( Field::MultiField * mf = dynamic_cast<Field::MultiField *>( *it ) )
@@ -317,7 +320,7 @@ void LoginTask::extractCustomStatuses( Field::FieldList & fields )
 			for ( Field::FieldListIterator custStatIt = fl.begin(); custStatIt != fl.end(); ++custStatIt )
 			{
 				Field::MultiField * mf2 = dynamic_cast<Field::MultiField *>( *custStatIt );
-				if ( mf2 && ( mf2->tag() == NM_A_FA_STATUS ) )
+				if ( mf2 && ( mf2->tag() == Field::NM_A_FA_STATUS ) )
 				{
 					GroupWise::CustomStatus custom;
 					Field::FieldList fl2 = mf2->fields();
@@ -325,11 +328,11 @@ void LoginTask::extractCustomStatuses( Field::FieldList & fields )
 					{
 						if ( Field::SingleField * sf3 = dynamic_cast<Field::SingleField *>( *custContentIt ) )
 						{
-							if ( sf3->tag() == NM_A_SZ_TYPE )
+							if ( sf3->tag() == Field::NM_A_SZ_TYPE )
 								custom.status = (GroupWise::Status)sf3->value().toInt();
-							else if ( sf3->tag() == NM_A_SZ_DISPLAY_NAME )
+							else if ( sf3->tag() == Field::NM_A_SZ_DISPLAY_NAME )
 								custom.name = sf3->value().toString();
-							else if ( sf3->tag() == NM_A_SZ_MESSAGE_BODY )
+							else if ( sf3->tag() == Field::NM_A_SZ_MESSAGE_BODY )
 								custom.autoReply = sf3->value().toString();
 						}
 					}
@@ -340,4 +343,21 @@ void LoginTask::extractCustomStatuses( Field::FieldList & fields )
 	}
 }
 
+void LoginTask::extractKeepalivePeriod( Field::FieldList & fields )
+{
+	Field::FieldListIterator it = fields.find( Field::NM_A_UD_KEEPALIVE );
+	if ( it != fields.end() )
+	{
+		if ( Field::SingleField * sf = dynamic_cast<Field::SingleField *>( *it ) )
+		{
+			bool ok;
+			int period = sf->value().toInt( &ok );
+			if ( ok )
+			{
+				emit gotKeepalivePeriod( period );
+			}
+		}
+	}
+}
+
 #include "logintask.moc"
