@@ -22,6 +22,8 @@
 #define LOGINTASK_H
 
 #include "requesttask.h"
+//Added by qt3to4:
+#include <QByteArray>
 
 using namespace GroupWise;
 
@@ -39,8 +41,8 @@ public:
 	 */
 	void initialise();
 	/**
-	 * Only accepts the contactlist that comes back from the server, 
-	 * processes it and notifies the client of the contactlist
+	 * Only accepts the contact list that comes back from the server, 
+	 * processes it and notifies the client of the contact list
 	 */
 	bool take( Transfer * transfer );
 protected:
@@ -48,7 +50,7 @@ protected:
 	void extractContact( Field::MultiField * contactContainer );
 	ContactDetails extractUserDetails( Field::FieldList & fields );
 	void extractPrivacy( Field::FieldList & fields );
-	QStringList readPrivacyItems( const QCString & tag, Field::FieldList & fields );
+	QStringList readPrivacyItems( const QByteArray & tag, Field::FieldList & fields );
 	void extractCustomStatuses( Field::FieldList & fields );
 	void extractKeepalivePeriod( Field::FieldList & fields );
 signals:
