@@ -2,6 +2,7 @@
     Kopete Groupwise Protocol
     pollsearchresultstask.cpp - Poll the server to see if it has processed our search yet.
 
+    Copyright (c) 2006      Novell, Inc	 	 	 http://www.opensuse.org
     Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
     
     Based on Iris, Copyright (C) 2003  Justin Karneges
@@ -24,6 +25,8 @@
 #include "logintask.h"
 
 #include "pollsearchresultstask.h"
+//Added by qt3to4:
+#include <Q3ValueList>
 
 using namespace GroupWise;
 
@@ -39,7 +42,7 @@ PollSearchResultsTask::~PollSearchResultsTask()
 void PollSearchResultsTask::poll( const QString & queryHandle )
 {
 	Field::FieldList lst;
-	lst.append( new Field::SingleField( NM_A_SZ_OBJECT_ID, 0, NMFIELD_TYPE_UTF8, queryHandle ) );
+	lst.append( new Field::SingleField( Field::NM_A_SZ_OBJECT_ID, 0, NMFIELD_TYPE_UTF8, queryHandle ) );
 	createTransfer( "getresults", lst );
 }
 
@@ -58,10 +61,10 @@ bool PollSearchResultsTask::take( Transfer * transfer )
 	
 	// look for the status code
 	Field::FieldList responseFields = response->fields();
-	Field::SingleField * sf = responseFields.findSingleField( NM_A_SZ_STATUS );
+	Field::SingleField * sf = responseFields.findSingleField( Field::NM_A_SZ_STATUS );
 	m_queryStatus = sf->value().toInt();
 	
-	Field::MultiField * resultsArray = responseFields.findMultiField( NM_A_FA_RESULTS );
+	Field::MultiField * resultsArray = responseFields.findMultiField( Field::NM_A_FA_RESULTS );
 	if ( !resultsArray )
 	{
 		setError( Protocol );
@@ -69,9 +72,9 @@ bool PollSearchResultsTask::take( Transfer * transfer )
 	}
 	Field::FieldList matches = resultsArray->fields();
 	const Field::FieldListIterator end = matches.end();
-	for ( Field::FieldListIterator it = matches.find( NM_A_FA_CONTACT );
+	for ( Field::FieldListIterator it = matches.find( Field::NM_A_FA_CONTACT );
 		  it != end;
-		  it = matches.find( ++it, NM_A_FA_CONTACT ) )
+		  it = matches.find( ++it, Field::NM_A_FA_CONTACT ) )
 	{
 		Field::MultiField * mf = static_cast<Field::MultiField *>( *it );
 		Field::FieldList contact = mf->fields();
@@ -79,7 +82,7 @@ bool PollSearchResultsTask::take( Transfer * transfer )
 		m_results.append( cd );
 	}
 	
-	// first field: NM_A_SZ_STATUS contains 
+	// first field: Field::NM_A_SZ_STATUS contains 
 	#define SEARCH_PENDING 0
 	#define SEARCH_INPROGRESS 1
 	#define SEARCH_COMPLETED 2
@@ -87,7 +90,7 @@ bool PollSearchResultsTask::take( Transfer * transfer )
 	#define SEARCH_CANCELLED 4
 	#define SEARCH_ERROR 5
 	// set a status code if needed
-	// followed by NM_A_FA_RESULTS, looks like a getdetails
+	// followed by Field::NM_A_FA_RESULTS, looks like a getdetails
 	// add an accessor to get at the results list of ContactItems, probably
 	
 	if ( m_queryStatus != 2 )
@@ -97,7 +100,7 @@ bool PollSearchResultsTask::take( Transfer * transfer )
 	return true;
 }
 
-QValueList< GroupWise::ContactDetails > PollSearchResultsTask::results()
+Q3ValueList< GroupWise::ContactDetails > PollSearchResultsTask::results()
 {
 	return m_results;
 }
@@ -114,27 +117,27 @@ GroupWise::ContactDetails PollSearchResultsTask::extractUserDetails( Field::Fiel
 	cd.archive = false;
 	// read the supplied fields, set metadata and status.
 	Field::SingleField * sf;
-	if ( ( sf = fields.findSingleField ( NM_A_SZ_AUTH_ATTRIBUTE ) ) )
+	if ( ( sf = fields.findSingleField ( Field::NM_A_SZ_AUTH_ATTRIBUTE ) ) )
 		cd.authAttribute = sf->value().toString();
-	if ( ( sf = fields.findSingleField ( NM_A_SZ_DN ) ) )
-		cd.dn =sf->value().toString().lower(); // HACK: lowercased DN
-	if ( ( sf = fields.findSingleField ( "CN" ) ) )
+	if ( ( sf = fields.findSingleField ( Field::NM_A_SZ_DN ) ) )
+		cd.dn =sf->value().toString().toLower(); // HACK: lowercased DN
+	if ( ( sf = fields.findSingleField ( Field::KOPETE_NM_USER_DETAILS_CN ) ) )
 		cd.cn = sf->value().toString();
-	if ( ( sf = fields.findSingleField ( "Given Name" ) ) )
+	if ( ( sf = fields.findSingleField ( Field::KOPETE_NM_USER_DETAILS_GIVEN_NAME ) ) )
 		cd.givenName = sf->value().toString();
-	if ( ( sf = fields.findSingleField ( "Surname" ) ) )
+	if ( ( sf = fields.findSingleField ( Field::KOPETE_NM_USER_DETAILS_SURNAME ) ) )
 		cd.surname = sf->value().toString();
-	if ( ( sf = fields.findSingleField ( "Full Name" ) ) )
+	if ( ( sf = fields.findSingleField ( Field::KOPETE_NM_USER_DETAILS_FULL_NAME ) ) )
 		cd.fullName = sf->value().toString();
-	if ( ( sf = fields.findSingleField ( "nnmArchive" ) ) )
+	if ( ( sf = fields.findSingleField ( Field::KOPETE_NM_USER_DETAILS_ARCHIVE_FLAG ) ) )
 		cd.archive = ( sf->value().toInt() == 1 );
-	if ( ( sf = fields.findSingleField ( NM_A_SZ_STATUS ) ) )
+	if ( ( sf = fields.findSingleField ( Field::NM_A_SZ_STATUS ) ) )
 		cd.status = sf->value().toInt();
-	if ( ( sf = fields.findSingleField ( NM_A_SZ_MESSAGE_BODY ) ) )
+	if ( ( sf = fields.findSingleField ( Field::NM_A_SZ_MESSAGE_BODY ) ) )
 		cd.awayMessage = sf->value().toString();
 	Field::MultiField * mf;
-	QMap< QString, QString > propMap;
-	if ( ( mf = fields.findMultiField ( NM_A_FA_INFO_DISPLAY_ARRAY ) ) )
+	QMap< QString, QVariant > propMap;
+	if ( ( mf = fields.findMultiField ( Field::NM_A_FA_INFO_DISPLAY_ARRAY ) ) )
 	{
 		Field::FieldList fl = mf->fields();
 		const Field::FieldListIterator end = fl.end();
@@ -164,7 +167,7 @@ GroupWise::ContactDetails PollSearchResultsTask::extractUserDetails( Field::Fiel
 						if ( propField )
 						{
 							QString propValue = propField->value().toString();
-							QString contents = propMap[ propField->tag() ];
+							QString contents = propMap[ propField->tag() ].toString();
 							if ( !contents.isEmpty() )
 								contents.append( ", " );
 							contents.append( propField->value().toString());
