@@ -23,19 +23,22 @@
 
 #include "gwerror.h"
 
+#include "libgroupwise_export.h"
 #include "updateitemtask.h"
+//Added by qt3to4:
+#include <Q3ValueList>
 
 /**
  * Renames a contact on the server
  * @author Kopete Developers
  */
-class UpdateContactTask : public UpdateItemTask
+class LIBGROUPWISE_EXPORT UpdateContactTask : public UpdateItemTask
 {
 Q_OBJECT
 public:
 	UpdateContactTask(Task* parent);
 	~UpdateContactTask();
-	void renameContact( const QString& newName, const QValueList<GroupWise::ContactItem> & contactInstances );
+	void renameContact( const QString& newName, const Q3ValueList<GroupWise::ContactItem> & contactInstances );
 	QString displayName();
 private:
 	QString m_name;
