@@ -23,11 +23,11 @@
 #include "xmpp.h"
 #include "im.h"
 
-class dlgJabberVCard;
 class JabberProtocol;
 class JabberAccount;
-class JabberResource;
+class JabberTransport;
 namespace Kopete { class MetaContact; }
+namespace XMPP { class VCard; }
 
 class JabberBaseContact : public Kopete::Contact
 {
@@ -37,8 +37,12 @@ friend class JabberAccount;	/* Friends can touch each other's private parts. */
 
 public:
 
+	/**
+	 * @param legacyId is the contactId of the contact if != Jid
+	 */
 	JabberBaseContact (const XMPP::RosterItem &rosterItem,
-				   JabberAccount *account, Kopete::MetaContact * mc);
+					   Kopete::Account *account, Kopete::MetaContact * mc, 
+					   const QString &legacyId=QString());
 
 	/********************************************************************
 	 *
@@ -54,8 +58,13 @@ public:
 	/**
 	 * Return the account instance associated with this contact
 	 */
-	JabberAccount *account ();
-
+	JabberAccount *account () const { return m_account; };
+	
+	/**
+	 * return the transport if any, or null
+	 */
+	JabberTransport *transport();
+			
 	/**
 	 * Return if the contact is reachable (this is true if the account
 	 * is online)
@@ -66,7 +75,7 @@ public:
 	 * Create custom context menu items for the contact
 	 * FIXME: implement manager version here?
 	 */
-	virtual QPtrList<KAction> *customContextMenuActions () = 0;
+	virtual QList<KAction*> *customContextMenuActions () = 0;
 
 	/**
 	 * Serialize contact
@@ -90,13 +99,6 @@ public:
 	 */
 	void updateResourceList ();
 
-	/**
-	 * Re-evaluate online status. Gets called
-	 * whenever a resource is added, removed, or
-	 * changed in the resource pool.
-	 */
-	void reevaluateStatus ();
-
 	/**
 	 * Return current full address.
 	 * Uses bestResource() if no presubscribed
@@ -126,13 +128,34 @@ public:
 	 * See @ref setDontSync for a full description.
 	 */
 	bool dontSync ();
+	
+	/**
+	 * return the roster item of the contact.
+	 * to get the jid, use  rosterItem().jid().full()  don't use contactId as it is not the same with transport
+	 */
+	XMPP::RosterItem rosterItem() const { return mRosterItem; }
+	
+	/**
+	 * Reads a vCard object and updates the contact's
+	 * properties accordingly.
+	 */
+	void setPropertiesFromVCard ( const XMPP::VCard &vCard );
+
 
 public slots:
 
 	/**
 	 * Retrieve a vCard for the contact
 	 */
-	virtual void slotUserInfo () = 0;
+	virtual void slotUserInfo ();
+	
+	
+	/**
+	 * Re-evaluate online status. Gets called
+	 * whenever a resource is added, removed, or
+	 * changed in the resource pool.
+	 */
+	void reevaluateStatus ();
 
 protected:
 	/**
@@ -151,6 +174,7 @@ protected:
 
 private:
 	bool mDontSync;
+	JabberAccount *m_account;
 
 };
 
