@@ -18,30 +18,38 @@
  *
  */
 
-#include"socks.h"
+#include "socks.h"
 
-#include<qhostaddress.h>
-#include<qstringlist.h>
-#include<qptrlist.h>
-#include<qtimer.h>
-#include<qguardedptr.h>
-#include<qsocketdevice.h>
-#include<qsocketnotifier.h>
+#include <qhostaddress.h>
+#include <qstringlist.h>
+#include <q3ptrlist.h>
+#include <qtimer.h>
+#include <qpointer.h>
+#include <q3socketdevice.h>
+#include <qsocketnotifier.h>
+//Added by qt3to4:
+#include <Q3CString>
 
 #ifdef Q_OS_UNIX
-#include<sys/types.h>
-#include<netinet/in.h>
+#include <sys/types.h>
+#include <netinet/in.h>
 #endif
 
 #ifdef Q_OS_WIN32
-#include<windows.h>
+#include <windows.h>
+#include <winsock2.h>
 #endif
 
-#include"servsock.h"
-#include"bsocket.h"
+#ifdef Q_OS_UNIX
+#include <unistd.h>
+#include <fcntl.h>
+#endif
+
+#include "servsock.h"
+#include "bsocket.h"
 
 #ifdef PROX_DEBUG
-#include<stdio.h>
+#include <stdio.h>
 #endif
 
 // CS_NAMESPACE_BEGIN
@@ -56,7 +64,7 @@ static QByteArray sp_create_udp(const QString &host, Q_UINT16 port, const QByteA
 	//if(addr.setAddress(host))
 	//	return sp_set_request(addr, port, cmd1);
 
-	QCString h = host.utf8();
+	Q3CString h = host.utf8();
 	h.truncate(255);
 	h = QString::fromUtf8(h).utf8(); // delete any partial characters?
 	int hlen = h.length();
@@ -120,7 +128,7 @@ static int sp_read_udp(QByteArray *from, SPS_UDP *s)
 		full_len += host_len;
 		if((int)from->size() < full_len)
 			return 0;
-		QCString cs(host_len+1);
+		Q3CString cs(host_len+1);
 		memcpy(cs.data(), from->data() + 5, host_len);
 		host = QString::fromLatin1(cs);
 	}
@@ -152,7 +160,7 @@ static int sp_read_udp(QByteArray *from, SPS_UDP *s)
 class SocksUDP::Private
 {
 public:
-	QSocketDevice *sd;
+	Q3SocketDevice *sd;
 	QSocketNotifier *sn;
 	SocksClient *sc;
 	QHostAddress routeAddr;
@@ -166,7 +174,7 @@ SocksUDP::SocksUDP(SocksClient *sc, const QString &host, int port, const QHostAd
 {
 	d = new Private;
 	d->sc = sc;
-	d->sd = new QSocketDevice(QSocketDevice::Datagram);
+	d->sd = new Q3SocketDevice(Q3SocketDevice::Datagram);
 	d->sd->setBlocking(false);
 	d->sn = new QSocketNotifier(d->sd->socket(), QSocketNotifier::Read);
 	connect(d->sn, SIGNAL(activated(int)), SLOT(sn_activated(int)));
@@ -254,7 +262,7 @@ static int spc_get_version(QByteArray *from, SPCS_VERSION *s)
 		return -1;
 	if(from->size() < 2)
 		return 0;
-	uint num = from->at(1);
+	int num = from->at(1);
 	if(num > 16) // who the heck has over 16 auth methods??
 		return -1;
 	if(from->size() < 2 + num)
@@ -283,7 +291,7 @@ static int sps_get_version(QByteArray *from, SPSS_VERSION *s)
 }
 
 // authUsername
-static QByteArray spc_set_authUsername(const QCString &user, const QCString &pass)
+static QByteArray spc_set_authUsername(const Q3CString &user, const Q3CString &pass)
 {
 	int len1 = user.length();
 	int len2 = pass.length();
@@ -330,7 +338,7 @@ static int spc_get_authUsername(QByteArray *from, SPCS_AUTHUSERNAME *s)
 		return 0;
 	QByteArray a = ByteStream::takeArray(from, ulen + plen + 3);
 
-	QCString user, pass;
+	Q3CString user, pass;
 	user.resize(ulen+1);
 	pass.resize(plen+1);
 	memcpy(user.data(), a.data()+2, ulen);
@@ -352,7 +360,7 @@ static int sps_get_authUsername(QByteArray *from, SPSS_AUTHUSERNAME *s)
 		return 0;
 	QByteArray a = ByteStream::takeArray(from, 2);
 	s->version = a[0];
-	s->success = a[1] == 0 ? true: false;
+	s->success = ((char) a[1] == 0 ? true: false);
 	return 1;
 }
 
@@ -403,7 +411,7 @@ static QByteArray sp_set_request(const QString &host, Q_UINT16 port, unsigned ch
 	if(addr.setAddress(host))
 		return sp_set_request(addr, port, cmd1);
 
-	QCString h = host.utf8();
+	Q3CString h = host.utf8();
 	h.truncate(255);
 	h = QString::fromUtf8(h).utf8(); // delete any partial characters?
 	int hlen = h.length();
@@ -465,7 +473,7 @@ static int sp_get_request(QByteArray *from, SPS_CONNREQ *s)
 		full_len += host_len;
 		if((int)from->size() < full_len)
 			return 0;
-		QCString cs(host_len+1);
+		Q3CString cs(host_len+1);
 		memcpy(cs.data(), from->data() + 5, host_len);
 		host = QString::fromLatin1(cs);
 	}
@@ -818,7 +826,7 @@ void SocksClient::processOutgoing(const QByteArray &block)
 
 			d->active = true;
 
-			QGuardedPtr<QObject> self = this;
+			QPointer<QObject> self = this;
 			connected();
 			if(!self)
 				return;
@@ -1097,8 +1105,8 @@ public:
 	Private() {}
 
 	ServSock serv;
-	QPtrList<SocksClient> incomingConns;
-	QSocketDevice *sd;
+	Q3PtrList<SocksClient> incomingConns;
+	Q3SocketDevice *sd;
 	QSocketNotifier *sn;
 };
 
@@ -1130,7 +1138,10 @@ bool SocksServer::listen(Q_UINT16 port, bool udp)
 	if(!d->serv.listen(port))
 		return false;
 	if(udp) {
-		d->sd = new QSocketDevice(QSocketDevice::Datagram);
+		d->sd = new Q3SocketDevice(Q3SocketDevice::Datagram);
+#ifdef Q_OS_UNIX
+		::fcntl(d->sd->socket(), F_SETFD, FD_CLOEXEC);
+#endif
 		d->sd->setBlocking(false);
 		if(!d->sd->bind(QHostAddress(), port)) {
 			delete d->sd;
@@ -1219,5 +1230,3 @@ void SocksServer::sn_activated(int)
 }
 
 // CS_NAMESPACE_END
-
-#include "socks.moc"
