@@ -23,14 +23,16 @@
 //       report ErrProtocol if server uses wrong NS
 //       use send() instead of writeElement() in CoreProtocol
 
-#include"protocol.h"
+#include "protocol.h"
 
-#include<qca.h>
-#include"base64.h"
-#include"hash.h"
+#include <qca.h>
+//Added by qt3to4:
+#include <QList>
+#include <Q3CString>
+#include <QtCrypto>
 
 #ifdef XMPP_TEST
-#include"td.h"
+#include "td.h"
 #endif
 
 using namespace XMPP;
@@ -43,7 +45,7 @@ using namespace XMPP;
 static QString printArray(const QByteArray &a)
 {
 	QString s;
-	for(uint n = 0; n < a.size(); ++n) {
+	for(int n = 0; n < a.size(); ++n) {
 		unsigned char c = (unsigned char)a[(int)n];
 		if(c < 32 || c >= 127) {
 			QString str;
@@ -86,6 +88,7 @@ StreamFeatures::StreamFeatures()
 	sasl_supported = false;
 	bind_supported = false;
 	tls_required = false;
+	compress_supported = false;
 }
 
 //----------------------------------------------------------------------------
@@ -315,7 +318,7 @@ void BasicProtocol::extractStreamError(const QDomElement &e)
 
 		// find first non-standard namespaced element
 		QDomNodeList nl = e.childNodes();
-		for(uint n = 0; n < nl.count(); ++n) {
+		for(int n = 0; n < nl.count(); ++n) {
 			QDomNode i = nl.item(n);
 			if(i.isElement() && i.namespaceURI() != NS_STREAMS) {
 				appSpec = i.toElement();
@@ -530,7 +533,7 @@ bool BasicProtocol::doStep(const QDomElement &e)
 		if(!sendList.isEmpty()) {
 			SendItem i;
 			{
-				QValueList<SendItem>::Iterator it = sendList.begin();
+				QList<SendItem>::Iterator it = sendList.begin();
 				i = (*it);
 				sendList.remove(it);
 			}
@@ -611,12 +614,13 @@ void CoreProtocol::init()
 	dialback_verify = false;
 
 	// settings
-	jid = Jid();
+	jid_ = Jid();
 	password = QString();
 	oldOnly = false;
 	allowPlain = false;
 	doTLS = true;
 	doAuth = true;
+	doCompress = true;
 	doBinding = true;
 
 	// input
@@ -628,6 +632,7 @@ void CoreProtocol::init()
 	digest = false;
 	tls_started = false;
 	sasl_started = false;
+	compress_started = false;
 }
 
 void CoreProtocol::reset()
@@ -636,12 +641,13 @@ void CoreProtocol::reset()
 	init();
 }
 
-void CoreProtocol::startClientOut(const Jid &_jid, bool _oldOnly, bool tlsActive, bool _doAuth)
+void CoreProtocol::startClientOut(const Jid &_jid, bool _oldOnly, bool tlsActive, bool _doAuth, bool _doCompress)
 {
-	jid = _jid;
+	jid_ = _jid;
 	to = _jid.domain();
 	oldOnly = _oldOnly;
 	doAuth = _doAuth;
+	doCompress = _doCompress;
 	tls_started = tlsActive;
 
 	if(oldOnly)
@@ -710,6 +716,11 @@ void CoreProtocol::setAllowPlain(bool b)
 	allowPlain = b;
 }
 
+const Jid& CoreProtocol::jid() const
+{
+	return jid_;
+}
+
 void CoreProtocol::setPassword(const QString &s)
 {
 	password = s;
@@ -770,6 +781,7 @@ bool CoreProtocol::stepRequiresElement() const
 	switch(step) {
 		case GetFeatures:
 		case GetTLSProceed:
+		case GetCompressProceed:
 		case GetSASLChallenge:
 		case GetBindResponse:
 		case GetAuthGetResponse:
@@ -879,7 +891,7 @@ bool CoreProtocol::isValidStanza(const QDomElement &e) const
 
 bool CoreProtocol::grabPendingItem(const Jid &to, const Jid &from, int type, DBItem *item)
 {
-	for(QValueList<DBItem>::Iterator it = dbpending.begin(); it != dbpending.end(); ++it) {
+	for(QList<DBItem>::Iterator it = dbpending.begin(); it != dbpending.end(); ++it) {
 		const DBItem &i = *it;
 		if(i.type == type && i.to.compare(to) && i.from.compare(from)) {
 			const DBItem &i = (*it);
@@ -904,7 +916,7 @@ bool CoreProtocol::dialbackStep(const QDomElement &e)
 		// process a request
 		DBItem i;
 		{
-			QValueList<DBItem>::Iterator it = dbrequests.begin();
+			QList<DBItem>::Iterator it = dbrequests.begin();
 			i = (*it);
 			dbrequests.remove(it);
 		}
@@ -1051,12 +1063,33 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 			return true;
 		}
 
+		// Should we go further ?
+		if (!doAuth)
+			return loginComplete();
+		
+		// Deal with compression
+		if (doCompress && !compress_started && features.compress_supported && features.compression_mechs.contains("zlib")) {
+			QDomElement e = doc.createElementNS(NS_COMPRESS_PROTOCOL, "compress");
+			QDomElement m = doc.createElementNS(NS_COMPRESS_PROTOCOL, "method");
+			m.appendChild(doc.createTextNode("zlib"));
+			e.appendChild(m);
+			send(e,true);
+			event = ESend;
+			step = GetCompressProceed;
+			return true;
+		}
+
 		// deal with SASL?
 		if(!sasl_authed) {
 			if(!features.sasl_supported) {
 				// SASL MUST be supported
-				event = EError;
-				errorCode = ErrProtocol;
+				//event = EError;
+				//errorCode = ErrProtocol;
+				//return true;
+				
+				// Fall back on auth for non-compliant servers 
+				step = HandleAuthGet;
+				old = true;
 				return true;
 			}
 
@@ -1090,10 +1123,10 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 		QDomElement b = doc.createElementNS(NS_BIND, "bind");
 
 		// request specific resource?
-		QString resource = jid.resource();
+		QString resource = jid_.resource();
 		if(!resource.isEmpty()) {
 			QDomElement r = doc.createElement("resource");
-			r.appendChild(doc.createTextNode(jid.resource()));
+			r.appendChild(doc.createTextNode(jid_.resource()));
 			b.appendChild(r);
 		}
 
@@ -1111,7 +1144,7 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 #ifdef XMPP_TEST
 			TD::msg(QString("SASL OUT: [%1]").arg(printArray(sasl_step)));
 #endif
-			e.appendChild(doc.createTextNode(Base64::arrayToString(sasl_step)));
+			e.appendChild(doc.createTextNode(QCA::Base64().arrayToString(sasl_step)));
 		}
 
 		send(e, true);
@@ -1132,7 +1165,7 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 				QByteArray stepData = sasl_step;
 				QDomElement e = doc.createElementNS(NS_SASL, "challenge");
 				if(!stepData.isEmpty())
-					e.appendChild(doc.createTextNode(Base64::arrayToString(stepData)));
+					e.appendChild(doc.createTextNode(QCA::Base64().arrayToString(stepData)));
 
 				writeElement(e, TypeElement, false, true);
 				event = ESend;
@@ -1141,13 +1174,23 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 			}
 		}
 		else {
+			// already authed?  then ignore last client step
+			//   (this happens if "additional data with success"
+			//   is used)
+			if(sasl_authed)
+			{
+				event = ESASLSuccess;
+				step = HandleSASLSuccess;
+				return true;
+			}
+
 			QByteArray stepData = sasl_step;
 #ifdef XMPP_TEST
 			TD::msg(QString("SASL OUT: [%1]").arg(printArray(sasl_step)));
 #endif
 			QDomElement e = doc.createElementNS(NS_SASL, "response");
 			if(!stepData.isEmpty())
-				e.appendChild(doc.createTextNode(Base64::arrayToString(stepData)));
+				e.appendChild(doc.createTextNode(QCA::Base64().arrayToString(stepData)));
 
 			send(e, true);
 			event = ESend;
@@ -1168,7 +1211,7 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 		e.setAttribute("id", "auth_1");
 		QDomElement q = doc.createElementNS("jabber:iq:auth", "query");
 		QDomElement u = doc.createElement("username");
-		u.appendChild(doc.createTextNode(jid.node()));
+		u.appendChild(doc.createTextNode(jid_.node()));
 		q.appendChild(u);
 		e.appendChild(q);
 
@@ -1184,17 +1227,17 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 		e.setAttribute("id", "auth_2");
 		QDomElement q = doc.createElementNS("jabber:iq:auth", "query");
 		QDomElement u = doc.createElement("username");
-		u.appendChild(doc.createTextNode(jid.node()));
+		u.appendChild(doc.createTextNode(jid_.node()));
 		q.appendChild(u);
 		QDomElement p;
 		if(digest) {
 			// need SHA1 here
-			if(!QCA::isSupported(QCA::CAP_SHA1))
-				QCA::insertProvider(createProviderHash());
+			//if(!QCA::isSupported(QCA::CAP_SHA1))
+			//	QCA::insertProvider(createProviderHash());
 
 			p = doc.createElement("digest");
-			QCString cs = id.utf8() + password.utf8();
-			p.appendChild(doc.createTextNode(QCA::SHA1::hashToString(cs)));
+			Q3CString cs = id.utf8() + password.utf8();
+			p.appendChild(doc.createTextNode(QCA::Hash("sha1").hashToString(cs)));
 		}
 		else {
 			p = doc.createElement("password");
@@ -1202,7 +1245,7 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 		}
 		q.appendChild(p);
 		QDomElement r = doc.createElement("resource");
-		r.appendChild(doc.createTextNode(jid.resource()));
+		r.appendChild(doc.createTextNode(jid_.resource()));
 		q.appendChild(r);
 		e.appendChild(q);
 
@@ -1270,9 +1313,16 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 			if(!m.isNull()) {
 				f.sasl_supported = true;
 				QDomNodeList l = m.elementsByTagNameNS(NS_SASL, "mechanism");
-				for(uint n = 0; n < l.count(); ++n)
+				for(int n = 0; n < l.count(); ++n)
 					f.sasl_mechs += l.item(n).toElement().text();
 			}
+			QDomElement c = e.elementsByTagNameNS(NS_COMPRESS_FEATURE, "compression").item(0).toElement();
+			if(!c.isNull()) {
+				f.compress_supported = true;
+				QDomNodeList l = c.elementsByTagNameNS(NS_COMPRESS_FEATURE, "method");
+				for(int n = 0; n < l.count(); ++n)
+					f.compression_mechs += l.item(n).toElement().text();
+			}
 			QDomElement b = e.elementsByTagNameNS(NS_BIND, "bind").item(0).toElement();
 			if(!b.isNull())
 				f.bind_supported = true;
@@ -1293,15 +1343,19 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 				TD::msg(s);
 #endif
 			}
-
-			if(doAuth) {
-				event = EFeatures;
-				features = f;
-				step = HandleFeatures;
-				return true;
+			if(f.compress_supported) {
+#ifdef XMPP_TEST
+				QString s = "Compression mechs:";
+				for(QStringList::ConstIterator it = f.compression_mechs.begin(); it != f.compression_mechs.end(); ++it)
+					s += QString(" [%1]").arg((*it));
+				TD::msg(s);
+#endif
 			}
-			else
-				return loginComplete();
+
+			event = EFeatures;
+			features = f;
+			step = HandleFeatures;
+			return true;
 		}
 		else {
 			// ignore
@@ -1335,11 +1389,39 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 			// ignore
 		}
 	}
+	else if(step == GetCompressProceed) {
+		// waiting for proceed to compression
+		if(e.namespaceURI() == NS_COMPRESS_PROTOCOL) {
+			if(e.tagName() == "compressed") {
+#ifdef XMPP_TEST
+				TD::msg("Server wants us to proceed with compression");
+#endif
+				compress_started = true;
+				need = NCompress;
+				spare = resetStream();
+				step = Start;
+				return false;
+			}
+			else if(e.tagName() == "failure") {
+				event = EError;
+				errorCode = ErrCompress;
+				return true;
+			}
+			else {
+				event = EError;
+				errorCode = ErrProtocol;
+				return true;
+			}
+		}
+		else {
+			// ignore
+		}
+	}
 	else if(step == GetSASLChallenge) {
 		// waiting for sasl challenge/success/fail
 		if(e.namespaceURI() == NS_SASL) {
 			if(e.tagName() == "challenge") {
-				QByteArray a = Base64::stringToArray(e.text());
+				QByteArray a = QCA::Base64().stringToArray(e.text()).toByteArray();
 #ifdef XMPP_TEST
 				TD::msg(QString("SASL IN: [%1]").arg(printArray(a)));
 #endif
@@ -1349,6 +1431,18 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 				return false;
 			}
 			else if(e.tagName() == "success") {
+				QString str = e.text();
+				// "additional data with success" ?
+				if(!str.isEmpty())
+				{
+					QByteArray a = QCA::Base64().stringToArray(str).toByteArray();
+					sasl_step = a;
+					sasl_authed = true;
+					need = NSASLNext;
+					step = GetSASLNext;
+					return false;
+				}
+
 				sasl_authed = true;
 				event = ESASLSuccess;
 				step = HandleSASLSuccess;
@@ -1390,7 +1484,7 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 						errorCode = ErrProtocol;
 						return true;
 					}
-					jid = j;
+					jid_ = j;
 					return loginComplete();
 				}
 				else {
@@ -1401,7 +1495,7 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 						// get error condition
 						QDomNodeList nl = err.childNodes();
 						QDomElement t;
-						for(uint n = 0; n < nl.count(); ++n) {
+						for(int n = 0; n < nl.count(); ++n) {
 							QDomNode i = nl.item(n);
 							if(i.isElement()) {
 								t = i.toElement();
@@ -1534,7 +1628,7 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 				sasl_started = true;
 				sasl_mech = e.attribute("mechanism");
 				// TODO: if child text missing, don't pass it
-				sasl_step = Base64::stringToArray(e.text());
+				sasl_step = QCA::Base64().stringToArray(e.text()).toByteArray();
 				need = NSASLFirst;
 				step = GetSASLNext;
 				return false;
@@ -1573,7 +1667,7 @@ bool CoreProtocol::normalStep(const QDomElement &e)
 	}
 	else if(step == GetSASLResponse) {
 		if(e.namespaceURI() == NS_SASL && e.localName() == "response") {
-			sasl_step = Base64::stringToArray(e.text());
+			sasl_step = QCA::Base64().stringToArray(e.text()).toByteArray();
 			need = NSASLNext;
 			step = GetSASLNext;
 			return false;
