@@ -4,7 +4,7 @@
                              -------------------
     begin                : Mon Dec 9 2002
     copyright            : (C) 2002-2003 by Till Gerken <till@tantalo.net>
-                           Based on code by Olivier Goffart <ogoffart @ kde.org>
+                           Based on code by Olivier Goffart <ogoffart@kde.org>
     email                : kopete-devel@kde.org
  ***************************************************************************/
 
@@ -17,27 +17,27 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef JABBEREDITACCOUNTWIDEGET_H
-#define JABBEREDITACCOUNTWIDEGET_H
+#ifndef JABBEREDITACCOUNTWIDGET_H
+#define JABBEREDITACCOUNTWIDGET_H
 
 #include <qwidget.h>
-#include <kprogress.h>
+
 #include "editaccountwidget.h"
 #include "jabberaccount.h"
-#include "dlgjabbereditaccountwidget.h"
+#include "ui_dlgjabbereditaccountwidget.h"
 #include "jabberprotocol.h"
 
 /**
   *@author Till Gerken <till@tantalo.net>
   */
 
-class JabberEditAccountWidget:public DlgJabberEditAccountWidget, public KopeteEditAccountWidget
+class JabberEditAccountWidget: public QWidget, public Ui::DlgJabberEditAccountWidget, public KopeteEditAccountWidget
 {
 
 Q_OBJECT
 
 public:
-	JabberEditAccountWidget (JabberProtocol * proto, JabberAccount *, QWidget * parent = 0, const char *name = 0);
+	JabberEditAccountWidget (JabberProtocol * proto, JabberAccount *, QWidget * parent = 0);
 	~JabberEditAccountWidget ();
 	virtual bool validateData ();
 	virtual Kopete::Account *apply ();
@@ -50,6 +50,7 @@ private slots:
 	void deleteClicked ();
 	void sslToggled (bool);
 	void updateServerField ();
+	void slotPrivacyListsClicked ();
 
 private:
 	JabberProtocol *m_protocol;
@@ -59,4 +60,4 @@ private:
 
 };
 
-#endif
+#endif // JABBEREDITACCOUNTWIDGET_H
