@@ -26,13 +26,12 @@
 #include "kopetepassword.h"
 
 #include <kaction.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <klocale.h>
 #include <kconfigbase.h>
-#include "kopeteaway.h"
 #include <kinputdialog.h>
 #include <kmessagebox.h>
-#include <qdict.h>
+#include <q3dict.h>
 
 MeanwhileAccount::MeanwhileAccount(
                         MeanwhileProtocol *parent,
@@ -108,7 +107,7 @@ void MeanwhileAccount::connectWithPassword(const QString &password)
 
     if (!m_session->isConnected() && !m_session->isConnecting())
         m_session->connect(configGroup()->readEntry("Server"),
-                configGroup()->readNumEntry("Port"),
+                configGroup()->readEntry("Port"),
                 m_meanwhileId, password);
 
     m_session->setStatus(initialStatus());
@@ -133,19 +132,18 @@ void MeanwhileAccount::disconnect(Kopete::Account::DisconnectReason reason)
     m_session = 0L;
 }
 
-KActionMenu * MeanwhileAccount::actionMenu()
+void MeanwhileAccount::fillActionMenu( KActionMenu *actionMenu )
 {
-    KActionMenu *menu = Kopete::Account::actionMenu();
+	Kopete::Account::fillActionMenu( actionMenu );
 
-    menu->popupMenu()->insertSeparator();
+	actionMenu->popupMenu()->insertSeparator();
 
 #if 0
-    menu->insert(new KAction(i18n("&Change Status Message"), QString::null, 0,
+    actionMenu->insert(new KAction(i18n("&Change Status Message"), QString(), 0,
                 this, SLOT(meanwhileChangeStatus()), this,
                 "meanwhileChangeStatus"));
     //infoPlugin->addCustomMenus(theMenu);
 #endif
-    return menu;
 }
 
 QString MeanwhileAccount::getServerName()
@@ -155,7 +153,7 @@ QString MeanwhileAccount::getServerName()
 
 int MeanwhileAccount::getServerPort()
 {
-    return configGroup()->readNumEntry("Port");
+    return configGroup()->readEntry("Port");
 }
 
 void MeanwhileAccount::setServerName(const QString &server)
