@@ -9,16 +9,15 @@
 /**
   *@author duncan
   */
-class msnAddUI;
-class MSNProtocol;
+namespace Ui { class msnAddUI; }
 
 class MSNAddContactPage : public AddContactPage
 {
    Q_OBJECT
 public:
-	MSNAddContactPage(bool connected, QWidget *parent=0, const char *name=0);
+	explicit MSNAddContactPage(bool connected, QWidget *parent=0);
 	~MSNAddContactPage();
-	msnAddUI *msndata;
+	Ui::msnAddUI *msndata;
 	QLabel *noaddMsg1;
 	QLabel *noaddMsg2;
 	bool canadd;
