@@ -17,23 +17,29 @@
 
 #include "msnchatsession.h"
 
-#include <qlabel.h>
-#include <qimage.h>
-#include <qtooltip.h>
+#include <QLabel>
+#include <QImage>
+
 #include <qfile.h>
 #include <qiconset.h>
+#include <QPixmap>
 
-
+#include <kaction.h>
+#include <kactionmenu.h>
 #include <kconfig.h>
 #include <kdebug.h>
+#include <kglobal.h>
 #include <kinputdialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kpopupmenu.h>
-#include <ktempfile.h>
-#include <kmainwindow.h>
+#include <kmenu.h>
+#include <ktemporaryfile.h>
+#include <kxmlguiwindow.h>
+#include <kcomponentdata.h>
+#include <kactioncollection.h>
 #include <ktoolbar.h>
 #include <krun.h>
+#include <kicon.h>
 
 #include "kopetecontactaction.h"
 #include "kopetemetacontact.h"
@@ -48,15 +54,13 @@
 #include "msnaccount.h"
 #include "msnswitchboardsocket.h"
 
-#include "config.h"
-
 #if !defined NDEBUG
 #include "msndebugrawcmddlg.h"
 #endif
 
 MSNChatSession::MSNChatSession( Kopete::Protocol *protocol, const Kopete::Contact *user,
-	Kopete::ContactPtrList others, const char *name )
-: Kopete::ChatSession( user, others, protocol,  name )
+	Kopete::ContactPtrList others )
+: Kopete::ChatSession( user, others, protocol )
 {
 	Kopete::ChatSessionManager::self()->registerChatSession( this );
 	m_chatService = 0l;
@@ -64,45 +68,57 @@ MSNChatSession::MSNChatSession( Kopete::Protocol *protocol, const Kopete::Contac
 	m_newSession = true;
 	m_connectionTry=0;
 
-	setInstance(protocol->instance());
+	setComponentData(protocol->componentData());
 
 	connect( this, SIGNAL( messageSent( Kopete::Message&,
 		Kopete::ChatSession* ) ),
 		this, SLOT( slotMessageSent( Kopete::Message&,
 		Kopete::ChatSession* ) ) );
 
-	connect( this, SIGNAL( invitation(MSNInvitation*& ,  const QString & , long unsigned int , MSNChatSession*  , MSNContact*  ) ) ,
-		protocol,  SIGNAL( invitation(MSNInvitation*& ,  const QString & , long unsigned int , MSNChatSession*  , MSNContact*  ) ) );
+	connect( this, SIGNAL( invitation(MSNInvitation*& ,  const QString & , unsigned long int , MSNChatSession*  , MSNContact*  ) ) ,
+		protocol,  SIGNAL( invitation(MSNInvitation*& ,  const QString & , unsigned long int , MSNChatSession*  , MSNContact*  ) ) );
 
 
-	m_actionInvite = new KActionMenu( i18n( "&Invite" ), "kontact_contacts", actionCollection(), "msnInvite" );
-	connect ( m_actionInvite->popupMenu() , SIGNAL( aboutToShow() ) , this , SLOT(slotActionInviteAboutToShow() ) ) ;
+	m_actionInvite = new KActionMenu( KIcon("kontact_contacts"), i18n( "&Invite" ), this );
+        actionCollection()->addAction( "msnInvite", m_actionInvite );
+	connect ( m_actionInvite->menu() , SIGNAL( aboutToShow() ) , this , SLOT(slotActionInviteAboutToShow() ) ) ;
 
 	#if !defined NDEBUG
-	new KAction( i18n( "Send Raw C&ommand..." ), 0, this, SLOT( slotDebugRawCommand() ), actionCollection(), "msnDebugRawCommand" ) ;
+	KAction* rawCmd = new KAction( i18n( "Send Raw C&ommand..." ), this );
+        actionCollection()->addAction( "msnDebugRawCommand", rawCmd ) ;
+	connect( rawCmd, SIGNAL(triggered()), this, SLOT(slotDebugRawCommand()) );
 	#endif
 
+	m_actionNudge=new KAction( KIcon("preferences-desktop-notification-bell"), i18n( "Send Nudge" ), this );
+        actionCollection()->addAction( "msnSendNudge", m_actionNudge ) ;
+	connect( m_actionNudge, SIGNAL(triggered(bool)), this, SLOT(slotSendNudge()) );
 
-	m_actionNudge=new KAction( i18n( "Send Nudge" ), "bell", 0, this, SLOT(slotSendNudge() ), actionCollection(), "msnSendNudge" ) ;
-#if MSN_WEBCAM
 	// Invite to receive webcam action
-	m_actionWebcamReceive=new KAction( i18n( "View Contact's Webcam" ), "webcamreceive",  0, this, SLOT(slotWebcamReceive()), actionCollection(), "msnWebcamReceive" ) ;
-	
+	m_actionWebcamReceive=new KAction( KIcon("webcamreceive"), i18n( "View Contact's Webcam" ), this );
+        actionCollection()->addAction( "msnWebcamReceive", m_actionWebcamReceive ) ;
+	connect( m_actionWebcamReceive, SIGNAL(triggered(bool)), this, SLOT(slotWebcamReceive()) );
+
 	//Send webcam action
-	m_actionWebcamSend=new KAction( i18n( "Send Webcam" ), "webcamsend",  0, this, SLOT(slotWebcamSend()), actionCollection(), "msnWebcamSend" ) ;
-#endif
-	
-	new KAction( i18n( "Send File" ),"attach", 0, this, SLOT( slotSendFile() ), actionCollection(), "msnSendFile" );
+	m_actionWebcamSend=new KAction( KIcon("webcamsend"), i18n( "Send Webcam" ), this );
+        actionCollection()->addAction( "msnWebcamSend", m_actionWebcamSend ) ;
+	connect( m_actionWebcamSend, SIGNAL(triggered(bool)), this, SLOT(slotWebcamSend()) );
 
 	MSNContact *c = static_cast<MSNContact*>( others.first() );
-	(new KAction( i18n( "Request Display Picture" ), "image", 0,  this, SLOT( slotRequestPicture() ), actionCollection(), "msnRequestDisplayPicture" ))->setEnabled(!c->object().isEmpty());
+	KAction* requestPicture = new KAction( KIcon("image-x-generic"), i18n( "Request Display Picture" ), this );
+        actionCollection()->addAction( "msnRequestDisplayPicture", requestPicture );
+	requestPicture->setEnabled(!c->object().isEmpty());
+	connect( requestPicture, SIGNAL(triggered()), this, SLOT(slotRequestPicture()) );
 
 	if ( !c->object().isEmpty() )
 	{
-		
+
 		connect( c, SIGNAL( displayPictureChanged() ), this, SLOT( slotDisplayPictureChanged() ) );
-		m_image = new QLabel( 0L, "kde toolbar widget" );
-		new KWidgetAction( m_image, i18n( "MSN Display Picture" ), 0, this, SLOT( slotRequestPicture() ), actionCollection(), "msnDisplayPicture" );
+		m_image = new QLabel( 0L );
+		KAction *imageAction = new KAction( i18n( "MSN Display Picture" ), this );
+                actionCollection()->addAction( "msnDisplayPicture", imageAction );
+		imageAction->setDefaultWidget( m_image );
+		connect( imageAction, SIGNAL( triggered() ), this, SLOT( slotRequestPicture() ) );
+
 		if(c->hasProperty(Kopete::Global::Properties::self()->photo().key())  )
 		{
 			//if the view doesn't exist yet, we will be unable to get the size of the toolbar
@@ -120,7 +136,7 @@ MSNChatSession::MSNChatSession( Kopete::Protocol *protocol, const Kopete::Contac
 	}
 
 	setXMLFile("msnchatui.rc");
-	
+
 	setMayInvite( true );
 }
 
@@ -136,21 +152,22 @@ MSNChatSession::~MSNChatSession()
 	for( it = m_invitations.begin(); it != m_invitations.end() ; it = m_invitations.begin())
 	{
 		delete *it;
-		m_invitations.remove( it );
+		m_invitations.erase( it );
 	}
+	qDeleteAll(m_inviteactions);
 }
 
 void MSNChatSession::createChat( const QString &handle,
 	const QString &address, const QString &auth, const QString &ID )
 {
-	/* disabled because i don't want to reopen a chatwindow if we just closed it
+	/* disabled because i don't want to reopen a chat window if we just closed it
 	 * and the contact take much time to type his message
 	 m_newSession= !(ID.isEmpty());
 	*/
-	
+
 	if( m_chatService )
 	{
-		kdDebug(14140) << k_funcinfo << "Service already exists, disconnect them." << endl;
+		kDebug(14140) << "Service already exists, disconnect them.";
 		delete m_chatService;
 	}
 
@@ -173,13 +190,14 @@ void MSNChatSession::createChat( const QString &handle,
 		this, SLOT( slotSwitchBoardClosed() ) );
 	connect( m_chatService, SIGNAL( receivedTypingMsg( const QString &, bool ) ),
 		this, SLOT( receivedTypingMsg( const QString &, bool ) ) );
-	KConfig *config = KGlobal::config();
-	config->setGroup( "MSN" );
-	if(config->readBoolEntry( "SendTypingNotification" , true) )
+
+    KConfigGroup *config=account()->configGroup();
+	if ( config->readEntry( "SendTypingNotification", true ) )
 	{
 		connect( this, SIGNAL( myselfTyping( bool ) ),
 			m_chatService, SLOT( sendTypingMsg( bool ) ) );
 	}
+
 	connect( m_chatService, SIGNAL( msgAcknowledgement(unsigned int, bool) ),
 		this, SLOT( slotAcknowledgement(unsigned int, bool) ) );
 	connect( m_chatService, SIGNAL( invitation( const QString&, const QString& ) ),
@@ -187,45 +205,39 @@ void MSNChatSession::createChat( const QString &handle,
 	connect( m_chatService, SIGNAL( nudgeReceived(const QString&) ),
 		this, SLOT( slotNudgeReceived(const QString&) ) );
 	connect( m_chatService, SIGNAL( errorMessage(int, const QString& ) ), static_cast<MSNAccount *>(myself()->account()), SLOT( slotErrorMessageReceived(int, const QString& ) ) );
-	
+
 	if(!m_timeoutTimer)
 	{
 		m_timeoutTimer=new QTimer(this);
 		connect( m_timeoutTimer , SIGNAL(timeout()), this , SLOT(slotConnectionTimeout() ) );
 	}
-	m_timeoutTimer->start(20000,true);
+	m_timeoutTimer->setSingleShot(true);
+	m_timeoutTimer->start(20000);
 }
 
 void MSNChatSession::slotUserJoined( const QString &handle, const QString &publicName, bool IRO )
 {
 	delete m_timeoutTimer;
 	m_timeoutTimer=0L;
-	
+
 	if( !account()->contacts()[ handle ] )
-		account()->addContact( handle, QString::null, 0L, Kopete::Account::Temporary);
+		account()->addContact( handle, QString(), 0L, Kopete::Account::Temporary);
 
 	MSNContact *c = static_cast<MSNContact*>( account()->contacts()[ handle ] );
 
 	c->setProperty( Kopete::Global::Properties::self()->nickName() , publicName);
-	
+
 	if(c->clientFlags() & MSNProtocol::MSNC4 )
 	{
 		m_actionNudge->setEnabled(true);
 	}
-#if MSN_WEBCAM
-	if(c->clientFlags() & MSNProtocol::SupportWebcam )
-	{
-		m_actionWebcamReceive->setEnabled(true);
-	}
-#endif
 
 	addContact(c , IRO); // don't show notificaions when we join wesalef
 	if(!m_messagesQueue.empty() || !m_invitations.isEmpty())
 		sendMessageQueue();
 
-	KConfig *config = KGlobal::config();
-	config->setGroup( "MSN" );
-	if ( members().count()==1 && config->readNumEntry( "DownloadPicture", 1 ) >= 1 && !c->object().isEmpty() && !c->hasProperty(Kopete::Global::Properties::self()->photo().key()))
+    KConfigGroup *config=account()->configGroup();
+	if ( members().count()==1 && config->readEntry( "DownloadPicture", 1 ) >= 1 && !c->object().isEmpty() && !c->hasProperty(Kopete::Global::Properties::self()->photo().key()))
 		slotRequestPicture();
 }
 
@@ -240,7 +252,7 @@ void MSNChatSession::slotUserLeft( const QString &handle, const QString& reason
 
 void MSNChatSession::slotSwitchBoardClosed()
 {
-	//kdDebug(14140) << "MSNChatSession::slotSwitchBoardClosed"  << endl;
+	//kDebug(14140) << "MSNChatSession::slotSwitchBoardClosed";
 	m_chatService->deleteLater();
 	m_chatService=0l;
 
@@ -259,23 +271,23 @@ void MSNChatSession::slotMessageSent(Kopete::Message &message,Kopete::ChatSessio
 		if(id == -1)
 		{
 			m_messagesQueue.append(message);
-			kdDebug(14140) << k_funcinfo << "Message added to the queue" <<endl;
+			kDebug(14140) << "Message added to the queue";
 		}
 		else if( id== -2 ) //the message has not been sent
 		{
-			//FIXME:  tell the what window the message has been processed. but we havent't sent it 
+			//FIXME:  tell the what window the message has been processed. but we havent't sent it
 			messageSucceeded();  //that should stop the blonking icon.
 		}
 		else if( id == -3) //the message has been sent as an immge
 		{
-			appendMessage(message); 
+			appendMessage(message);
 			messageSucceeded();
 		}
 		else
 		{
 			m_messagesSent.insert( id, message );
-			message.setBg(QColor()); // clear the bgColor
-			message.setBody(message.plainBody() , Kopete::Message::PlainText ); //clear every custom tag which are not sent
+			message.setBackgroundColor(QColor()); // clear the bgColor
+			message.setPlainBody(message.plainBody() ); //clear every custom tag which are not sent
 			appendMessage(message); // send the own msg to chat window
 		}
 	}
@@ -294,7 +306,7 @@ void MSNChatSession::slotMessageReceived( Kopete::Message &msg )
 	if( msg.plainBody().startsWith( "AutoMessage: " ) )
 	{
 		//FIXME: HardCodded color are not so good
-		msg.setFg( QColor( "SlateGray3" ) );
+		msg.setForegroundColor( QColor( "SlateGray3" ) );
 		QFont f;
 		f.setItalic( true );
 		msg.setFont( f );
@@ -307,31 +319,34 @@ void MSNChatSession::slotActionInviteAboutToShow()
 	// We can't simply insert  KAction in this menu bebause we don't know when to delete them.
 	//  items inserted with insert items are automatically deleted when we call clear
 
-	m_inviteactions.setAutoDelete(true);
+	qDeleteAll(m_inviteactions);
 	m_inviteactions.clear();
 
-	m_actionInvite->popupMenu()->clear();
+	m_actionInvite->menu()->clear();
 
-	
-	QDictIterator<Kopete::Contact> it( account()->contacts() );
-	for( ; it.current(); ++it )
+
+	QHash<QString, Kopete::Contact*> contactList = account()->contacts();
+	QHash<QString, Kopete::Contact*>::Iterator it, itEnd = contactList.end();
+	for( it = contactList.begin(); it != itEnd; ++it )
 	{
-		if( !members().contains( it.current() ) && it.current()->isOnline() && it.current() != myself() )
+		if( !members().contains( it.value() ) && it.value()->isOnline() && it.value() != myself() )
 		{
-			KAction *a=new KopeteContactAction( it.current(), this,
-				SLOT( slotInviteContact( Kopete::Contact * ) ), m_actionInvite );
-			m_actionInvite->insert( a );
+			KAction *a = new Kopete::UI::ContactAction( it.value(), actionCollection() );
+			m_actionInvite->addAction( a );
 			m_inviteactions.append( a ) ;
 		}
 	}
-	KAction *b=new KAction( i18n ("Other..."), 0, this, SLOT( slotInviteOtherContact() ), m_actionInvite, "actionOther" );
-	m_actionInvite->insert( b );
+	KAction *b = new KAction( i18n ("Other..."), actionCollection() );
+        actionCollection()->addAction( "actionOther", b );
+	QObject::connect( b, SIGNAL( triggered( bool ) ),
+	                  this, SLOT( slotInviteOtherContact() ) );
+	m_actionInvite->addAction( b );
 	m_inviteactions.append( b ) ;
 }
 
 void MSNChatSession::slotCloseSession()
 {
-	kdDebug(14140) << k_funcinfo  << m_chatService <<endl;
+	kDebug(14140) << m_chatService;
 	if(m_chatService)
 		m_chatService->slotCloseSession();
 }
@@ -355,11 +370,11 @@ void MSNChatSession::slotInviteOtherContact()
 	bool ok;
 	QString handle = KInputDialog::getText(i18n( "MSN Plugin" ),
 			i18n( "Please enter the email address of the person you want to invite:" ),
-			QString::null, &ok );
+			QString(), &ok );
 	if( !ok )
 		return;
 
-	if( handle.contains('@') != 1 || handle.contains('.') <1)
+	if( handle.count(QChar('@')) != 1 || handle.count(QChar('.')) <1)
 	{
 			KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Sorry,
 					i18n("<qt>You must enter a valid email address.</qt>"), i18n("MSN Plugin"));
@@ -374,25 +389,26 @@ void MSNChatSession::sendMessageQueue()
 {
 	if(!m_chatService)
 	{
-		kdDebug(14140) <<k_funcinfo << "Service doesn't exist" <<endl;
+		kDebug(14140) << "Service doesn't exist";
 		return;
 	}
-//	kdDebug(14140) << "MSNChatSession::sendMessageQueue: " << m_messagesQueue.count() <<endl;
-	for ( QValueList<Kopete::Message>::iterator it = m_messagesQueue.begin(); it!=m_messagesQueue.end(); it = m_messagesQueue.begin() )
+//	kDebug(14140) << "MSNChatSession::sendMessageQueue: " << m_messagesQueue.count();
+	QList<Kopete::Message>::Iterator it;
+	for ( it = m_messagesQueue.begin(); it!=m_messagesQueue.end(); it = m_messagesQueue.begin() )
 	{
 		//m_chatService->sendMsg( *it)  ;
 		slotMessageSent(*it , this);
-		m_messagesQueue.remove(it);
+		m_messagesQueue.erase(it);
 	}
 
 
-	QMap<unsigned long int, MSNInvitation*>::Iterator it;
-	for( it = m_invitations.begin(); it != m_invitations.end() ; ++it)
+	QMap<unsigned long int, MSNInvitation*>::Iterator mapIt;
+	for( mapIt = m_invitations.begin(); mapIt != m_invitations.end() ; ++mapIt)
 	{
-		if(! (*it)->incoming() && (*it)->state()<MSNInvitation::Invited)
+		if(! (*mapIt)->incoming() && (*mapIt)->state()<MSNInvitation::Invited)
 		{
-			m_chatService->sendCommand( "MSG" , "N", true, (*it)->invitationHead().utf8() );
-			(*it)->setState(MSNInvitation::Invited);
+			m_chatService->sendCommand( "MSG" , "N", true, (*mapIt)->invitationHead().toUtf8() );
+			(*mapIt)->setState(MSNInvitation::Invited);
 		}
 	}
 }
@@ -408,11 +424,14 @@ void MSNChatSession::slotAcknowledgement(unsigned int id, bool ack)
 	if ( !ack )
 	{
 		Kopete::Message m = m_messagesSent[ id ];
-		QString body = i18n( "The following message has not been sent correctly:\n%1" ).arg( m.plainBody() );
-		Kopete::Message msg = Kopete::Message( m.to().first(), members(), body, Kopete::Message::Internal, Kopete::Message::PlainText );
+		QString body = i18n( "The following message has not been sent correctly:\n%1", m.plainBody() );
+		Kopete::Message msg = Kopete::Message( m.to().first(), members() );
+		msg.setDirection( Kopete::Message::Internal );
+		msg.setPlainBody( body );
+
 		appendMessage( msg );
 		//stop the stupid animation
-		messageSucceeded();  
+		messageSucceeded();
 	}
 	else
 	{
@@ -430,7 +449,7 @@ void MSNChatSession::slotInvitation(const QString &handle, const QString &msg)
 		return;
 
 	QRegExp rx("Invitation-Cookie: ([0-9]*)");
-	rx.search(msg);
+	rx.indexIn(msg);
 	long unsigned int cookie=rx.cap(1).toUInt();
 
 	if(m_invitations.contains(cookie))
@@ -461,14 +480,17 @@ void MSNChatSession::slotInvitation(const QString &handle, const QString &msg)
 			else
 			{
 				rx=QRegExp("Application-Name: ([^\\r\\n]*)");
-				rx.search(msg);
+				rx.indexIn(msg);
 				QString inviteName = rx.cap( 1 );
 
 				QString body = i18n(
-					"%1 has sent an unimplemented invitation, the invitation was rejected.\n"
-					"The invitation was: %2" )
-						.arg( c->property( Kopete::Global::Properties::self()->nickName()).value().toString(), inviteName );
-				Kopete::Message tmpMsg = Kopete::Message( c , members() , body , Kopete::Message::Internal, Kopete::Message::PlainText);
+					"%1 has sent an unimplemented invitation which was rejected.\n"
+					"The invitation was: %2",
+						c->property( Kopete::Global::Properties::self()->nickName()).value().toString(), inviteName );
+				Kopete::Message tmpMsg = Kopete::Message( c , members() );
+				tmpMsg.setDirection( Kopete::Message::Internal );
+				tmpMsg.setPlainBody( body );
+
 				appendMessage(tmpMsg);
 
 				m_chatService->sendCommand( "MSG" , "N", true, MSNInvitation::unimplemented(cookie) );
@@ -479,7 +501,7 @@ void MSNChatSession::slotInvitation(const QString &handle, const QString &msg)
 
 void MSNChatSession::invitationDone(MSNInvitation* MFTS)
 {
-	kdDebug(14140) << k_funcinfo <<endl;
+	kDebug(14140) ;
 	m_invitations.remove(MFTS->cookie());
 //	MFTS->deleteLater();
 	delete MFTS;
@@ -491,9 +513,9 @@ void MSNChatSession::sendFile(const QString &fileLocation, const QString &/*file
 	long unsigned int fileSize)
 {
 	// TODO create a switchboard to send the file is one is not available.
-	if(m_chatService && members().getFirst())
+	if(m_chatService && (*members().begin()))
 	{
-		m_chatService->PeerDispatcher()->sendFile(fileLocation, (Q_INT64)fileSize, members().getFirst()->contactId());
+		m_chatService->PeerDispatcher()->sendFile(fileLocation, (qint64)fileSize, (*members().begin())->contactId());
 	}
 }
 
@@ -504,7 +526,7 @@ void MSNChatSession::initInvitation(MSNInvitation* invitation)
 
 	if(m_chatService)
 	{
-		m_chatService->sendCommand( "MSG" , "N", true, invitation->invitationHead().utf8() );
+		m_chatService->sendCommand( "MSG" , "N", true, invitation->invitationHead().toUtf8() );
 		invitation->setState(MSNInvitation::Invited);
 	}
 	else
@@ -515,11 +537,11 @@ void MSNChatSession::initInvitation(MSNInvitation* invitation)
 
 void MSNChatSession::slotRequestPicture()
 {
-	QPtrList<Kopete::Contact> mb=members();
+	QList<Kopete::Contact*> mb=members();
 	MSNContact *c = static_cast<MSNContact*>( mb.first() );
 	if(!c)
 	 return;
-	
+
 	if( !c->hasProperty(Kopete::Global::Properties::self()->photo().key()))
 	{
 		if(m_chatService)
@@ -532,61 +554,70 @@ void MSNChatSession::slotRequestPicture()
 	}
 	else
 	{ //we already have the picture, just show it.
-		KRun::runURL( KURL::fromPathOrURL( c->property(Kopete::Global::Properties::self()->photo()).value().toString() ), "image/png" );
+		KRun::runUrl( KUrl( c->property(Kopete::Global::Properties::self()->photo()).value().toString() ), "image/png" , 0l );
 	}
 
 }
 
 void MSNChatSession::slotDisplayPictureChanged()
 {
-	QPtrList<Kopete::Contact> mb=members();
+	QList<Kopete::Contact*> mb=members();
 	MSNContact *c = static_cast<MSNContact *>( mb.first() );
 	if ( c && m_image )
 	{
 		if(c->hasProperty(Kopete::Global::Properties::self()->photo().key()))
 		{
+#ifdef __GNUC__
+#warning Port or remove this KToolBar hack
+#endif
+#if 0
 			int sz=22;
 			// get the size of the toolbar were the aciton is plugged.
 			//  if you know a better way to get the toolbar, let me know
-			KMainWindow *w= view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) : 0L;
+			KXmlGuiWindow *w= view(false) ? dynamic_cast<KXmlGuiWindow*>( view(false)->mainWidget()->topLevelWidget() ) : 0L;
 			if(w)
 			{
 				//We connected that in the constructor.  we don't need to keep this slot active.
 				disconnect( Kopete::ChatSessionManager::self() , SIGNAL(viewActivated(KopeteView* )) , this, SLOT(slotDisplayPictureChanged()) );
-			
-				QPtrListIterator<KToolBar>  it=w->toolBarIterator() ;
+
+
 				KAction *imgAction=actionCollection()->action("msnDisplayPicture");
-				if(imgAction)  while(it)
+				if(imgAction)
 				{
-					KToolBar *tb=*it;
-					if(imgAction->isPlugged(tb))
+					QList<KToolBar*> toolbarList = w->toolBarList();
+					QList<KToolBar*>::Iterator it, itEnd = toolbarList.end();
+					for(it = toolbarList.begin(); it != itEnd; ++it)
 					{
-						sz=tb->iconSize();
-						//ipdate if the size of the toolbar change.
-						disconnect(tb, SIGNAL(modechange()), this, SLOT(slotDisplayPictureChanged()));
-						connect(tb, SIGNAL(modechange()), this, SLOT(slotDisplayPictureChanged()));
-						break;
+						KToolBar *tb=*it;
+						if(imgAction->isPlugged(tb))
+						{
+							sz=tb->iconSize();
+							//ipdate if the size of the toolbar change.
+							disconnect(tb, SIGNAL(modechange()), this, SLOT(slotDisplayPictureChanged()));
+							connect(tb, SIGNAL(modechange()), this, SLOT(slotDisplayPictureChanged()));
+							break;
+						}
 					}
-					++it;
 				}
+
 			}
+
 			QString imgURL=c->property(Kopete::Global::Properties::self()->photo()).value().toString();
-			QImage scaledImg = QPixmap( imgURL ).convertToImage().smoothScale( sz, sz );
+			QImage scaledImg = QPixmap( imgURL ).toImage().smoothScale( sz, sz );
 			if(!scaledImg.isNull())
-				m_image->setPixmap( scaledImg );
+				m_image->setPixmap( QPixmap::fromImage(scaledImg) );
 			else
 			{ //the image has maybe not been transfered correctly..  force to download again
 				c->removeProperty(Kopete::Global::Properties::self()->photo());
 				//slotDisplayPictureChanged(); //don't do that or we might end in a infinite loop
 			}
-			QToolTip::add( m_image, "<qt><img src=\"" + imgURL + "\"></qt>" );
-			
+			m_image->setToolTip( "<qt><img src=\"" + imgURL + "\"></qt>" );
+#endif
 		}
-		else 
+		else
 		{
-			KConfig *config = KGlobal::config();
-			config->setGroup( "MSN" );
-			if ( config->readNumEntry( "DownloadPicture", 1 ) >= 1 && !c->object().isEmpty() )
+            KConfigGroup *config=account()->configGroup();
+			if ( config->readEntry( "DownloadPicture", 1 ) >= 1 && !c->object().isEmpty() )
 				slotRequestPicture();
 		}
 	}
@@ -603,7 +634,7 @@ void MSNChatSession::slotDebugRawCommand()
 	if( result == QDialog::Accepted && m_chatService )
 	{
 		m_chatService->sendCommand( dlg->command(), dlg->params(),
-					dlg->addId(), dlg->msg().replace("\n","\r\n").utf8() );
+					dlg->addId(), dlg->msg().replace("\n","\r\n").toUtf8() );
 	}
 	delete dlg;
 #endif
@@ -616,13 +647,14 @@ void MSNChatSession::receivedTypingMsg( const QString &contactId, bool b )
 	if(c && m_newSession &&  !view(false))
 	{
 		//this was originaly in MSNAccount::slotCreateChat
-		KGlobal::config()->setGroup( "MSN" );
-		bool notifyNewChat = KGlobal::config()->readBoolEntry( "NotifyNewChat", false );
-		if (  notifyNewChat  )
+        KConfigGroup *config=account()->configGroup();
+        if (  config->readEntry( "NotifyNewChat", false )  )
 		{
 			// this internal message should open the window if they not exist
-			QString body = i18n( "%1 has started a chat with you" ).arg( c->metaContact()->displayName() );
-			Kopete::Message tmpMsg = Kopete::Message( c, members(), body, Kopete::Message::Internal, Kopete::Message::PlainText );
+			QString body = i18n( "%1 has started a chat with you", c->metaContact()->displayName() );
+			Kopete::Message tmpMsg = Kopete::Message( c, members() );
+			tmpMsg.setDirection( Kopete::Message::Internal );
+			tmpMsg.setPlainBody( body );
 			appendMessage( tmpMsg );
 		}
 	}
@@ -636,8 +668,11 @@ void MSNChatSession::slotSendNudge()
 	if(m_chatService)
 	{
 		m_chatService->sendNudge();
-		Kopete::Message msg = Kopete::Message( myself(), members() , i18n ( "has sent a nudge" ),  Kopete::Message::Outbound, 
-											   Kopete::Message::PlainText, QString(), Kopete::Message::TypeAction );
+		Kopete::Message msg = Kopete::Message( myself(), members() );
+		msg.setDirection( Kopete::Message::Outbound );
+		msg.setType( Kopete::Message::TypeAction );
+		msg.setPlainBody( i18n("has sent a nudge") );
+
 		appendMessage( msg );
 
 	}
@@ -648,9 +683,11 @@ void MSNChatSession::slotNudgeReceived(const QString& handle)
 {
 	Kopete::Contact *c = account()->contacts()[ handle ] ;
 	if(!c)
-		c=members().getFirst();
-	Kopete::Message msg = Kopete::Message(c, myself(), i18n ( "has sent you a nudge" ), Kopete::Message::Inbound, 
-										  Kopete::Message::PlainText, QString(), Kopete::Message::TypeAction );
+		c=members().first();
+	Kopete::Message msg = Kopete::Message(c, myself() );
+	msg.setDirection( Kopete::Message::Inbound );
+	msg.setType( Kopete::Message::TypeAction );
+	msg.setPlainBody( i18n("has sent you a nudge") );
 	appendMessage( msg );
 	// Emit the nudge/buzz notification (configured by user).
 	emitNudgeNotification();
@@ -659,43 +696,43 @@ void MSNChatSession::slotNudgeReceived(const QString& handle)
 
 void MSNChatSession::slotWebcamReceive()
 {
-#if MSN_WEBCAM
-	if(m_chatService && members().getFirst())
+	if(m_chatService && !members().isEmpty())
 	{
-		m_chatService->PeerDispatcher()->startWebcam(myself()->contactId() , members().getFirst()->contactId() , true);
-	}
+#if 0
+		m_chatService->PeerDispatcher()->startWebcam(myself()->contactId() , members().first()->contactId() , true);
 #endif
+	}
 }
 
 void MSNChatSession::slotWebcamSend()
 {
-#if MSN_WEBCAM
-	kdDebug(14140) << k_funcinfo << endl;
-	if(m_chatService && members().getFirst())
+	kDebug(14140) ;
+	if(m_chatService && !members().isEmpty())
 	{
-		m_chatService->PeerDispatcher()->startWebcam(myself()->contactId() , members().getFirst()->contactId() , false);
-	}
+#if 0
+		m_chatService->PeerDispatcher()->startWebcam(myself()->contactId() , members().first()->contactId() , false);
 #endif
+	}
 }
 
 
 void MSNChatSession::slotSendFile()
-      {
-              QPtrList<Kopete::Contact>contacts = members();
-              static_cast<MSNContact *>(contacts.first())->sendFile();
-      }
+{
+	static_cast<MSNContact *>(members().first())->sendFile();
+}
 
 void MSNChatSession::startChatSession()
 {
-	QPtrList<Kopete::Contact> mb=members();
+	QList<Kopete::Contact*> mb=members();
 	static_cast<MSNAccount*>( account() )->slotStartChatSession( mb.first()->contactId() );
-	
+
 	if(!m_timeoutTimer)
 	{
 		m_timeoutTimer=new QTimer(this);
 		connect( m_timeoutTimer , SIGNAL(timeout()), this , SLOT(slotConnectionTimeout() ) );
 	}
-	m_timeoutTimer->start(20000, true);
+	m_timeoutTimer->setSingleShot(true);
+	m_timeoutTimer->start(20000);
 }
 
 
@@ -713,30 +750,37 @@ void MSNChatSession::cleanMessageQueue( const QString & reason )
 		if(m_messagesQueue.count() == 1)
 			m=m_messagesQueue.first();
 		else
-			m=m_messagesSent.begin().data();
-		
-		QString body=i18n("The following message has not been sent correctly  (%1): \n%2").arg(reason, m.plainBody());
-		Kopete::Message msg = Kopete::Message(m.to().first() , members() , body , Kopete::Message::Internal, Kopete::Message::PlainText);
+			m=m_messagesSent.begin().value();
+
+		QString body=i18n("The following message has not been sent correctly  (%1): \n%2", reason, m.plainBody());
+		Kopete::Message msg = Kopete::Message(m.to().first(), members() );
+		msg.setDirection( Kopete::Message::Internal );
+		msg.setPlainBody( body );
 		appendMessage(msg);
 	}
 	else
 	{
 		Kopete::Message m;
-		QString body=i18n("These messages have not been sent correctly (%1): <br /><ul>").arg(reason);
-		for ( QMap<unsigned int , Kopete::Message>::iterator it = m_messagesSent.begin(); it!=m_messagesSent.end(); it = m_messagesSent.begin() )
+		QString body=i18n("These messages have not been sent correctly (%1): <br /><ul>", reason);
+
+		QMap<unsigned int, Kopete::Message>::Iterator mapIt;
+		for (  mapIt = m_messagesSent.begin(); mapIt!=m_messagesSent.end(); mapIt = m_messagesSent.begin() )
 		{
-			m=it.data();
+			m=mapIt.value();
 			body+= "<li>"+m.escapedBody()+"</li>";
-			m_messagesSent.remove(it);
+			m_messagesSent.erase(mapIt);
 		}
-		for ( QValueList<Kopete::Message>::iterator it = m_messagesQueue.begin(); it!=m_messagesQueue.end(); it = m_messagesQueue.begin() )
+		QList<Kopete::Message>::Iterator messageIt;
+		for ( messageIt = m_messagesQueue.begin(); messageIt!=m_messagesQueue.end(); messageIt = m_messagesQueue.begin() )
 		{
-			m=(*it);
+			m=(*messageIt);
 			body+= "<li>"+m.escapedBody()+"</li>";
-			m_messagesQueue.remove(it);
+			m_messagesQueue.erase(messageIt);
 		}
 		body+="</ul>";
-		Kopete::Message msg = Kopete::Message(m.to().first() , members() , body , Kopete::Message::Internal, Kopete::Message::RichText);
+		Kopete::Message msg = Kopete::Message(m.to().first(), members());
+		msg.setDirection( Kopete::Message::Internal );
+		msg.setHtmlBody( body );
 		appendMessage(msg);
 
 	}
@@ -754,7 +798,7 @@ void MSNChatSession::slotConnectionTimeout()
 		m_chatService->deleteLater();
 		m_chatService=0L;
 	}
-	
+
 	if( m_connectionTry > 3 )
 	{
 		cleanMessageQueue( i18n("Impossible to establish the connection") );
@@ -766,9 +810,6 @@ void MSNChatSession::slotConnectionTimeout()
 
 }
 
-
-
-
 #include "msnchatsession.moc"
 
 // vim: set noet ts=4 sts=4 sw=4:
