@@ -1,7 +1,9 @@
 /*
     msnp2p.cpp - msn p2p protocol
 
-    Copyright (c) 2003-2005 by Olivier Goffart        <ogoffart@ kde.org>
+    Copyright (c) 2003-2005 by Olivier Goffart        <ogoffart@kde.org>
+
+    Kopete    (c) 2002-2007 by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -25,11 +27,13 @@
 #include <qregexp.h>
 #include <qfile.h>
 #include <qtextcodec.h>
+//Added by qt3to4:
+#include <QByteArray>
 
 // kde
 #include <kdebug.h>
-#include <kmdcodec.h>
-#include <ktempfile.h>
+#include <kcodecs.h>
+#include <ktemporaryfile.h>
 #include <krun.h>
 #include <klocale.h>
 #include <kglobal.h>
@@ -40,8 +44,15 @@
 //kopete
 #include <kopetetransfermanager.h>
 
-
-
+/**
+ * if VAR is a char*  and VAL is an integer, assing VAR[START] to VAR[START+4]  the value of VAL
+ */
+#define MKDWORD(VAR, START, VAL) {\
+	(VAR)[(START)]=  (char)( ((VAL)&0x000000FF) ) ;  \
+	(VAR)[(START)+1]=(char)( ((VAL)&0x0000FF00)  >> 8 ) ; \
+	(VAR)[(START)+2]=(char)( ((VAL)&0x00FF0000)  >> 16 ) ; \
+	(VAR)[(START)+3]=(char)( ((VAL)&0xFF000000)  >> 24 ) ; \
+}
 
 MSNP2P::MSNP2P( unsigned long int sessionID , MSNP2PDisplatcher *parent ) : QObject (parent)
 {
@@ -75,6 +86,8 @@ void MSNP2P::makeMSNSLPMessage( MessageType type, QString content )
 	{
 		case INVITE:
 			method="INVITE MSNMSGR:"+ m_msgHandle + "  MSNSLP/1.0";
+			if(!content.contains("AppID"))
+				contentType="application/x-msnmsgr-transreqbody";
 			CSeq="0";
 			break;
 		case DECLINE:
@@ -102,20 +115,19 @@ void MSNP2P::makeMSNSLPMessage( MessageType type, QString content )
 			break;
 	}
 
-	QCString dataMessage= QString(
+	QByteArray dataMessage= QString(
 			method + "\r\n"
 			"To: <msnmsgr:"+m_msgHandle+">\r\n"
 			"From: <msnmsgr:"+m_myHandle+">\r\n"
-			"Via: MSNSLP/1.0/TLP ;branch={"+m_branch.upper()+"}\r\n"
+			"Via: MSNSLP/1.0/TLP ;branch={"+m_branch.toUpper()+"}\r\n"
 			"CSeq: "+ CSeq +"\r\n"
-			"Call-ID: {"+m_CallID.upper()+"}\r\n"
+			"Call-ID: {"+m_CallID.toUpper()+"}\r\n"
 			"Max-Forwards: 0\r\n"
 			"Content-Type: "+ contentType +"\r\n"
 			"Content-Length: "+ QString::number(content.length()+1)+"\r\n"
-			"\r\n" + content ).utf8(); //\0
-	//the data message must be end by \0,  bye chance, QCString automaticaly appends \0 at the end of the QByteArray
+			"\r\n" + content ).toUtf8(); //\0
 
-	kdDebug(14141) << k_funcinfo << dataMessage << endl;
+	kDebug(14141) << dataMessage;
 
 	sendP2PMessage(dataMessage);
 }
@@ -123,10 +135,10 @@ void MSNP2P::makeMSNSLPMessage( MessageType type, QString content )
 
 void MSNP2P::sendP2PMessage(const QByteArray &dataMessage)
 {
-	const QCString messageHeader=QString(
+	const QByteArray messageHeader=QString(
 			"MIME-Version: 1.0\r\n"
 			"Content-Type: application/x-msnmsgrp2p\r\n"
-			"P2P-Dest: "+ m_msgHandle  +"\r\n\r\n").utf8();
+			"P2P-Dest: "+ m_msgHandle  +"\r\n\r\n").toUtf8();
 	const uint messageHeaderLength = messageHeader.length();
 
 
@@ -139,33 +151,20 @@ void MSNP2P::sendP2PMessage(const QByteArray &dataMessage)
 		m_msgIdentifier++;
 
 
-	//SessionID     (it's byll if the transfer has not started.  (i.e the footer == 0)
-	unsigned long int sessionID= m_footer ? m_sessionId : 0;
-	binHeader[0]=(char)(sessionID%256);
-	binHeader[1]=(char)((unsigned long int)(sessionID/256)%256);
-	binHeader[2]=(char)((unsigned long int)(sessionID/(256*256))%256);
-	binHeader[3]=(char)((unsigned long int)(sessionID/(256*256*256))%256);
+	//SessionID     (it's nyll if the transfer has not started.  (i.e the footer == 0)
+	if(m_footer)
+		MKDWORD(binHeader,0,m_sessionId);
 
 	//MessageID
-	binHeader[4]=(char)(m_msgIdentifier%256);
-	binHeader[5]=(char)((unsigned long int)(m_msgIdentifier/256)%256);
-	binHeader[6]=(char)((unsigned long int)(m_msgIdentifier/(256*256))%256);
-	binHeader[7]=(char)((unsigned long int)(m_msgIdentifier/(256*256*256))%256);
+	MKDWORD(binHeader,4,m_msgIdentifier);
 
 	//offset
-	binHeader[8]=(char)(m_offset%256);
-	binHeader[9]=(char)((unsigned long int)(m_offset/256)%256);
-	binHeader[10]=(char)((unsigned long int)(m_offset/(256*256))%256);
-	binHeader[11]=(char)((unsigned long int)(m_offset/(256*256*256))%256);
+	MKDWORD(binHeader,8,m_offset);
 
 	unsigned int size=dataMessage.size();
-
 	if(m_totalDataSize) //it's a splitted message
 	{
-		binHeader[16]=(char)(m_totalDataSize%256);
-		binHeader[17]=(char)((unsigned long int)(m_totalDataSize/256)%256);
-		binHeader[18]=(char)((unsigned long int)(m_totalDataSize/(256*256))%256);
-		binHeader[19]=(char)((unsigned long int)(m_totalDataSize/(256*256*256))%256);
+		MKDWORD(binHeader,16,m_totalDataSize);
 
 		//update offset
 		m_offset+=size;
@@ -177,13 +176,11 @@ void MSNP2P::sendP2PMessage(const QByteArray &dataMessage)
 	}
 	else //not a splitted message, the total size is the current size
 	{
-		binHeader[16]=(char)size%256;
-		binHeader[17]=(int)size/256;
+		MKDWORD(binHeader,16,size);
 	}
 
 	//message size
-	binHeader[24]=(char)size%256;
-	binHeader[25]=(int)size/256;
+	MKDWORD(binHeader,24,size);
 
 	if(m_footer=='\1' && size>4)
 	{	//when sending the data of an image, the flag is set to 0x20
@@ -192,15 +189,15 @@ void MSNP2P::sendP2PMessage(const QByteArray &dataMessage)
 	}
 
 	//Ack sessionID
-	binHeader[32]=(char)(rand()%256);
-	binHeader[33]=(char)(rand()%256);
-	binHeader[34]=(char)(rand()%256);
-	binHeader[35]=(char)(rand()%256);
-
-	/*binHeader[32]=0xDE;
+//#if ! MSN_WEBCAM
+	MKDWORD(binHeader,32,rand()%0x8FFFFFF0+4);
+//#else
+	//For webcam, the OK and INVITE message should have the smae id, but not others.
+	binHeader[32]=0xDE;
 	binHeader[33]=0xC7;
 	binHeader[34]=0x07;
-	binHeader[35]=0x14;*/
+	binHeader[35]=0x14;
+#endif
 
 
 	//merge all in a unique message
@@ -223,10 +220,10 @@ void MSNP2P::sendP2PMessage(const QByteArray &dataMessage)
 void MSNP2P::sendP2PAck( const char* originalHeader )
 {
 
-	const QCString messageHeader=QString(
+	const QByteArray messageHeader=QString(
 			"MIME-Version: 1.0\r\n"
 			"Content-Type: application/x-msnmsgrp2p\r\n"
-			"P2P-Dest: "+ m_msgHandle  +"\r\n\r\n").utf8();
+			"P2P-Dest: "+ m_msgHandle  +"\r\n\r\n").toUtf8();
 	const uint messageHeaderLength = messageHeader.length();
 
 
@@ -248,10 +245,7 @@ void MSNP2P::sendP2PAck( const char* originalHeader )
 	}
 	else
 		m_msgIdentifier++;
-	binHeader[4]=(char)(m_msgIdentifier%256);
-	binHeader[5]=(char)((unsigned long int)(m_msgIdentifier/256)%256);
-	binHeader[6]=(char)((unsigned long int)(m_msgIdentifier/(256*256))%256);
-	binHeader[7]=(char)((unsigned long int)(m_msgIdentifier/(256*256*256))%256);
+	MKDWORD(binHeader,4,m_msgIdentifier);
 
 	if(a)
 		m_msgIdentifier-=4;
@@ -305,8 +299,8 @@ void MSNP2P::sendP2PAck( const char* originalHeader )
 
 void MSNP2P::error()
 {
-	kdDebug(14140) << k_funcinfo   << endl;
-	makeMSNSLPMessage( ERROR, QString::null );
+	kDebug(14140) ;
+	makeMSNSLPMessage( ERROR, QString() );
 	m_parent->finished(this);
 }
 
@@ -316,7 +310,7 @@ void MSNP2P::parseMessage(MessageStruct &msgStr)
 	if(m_msgHandle.isEmpty())
 	{ //if these addresses were not previously set, get it, they should be provided in the first message at last.
 
-		QString dataMessage=QCString((msgStr.message.data()+48) , msgStr.dataMessageSize);
+		QString dataMessage=QByteArray((msgStr.message.data()+48) , msgStr.dataMessageSize);
 
 		QRegExp rx("To: <msnmsgr:([^>]*)>");
 		if( rx.search( dataMessage ) != -1 )
@@ -332,6 +326,162 @@ void MSNP2P::parseMessage(MessageStruct &msgStr)
 		sendP2PAck( msgStr.message.data() );
 }
 
+//---------------------------------------------------------------
+
+#if 0
+//#if MSN_WEBCAM
+
+MSNP2PWebcam::MSNP2PWebcam( unsigned long int sessionID , MSNP2PDisplatcher *parent )
+	: MSNP2P(sessionID , parent)
+{
+}
+
+MSNP2PWebcam::~MSNP2PWebcam()
+{
+}
+
+
+
+
+
+void MSNP2PWebcam::parseMessage(MessageStruct &msgStr)
+{
+	MSNP2P::parseMessage(msgStr);
+	if(msgStr.message[msgStr.message.size()-1]!='\4')
+		return;
+
+	QByteArray dataMessage;
+	dataMessage.duplicate((char*)(msgStr.message.data()+48) , msgStr.dataMessageSize);
+	QString echoS="";
+	//QString debug2="";
+
+	unsigned int f=0;
+	while(f<dataMessage.size())
+	{
+		echoS+='\n';
+		
+		for(unsigned int q=0; q<16 ; q++)
+		{
+			if(q+f<dataMessage.size())
+			{
+				unsigned int N=(unsigned int) (dataMessage[q+f]);
+				if(N<16)
+					echoS+='0';
+				echoS+=QString::number( N  ,16)+' ';
+			}
+			else
+				echoS+="   ";
+		}
+		echoS+="   ";
+		
+		for(unsigned int q=0; (q<16 && (q+f)<dataMessage.size()) ; q++)
+		{
+			unsigned char X=dataMessage[q+f];
+			char C=((char)(( X<128 && X>31 ) ? X : '.'));
+			echoS+=QString::fromLatin1(&C,1);
+		}
+
+		f+=16;
+	}
+	
+	kDebug(14141) << dataMessage.size() << echoS;
+
+	for(uint pos=m_content.isNull() ? 10 : 0; pos<dataMessage.size(); pos+=2)
+	{
+		m_content+=dataMessage[pos];
+	}
+
+	if( msgStr.dataMessageSize+msgStr.dataOffset < msgStr.totalSize )
+		return;
+	
+	kDebug(14141) << "Message contents: " << m_content << '\n';
+	if(m_content.length() < 5)
+		makeSIPMessage(m_content);
+	else if(m_content.contains("<producer>"))
+	{
+		makeSIPMessage(m_content.replace("producer","viewer"));
+	}
+	m_content.clear();
+}
+
+void MSNP2PWebcam::makeSIPMessage(const QString &message)
+{
+	QByteArray  dataMessage(10+message.length()*2);
+	dataMessage[0]=0x80;
+	dataMessage[1]=0x17;
+	dataMessage[2]=0x2a;
+	dataMessage[3]=0x01;
+	dataMessage[4]=0x08;
+	dataMessage[5]=0x00;
+	dataMessage[6]=message.length()*2+2;
+	dataMessage[7]=0x00;
+	dataMessage[8]=0x00;
+	dataMessage[9]=0x00;
+	for(uint f=0; f<message.length(); f++)
+	{
+		dataMessage[10+2*f]=message[f].toLatin1();
+		dataMessage[11+2*f]=0x00;
+	}
+
+	QString echoS="";
+	//QString debug2="";
+
+	unsigned int f=0;
+	while(f<dataMessage.size())
+	{
+		echoS+='\n';
+		
+		for(unsigned int q=0; q<16 ; q++)
+		{
+			if(q+f<dataMessage.size())
+			{
+				unsigned int N=(unsigned int) (dataMessage[q+f]);
+				if(N<16)
+					echoS+='0';
+				echoS+=QString::number( N  ,16)+' ';
+			}
+			else
+				echoS+="   ";
+		}
+		echoS+="   ";
+		
+		for(unsigned int q=0; (q<16 && (q+f)<dataMessage.size()) ; q++)
+		{
+			unsigned char X=dataMessage[q+f];
+			char C=((char)(( X<128 && X>31 ) ? X : '.'));
+			echoS+=QString::fromLatin1(&C,1);
+		}
+
+		f+=16;
+	}
+	
+	kDebug(14141) << dataMessage.size() << echoS;
+
+	m_footer='\4';
+	sendBigP2PMessage(dataMessage);
+	m_footer='\0';
+}
+
+void MSNP2PWebcam::sendBigP2PMessage( const QByteArray & dataMessage)
+{
+	unsigned int size=m_totalDataSize=dataMessage.size();
+	
+	for(unsigned int f=0;f<size;f+=1200)
+	{
+		m_offset=f;
+		QByteArray dm2;
+		dm2.duplicate(dataMessage.data()+m_offset, qMin(1200,m_totalDataSize-m_offset));
+		sendP2PMessage(dm2);
+	}
+}
+
+
+void MSNP2PWebcam::error()
+{
+	MSNP2P::error();
+}
+
+#endif
 
 
 #include "msnp2p.moc"
