@@ -3,10 +3,10 @@
 
     Copyright (c) 2002      by Duncan Mac-Vicar Prett <duncan@kde.org>
     Copyright (c) 2002-2003 by Martijn Klingens       <klingens@kde.org>
-    Copyright (c) 2002-2003 by Olivier Goffart        <ogoffart @ kde.org>
-    Copyright (c) 2005      by Michaël Larouche       <michael.larouche@kdemail.net>
+    Copyright (c) 2002-2003 by Olivier Goffart        <ogoffart@kde.org>
+    Copyright (c) 2005      by Michaël Larouche      <larouche@kde.org>
 
-    Kopete    (c) 2002-2003 by the Kopete developers  <kopete-devel@kde.org>
+    Kopete    (c) 2002-2007 by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -26,20 +26,15 @@
 
 #include "kopeteprotocol.h"
 #include "kopeteonlinestatus.h"
-#include "kopetecontactproperty.h"
+#include "kopeteproperty.h"
 
 #include "msnsocket.h"
 
 
-class QImage;
 
 class KAction;
-class KActionMenu;
 
 class MSNContact;
-class MSNAccount;
-class MSNNotifySocket;
-class MSNSwitchBoardSocket;
 class MSNChatSession;
 class MSNInvitation;
 namespace Kopete { class ChatSession; }
@@ -51,14 +46,14 @@ namespace Kopete { class Group; }
 /**
  * @author duncan
  * @author Martijn Klingens <klingens@kde.org>
- * @author Olivier Goffart  <ogoffart @ kde.org>
+ * @author Olivier Goffart  <ogoffart@kde.org>
  */
-class KOPETE_EXPORT MSNProtocol : public Kopete::Protocol
+class KOPETE_MSN_SHARED_EXPORT MSNProtocol : public Kopete::Protocol
 {
 	Q_OBJECT
 
 public:
-	MSNProtocol( QObject *parent, const char *name, const QStringList &args );
+	MSNProtocol( QObject *parent, const QStringList &args );
 
 	/**
 	 * SyncMode indicates whether settings differing between client and
@@ -105,13 +100,12 @@ public:
 	const Kopete::OnlineStatus UNK;  //inknown (internal)
 	const Kopete::OnlineStatus CNT;  //connecting (internal)
 
-	const Kopete::ContactPropertyTmpl propEmail;
-	const Kopete::ContactPropertyTmpl propPhoneHome;
-	const Kopete::ContactPropertyTmpl propPhoneWork;
-	const Kopete::ContactPropertyTmpl propPhoneMobile;
-	const Kopete::ContactPropertyTmpl propClient;
-	const Kopete::ContactPropertyTmpl propGuid;
-	const Kopete::ContactPropertyTmpl propPersonalMessage; // it's the equivalent of away message.
+	const Kopete::PropertyTmpl propEmail;
+	const Kopete::PropertyTmpl propPhoneHome;
+	const Kopete::PropertyTmpl propPhoneWork;
+	const Kopete::PropertyTmpl propPhoneMobile;
+	const Kopete::PropertyTmpl propClient;
+	const Kopete::PropertyTmpl propGuid;
 
 	enum List
 	{
@@ -158,7 +152,6 @@ public:
 
 	static MSNProtocol* protocol();
 	static bool validContactId(const QString&);
-	QImage scalePicture(const QImage &picture);
 
 private slots:
 	void slotSyncContactList();
@@ -178,7 +171,7 @@ signals:
 	 * @param msnMM is the message manager
 	 * @param c is the contact
 	 */
-	void invitation(MSNInvitation*& invitation,  const QString &bodyMSG , long unsigned int cookie , MSNChatSession* msnMM , MSNContact* c );
+	void invitation(MSNInvitation*& invitation,  const QString &bodyMSG , unsigned long int cookie , MSNChatSession* msnMM , MSNContact* c );
 };
 
 #endif
