@@ -2,9 +2,10 @@
     msnsocket.h - Base class for the sockets used in MSN
 
     Copyright (c) 2002      by Martijn Klingens       <klingens@kde.org>
-    Copyright (c) 2002-2004 by Olivier Goffart        <ogoffart @ kde.org>
-    Copyright (c) 2005		by Gregg Edghill 		  <gregg.edghill@gmail.com>
-    Kopete    (c) 2002      by the Kopete developers  <kopete-devel@kde.org>
+    Copyright (c) 2002-2004 by Olivier Goffart        <ogoffart@kde.org>
+    Copyright (c) 2005      by Gregg Edghill          <gregg.edghill@gmail.com>
+
+    Kopete    (c) 2002-2007 by the Kopete developers  <kopete-devel@kde.org>
 
     Portions of this code are taken from KMerlin,
               (c) 2001 by Olaf Lueg              <olueg@olsd.de>
@@ -26,7 +27,7 @@
 #include <qdatastream.h>
 #include <qstringlist.h>
 #include <qtimer.h>
-#include <qvaluelist.h>
+#include <QList>
 
 #include "kopete_export.h"
 
@@ -44,7 +45,7 @@ class MimeMessage;
  * Server, the Notification Server and the Switchboard Server. It is
  * inherited by the various specialized classes.
  */
-class KOPETE_EXPORT MSNSocket : public QObject
+class KOPETE_MSN_SHARED_EXPORT MSNSocket : public QObject
 {
 	Q_OBJECT
 
@@ -61,7 +62,7 @@ public:
 	 *       command-processing this method can effectively block all
 	 *       communications when passed a wrong length!
 	 */
-	void readBlock( uint len );
+	void read( uint len );
 
 	/**
 	 * OnlineStatus encapsulates the 4 states a connection can be in,
@@ -113,7 +114,7 @@ public slots:
 	 *
 	 * return the id
 	 */
-	int sendCommand( const QString &cmd, const QString &args = QString::null,
+	int sendCommand( const QString &cmd, const QString &args = QString(),
 		bool addId = true, const QByteArray &body = QByteArray() , bool binary=false );
 
 signals:
@@ -139,7 +140,7 @@ signals:
 	void socketClosed();
 
 	/**
-	 * A error has occured. Handle the display of the message.
+	 * A error has occurred. Handle the display of the message.
 	 */
 	void errorMessage( int type, const QString &msg );
 
@@ -268,7 +269,7 @@ private:
 	 * Queue of pending commands (should be mostly empty, but is needed to
 	 * send more than one command to the server)
 	 */
-	QValueList<QByteArray> m_sendQueue;
+	QList<QByteArray> m_sendQueue;
 
 	/**
 	 * Parse a single line of data.
@@ -286,7 +287,7 @@ private:
 	/**
 	 * The size of the requested block for block-based reads
 	 */
-	uint m_waitBlockSize;
+	int m_waitBlockSize;
 
 	class Buffer : public QByteArray
 	{
@@ -294,7 +295,7 @@ private:
 		Buffer( unsigned size = 0 );
 		~Buffer();
 		void add( char *str, unsigned size );
-		QByteArray take( unsigned size );
+		QByteArray take( int size );
 	};
 
 	Buffer m_buffer;
@@ -320,7 +321,7 @@ private:
 	bool m_pending; 			// Indicates whether a http response is pending.
 	int m_remaining;			// Indicates how many bytes of content data remain
 						// to be received if the content bytes are sent in
-						// a seperate packet(s).
+						// a separate packet(s).
 
 	/**
 	 * Provides access to information returned from a URI request.
