@@ -16,13 +16,14 @@
 
 #include "oscarversionupdater.h"
 
-#include <qdom.h>
-#include <qmutex.h>
+#include <QtXml/QDomDocument>
+#include <QtCore/QMutex>
 
 #include <kdebug.h>
 #include <kio/job.h>
-#include <kconfig.h>
+#include <ksharedconfig.h>
 #include <kglobal.h>
+#include <kconfiggroup.h>
 
 
 QMutex updateMutex;
@@ -49,7 +50,7 @@ OscarVersionUpdater *OscarVersionUpdater::self()
 
 bool OscarVersionUpdater::update( unsigned int stamp )
 {
-	kdDebug(OSCAR_GEN_DEBUG) << k_funcinfo << endl;
+	kDebug(OSCAR_GEN_DEBUG) ;
 	bool doUpdate = false;
 	bool isUpdating = false;
 	
@@ -69,10 +70,10 @@ bool OscarVersionUpdater::update( unsigned int stamp )
 		KConfigGroup config( KGlobal::config(), "Oscar" );
 		QString url = config.readEntry( "NewVersionURL", "http://kopete.kde.org/oscarversions.xml" );
 		mTransferJob = KIO::get ( url );
-		kdDebug(OSCAR_GEN_DEBUG) << k_funcinfo << "Download version info from server."<< endl;
+		kDebug(OSCAR_GEN_DEBUG) << "Download version info from server.";
 		
-		connect ( mTransferJob, SIGNAL ( result ( KIO::Job* ) ),
-		          this, SLOT ( slotTransferResult ( KIO::Job* ) ) );
+		connect ( mTransferJob, SIGNAL ( result ( KJob* ) ),
+		          this, SLOT ( slotTransferResult ( KJob* ) ) );
 		connect ( mTransferJob, SIGNAL ( data ( KIO::Job*, const QByteArray& ) ),
 		          this, SLOT ( slotTransferData ( KIO::Job*, const QByteArray& ) ) );
 	}
@@ -86,10 +87,10 @@ unsigned int OscarVersionUpdater::stamp() const
 
 void OscarVersionUpdater::initICQVersionInfo()
 {
-	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << endl;
+	kDebug(OSCAR_RAW_DEBUG) ;
 	KConfigGroup config( KGlobal::config(), "ICQVersion" );
 	
-	mICQVersion.clientString = config.readEntry( "ClientString", "ICQBasic" );
+	mICQVersion.clientString = config.readEntry( "ClientString", "ICQ Client" );
 	mICQVersion.clientId = config.readEntry( "ClientId", "0x010A" ).toUShort( 0, 0 );
 	mICQVersion.major = config.readEntry( "Major", "0x0006" ).toUShort( 0, 0 );
 	mICQVersion.minor = config.readEntry( "Minor", "0x0000" ).toUShort( 0, 0 );
@@ -102,7 +103,7 @@ void OscarVersionUpdater::initICQVersionInfo()
 
 void OscarVersionUpdater::initAIMVersionInfo()
 {
-	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << endl;
+	kDebug(OSCAR_RAW_DEBUG) ;
 	
 	KConfigGroup config( KGlobal::config(), "AIMVersion" );
 	
@@ -119,51 +120,52 @@ void OscarVersionUpdater::initAIMVersionInfo()
 
 void OscarVersionUpdater::printDebug()
 {
-	kdDebug(OSCAR_RAW_DEBUG) << "*************** AIM VERSION INFO ***************" << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "client string: " << mAIMVersion.clientString << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "client id: "  << QString::number( mAIMVersion.clientId, 16 ) << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "major: "  << QString::number( mAIMVersion.major, 16 ) << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "minor: "  << QString::number( mAIMVersion.minor, 16 ) << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "point: "  << QString::number( mAIMVersion.point, 16 ) << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "build: "  << QString::number( mAIMVersion.build, 16 ) << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "other: "  << QString::number( mAIMVersion.other, 16 ) << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "country: "  << mAIMVersion.country << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "lang: "  << mAIMVersion.lang << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "************************************************" << endl;
+	kDebug(OSCAR_RAW_DEBUG) << "*************** AIM VERSION INFO ***************";
+	kDebug(OSCAR_RAW_DEBUG) << "client string: " << mAIMVersion.clientString;
+	kDebug(OSCAR_RAW_DEBUG) << "client id: "  << QString::number( mAIMVersion.clientId, 16 );
+	kDebug(OSCAR_RAW_DEBUG) << "major: "  << QString::number( mAIMVersion.major, 16 );
+	kDebug(OSCAR_RAW_DEBUG) << "minor: "  << QString::number( mAIMVersion.minor, 16 );
+	kDebug(OSCAR_RAW_DEBUG) << "point: "  << QString::number( mAIMVersion.point, 16 );
+	kDebug(OSCAR_RAW_DEBUG) << "build: "  << QString::number( mAIMVersion.build, 16 );
+	kDebug(OSCAR_RAW_DEBUG) << "other: "  << QString::number( mAIMVersion.other, 16 );
+	kDebug(OSCAR_RAW_DEBUG) << "country: "  << mAIMVersion.country;
+	kDebug(OSCAR_RAW_DEBUG) << "lang: "  << mAIMVersion.lang;
+	kDebug(OSCAR_RAW_DEBUG) << "************************************************";
 	
-	kdDebug(OSCAR_RAW_DEBUG) << "*************** ICQ VERSION INFO ***************" << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "client string: " << mICQVersion.clientString << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "client id: "  << QString::number( mICQVersion.clientId, 16 ) << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "major: "  << QString::number( mICQVersion.major, 16 ) << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "minor: "  << QString::number( mICQVersion.minor, 16 ) << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "point: "  << QString::number( mICQVersion.point, 16 ) << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "build: "  << QString::number( mICQVersion.build, 16 ) << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "other: "  << QString::number( mICQVersion.other, 16 ) << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "country: "  << mICQVersion.country << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "lang: "  << mICQVersion.lang << endl;
-	kdDebug(OSCAR_RAW_DEBUG) << "************************************************" << endl;
+	kDebug(OSCAR_RAW_DEBUG) << "*************** ICQ VERSION INFO ***************";
+	kDebug(OSCAR_RAW_DEBUG) << "client string: " << mICQVersion.clientString;
+	kDebug(OSCAR_RAW_DEBUG) << "client id: "  << QString::number( mICQVersion.clientId, 16 );
+	kDebug(OSCAR_RAW_DEBUG) << "major: "  << QString::number( mICQVersion.major, 16 );
+	kDebug(OSCAR_RAW_DEBUG) << "minor: "  << QString::number( mICQVersion.minor, 16 );
+	kDebug(OSCAR_RAW_DEBUG) << "point: "  << QString::number( mICQVersion.point, 16 );
+	kDebug(OSCAR_RAW_DEBUG) << "build: "  << QString::number( mICQVersion.build, 16 );
+	kDebug(OSCAR_RAW_DEBUG) << "other: "  << QString::number( mICQVersion.other, 16 );
+	kDebug(OSCAR_RAW_DEBUG) << "country: "  << mICQVersion.country;
+	kDebug(OSCAR_RAW_DEBUG) << "lang: "  << mICQVersion.lang;
+	kDebug(OSCAR_RAW_DEBUG) << "************************************************";
 }
 
-void OscarVersionUpdater::slotTransferData ( KIO::Job */*job*/, const QByteArray &data )
+void OscarVersionUpdater::slotTransferData ( KIO::Job *job, const QByteArray &data )
 {
+	Q_UNUSED( job )
 	unsigned oldSize = mVersionData.size();
 	mVersionData.resize ( oldSize + data.size() );
 	memcpy ( &mVersionData.data()[oldSize], data.data(), data.size() );
 	
-	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "Data size " << mVersionData.size() << endl;
+	kDebug(OSCAR_RAW_DEBUG) << "Data size " << mVersionData.size();
 }
 
-void OscarVersionUpdater::slotTransferResult ( KIO::Job *job )
+void OscarVersionUpdater::slotTransferResult ( KJob *job )
 {
 	bool bUpdate = false;
 	if ( job->error() || mTransferJob->isErrorPage() )
 	{
 		//TODO show error
-		kdDebug(OSCAR_GEN_DEBUG) << k_funcinfo << "Download of version info has faild!" << endl;
+		kDebug(OSCAR_GEN_DEBUG) << "Download of version info has faild!";
 	}
 	else
 	{
-		kdDebug(OSCAR_GEN_DEBUG) << k_funcinfo << "Updating version info" << endl;
+		kDebug(OSCAR_GEN_DEBUG) << "Updating version info";
 		
 		QDomDocument doc;
 		if ( doc.setContent ( mVersionData ) )
@@ -200,7 +202,7 @@ void OscarVersionUpdater::slotTransferResult ( KIO::Job *job )
 
 void OscarVersionUpdater::parseDocument( QDomDocument& doc )
 {
-	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << endl;
+	kDebug(OSCAR_RAW_DEBUG) ;
 	
 	QDomElement root = doc.documentElement();
 	if ( root.tagName() != "oscar" )
@@ -220,18 +222,18 @@ void OscarVersionUpdater::parseDocument( QDomDocument& doc )
 
 bool OscarVersionUpdater::parseVersion( Oscar::ClientVersion& version, QDomElement& element )
 {
-	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << endl;
+	kDebug(OSCAR_RAW_DEBUG) ;
 	
 	// clear structure
-	version.clientString = QString::null;
+	version.clientString = QString();
 	version.clientId = 0x0000;
 	version.major = 0x0000;
 	version.minor = 0x0000;
 	version.point = 0x0000;
 	version.build = 0x0000;
 	version.other = 0x00000000;
-	version.country = QString::null;
-	version.lang = QString::null;
+	version.country = QString();
+	version.lang = QString();
 	
 	QDomElement versionChild = element.firstChild().toElement();
 	while ( !versionChild.isNull() )
@@ -263,16 +265,16 @@ bool OscarVersionUpdater::parseVersion( Oscar::ClientVersion& version, QDomEleme
 
 void OscarVersionUpdater::storeVersionInfo( const QString& group, const Oscar::ClientVersion& version ) const
 {
-	kdDebug(OSCAR_GEN_DEBUG) << k_funcinfo << "Storing version info to group: " << group << endl;
+	kDebug(OSCAR_GEN_DEBUG) << "Storing version info to group: " << group;
 	KConfigGroup config( KGlobal::config(), group );
 	
 	config.writeEntry( "ClientString", version.clientString );
-	config.writeEntry( "ClientId", version.clientId );
-	config.writeEntry( "Major", version.major );
-	config.writeEntry( "Minor", version.minor );
-	config.writeEntry( "Point", version.point );
-	config.writeEntry( "Build", version.build );
-	config.writeEntry( "Other", version.other );
+	config.writeEntry( "ClientId", uint(version.clientId) );
+	config.writeEntry( "Major", uint(version.major) );
+	config.writeEntry( "Minor", uint(version.minor) );
+	config.writeEntry( "Point", uint(version.point) );
+	config.writeEntry( "Build", uint(version.build) );
+	config.writeEntry( "Other", uint(version.other) );
 	config.writeEntry( "Country", version.country );
 	config.writeEntry( "Lang", version.lang );
 	config.sync();
