@@ -1,5 +1,5 @@
 /*  *************************************************************************
-    *   copyright: (C) 2003 Richard Lrkng <nouseforaname@home.se>         *
+    *   copyright: (C) 2003 Richard Lärkäng <nouseforaname@home.se>         *
     *   copyright: (C) 2003 Gav Wood <gav@kde.org>                          *
     *************************************************************************
 */
@@ -22,7 +22,6 @@
 
 #include <qstring.h>
 
-class SMSAccount;
 namespace Kopete { class ChatSession; }
 namespace Kopete { class MetaContact; }
 
@@ -36,7 +35,7 @@ public:
 	SMSContact( Kopete::Account* _account, const QString &phoneNumber,
 		const QString &displayName, Kopete::MetaContact *parent );
 
-	QPtrList<KAction>* customContextMenuActions();
+	KActionCollection* customContextMenuActions(QWidget *parent);
 
 	const QString &phoneNumber();
 	void setPhoneNumber( const QString phoneNumber );
