@@ -1,5 +1,5 @@
 /*  *************************************************************************
-    *   copyright: (C) 2003 Richard Lrkng <nouseforaname@home.se>         *
+    *   copyright: (C) 2003 Richard Lärkäng <nouseforaname@home.se>         *
     *   copyright: (C) 2003 Gav Wood <gav@kde.org>                          *
     *************************************************************************
 */
@@ -17,7 +17,7 @@
 #ifndef SMSEDITACCOUNTWIDGET_H
 #define SMSEDITACCOUNTWIDGET_H
 
-#include <qwidget.h>
+#include <QWidget>
 #include "editaccountwidget.h"
 
 class SMSProtocol;
@@ -30,7 +30,7 @@ class SMSEditAccountWidget : public QWidget, public KopeteEditAccountWidget
 {
 	Q_OBJECT
 public:
-	SMSEditAccountWidget(SMSProtocol *protocol, Kopete::Account *theAccount, QWidget *parent = 0, const char *name = 0);
+	SMSEditAccountWidget(SMSProtocol *protocol, Kopete::Account *theAccount, QWidget *parent = 0);
 	~SMSEditAccountWidget();
 
 	bool validateData();
