@@ -18,20 +18,25 @@
 
 #include <qlayout.h>
 #include <qradiobutton.h>
+//Added by qt3to4:
+#include <QVBoxLayout>
 #include <qlineedit.h>
 #include <kdebug.h>
 
 #include "kopeteaccount.h"
+#include "kopetecontactlist.h"
 #include "kopetemetacontact.h"
 
-#include "testbedaddui.h"
+#include "testbedcontact.h"
 
-TestbedAddContactPage::TestbedAddContactPage( QWidget* parent, const char* name )
-		: AddContactPage(parent, name)
+TestbedAddContactPage::TestbedAddContactPage( QWidget* parent )
+		: AddContactPage(parent)
 {
-	kdDebug(14210) << k_funcinfo << endl;
-	( new QVBoxLayout( this ) )->setAutoAdd( true );
-	m_testbedAddUI = new TestbedAddUI( this );
+	kDebug(14210) ;
+	QVBoxLayout* l = new QVBoxLayout( this );
+	QWidget* w = new QWidget();
+	m_testbedAddUI.setupUi( w );
+	l->addWidget( w );
 }
 
 TestbedAddContactPage::~TestbedAddContactPage()
@@ -40,19 +45,19 @@ TestbedAddContactPage::~TestbedAddContactPage()
 
 bool TestbedAddContactPage::apply( Kopete::Account* a, Kopete::MetaContact* m )
 {
-    if ( validateData() )
+	if ( validateData() )
 	{
-		bool ok = false;
-		QString type;
-		QString name;
-		if ( m_testbedAddUI->m_rbEcho->isOn() )
+		QString name = m_testbedAddUI.m_uniqueName->text();
+
+		if ( a->addContact(name, m, Kopete::Account::ChangeKABC ) )
 		{
-			type = m_testbedAddUI->m_uniqueName->text();
-			name = QString::fromLatin1( "Echo Contact" );
-			ok = true;
+			TestbedContact * newContact = qobject_cast<TestbedContact*>( Kopete::ContactList::self()->findContact( a->protocol()->pluginId(), a->accountId(), name ) );
+			if ( newContact )
+			{
+				newContact->setType( m_testbedAddUI.m_rbEcho->isChecked() ? TestbedContact::Echo : TestbedContact::Group );
+				return true;
+			}
 		}
-		if ( ok )
-			return a->addContact(type, /* FIXME: ? name, */ m, Kopete::Account::ChangeKABC );
 		else
 			return false;
 	}
