@@ -16,6 +16,8 @@
 
 #include "testbedcontact.h"
 
+#include <QList>
+
 #include <kaction.h>
 #include <kdebug.h>
 #include <klocale.h>
@@ -29,11 +31,11 @@
 #include "testbedprotocol.h"
 
 TestbedContact::TestbedContact( Kopete::Account* _account, const QString &uniqueName,
-		const TestbedContactType type, const QString &displayName, Kopete::MetaContact *parent )
+		const QString &displayName, Kopete::MetaContact *parent )
 : Kopete::Contact( _account, uniqueName, parent )
 {
-	kdDebug( 14210 ) << k_funcinfo << " uniqueName: " << uniqueName << ", displayName: " << displayName << endl;
-	m_type = type;
+	kDebug( 14210 ) << " uniqueName: " << uniqueName << ", displayName: " << displayName;
+	m_type = TestbedContact::Null;
 	// FIXME: ? setDisplayName( displayName );
 	m_msgManager = 0L;
 
@@ -44,6 +46,11 @@ TestbedContact::~TestbedContact()
 {
 }
 
+void TestbedContact::setType( TestbedContact::Type type )
+{
+	m_type = type;
+}
+
 bool TestbedContact::isReachable()
 {
     return true;
@@ -55,34 +62,42 @@ void TestbedContact::serialize( QMap< QString, QString > &serializedData, QMap<
 	switch ( m_type )
 	{
 	case Null:
-		value = "null";
+		value = QLatin1String("null");
 	case Echo:
-		value = "echo";
+		value = QLatin1String("echo");
+	case Group:
+		value = QLatin1String("group");
 	}
 	serializedData[ "contactType" ] = value;
 }
 
-Kopete::ChatSession* TestbedContact::manager( CanCreateFlags )
+Kopete::ChatSession* TestbedContact::manager( CanCreateFlags canCreateFlags )
 {
-	kdDebug( 14210 ) << k_funcinfo << endl;
+	kDebug( 14210 ) ;
 	if ( m_msgManager )
 	{
 		return m_msgManager;
 	}
-	else
+	else if ( canCreateFlags == CanCreate )
 	{
-		QPtrList<Kopete::Contact> contacts;
+		QList<Kopete::Contact*> contacts;
 		contacts.append(this);
-		m_msgManager = Kopete::ChatSessionManager::self()->create(account()->myself(), contacts, protocol());
+		Kopete::ChatSession::Form form = ( m_type == Group ?
+				  Kopete::ChatSession::Chatroom : Kopete::ChatSession::Small );
+		m_msgManager = Kopete::ChatSessionManager::self()->create(account()->myself(), contacts, protocol(), form );
 		connect(m_msgManager, SIGNAL(messageSent(Kopete::Message&, Kopete::ChatSession*)),
 				this, SLOT( sendMessage( Kopete::Message& ) ) );
 		connect(m_msgManager, SIGNAL(destroyed()), this, SLOT(slotChatSessionDestroyed()));
 		return m_msgManager;
 	}
+	else
+	{
+		return 0;
+	}
 }
 
 
-QPtrList<KAction> *TestbedContact::customContextMenuActions() //OBSOLETE
+QList<KAction *> *TestbedContact::customContextMenuActions() //OBSOLETE
 {
 	//FIXME!!!  this function is obsolete, we should use XMLGUI instead
 	/*m_actionCollection = new KActionCollection( this, "userColl" );
@@ -101,7 +116,7 @@ void TestbedContact::showContactSettings()
 
 void TestbedContact::sendMessage( Kopete::Message &message )
 {
-	kdDebug( 14210 ) << k_funcinfo << endl;
+	kDebug( 14210 ) ;
 	// convert to the what the server wants
 	// For this 'protocol', there's nothing to do
 	// send it
@@ -116,17 +131,15 @@ void TestbedContact::sendMessage( Kopete::Message &message )
 
 void TestbedContact::receivedMessage( const QString &message )
 {
-	// Create a Kopete::Message
-	Kopete::Message *newMessage;
 	Kopete::ContactPtrList contactList;
-	account();
 	contactList.append( account()->myself() );
-	newMessage = new Kopete::Message( this, contactList, message, Kopete::Message::Inbound );
+	// Create a Kopete::Message
+	Kopete::Message newMessage( this, contactList );
+	newMessage.setPlainBody( message );
+	newMessage.setDirection( Kopete::Message::Inbound );
 
 	// Add it to the manager
-	manager()->appendMessage (*newMessage);
-
-	delete newMessage;
+	manager()->appendMessage (newMessage);
 }
 
 void TestbedContact::slotChatSessionDestroyed()
