@@ -2,7 +2,7 @@
     Kopete Yahoo Protocol
     Handles several lists such as buddylist, ignorelist and so on
 
-    Copyright (c) 2005 André Duffeck <andre.duffeck@kdemail.net>
+    Copyright (c) 2005 André Duffeck <duffeck@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -20,13 +20,12 @@
 #include "transfer.h"
 #include "ymsgtransfer.h"
 #include "client.h"
-#include <qstring.h>
 #include <qstringlist.h>
 #include <kdebug.h>
 
 ListTask::ListTask(Task* parent) : Task(parent)
 {
-	kdDebug(YAHOO_RAW_DEBUG) << k_funcinfo << endl;
+	kDebug(YAHOO_RAW_DEBUG) ;
 }
 
 ListTask::~ListTask()
@@ -36,8 +35,6 @@ ListTask::~ListTask()
 
 bool ListTask::take( Transfer* transfer )
 {
-	kdDebug(YAHOO_RAW_DEBUG) << k_funcinfo << endl;
-	
 	if ( !forMe( transfer ) )
 		return false;
 	
@@ -49,16 +46,15 @@ bool ListTask::take( Transfer* transfer )
 	return true;
 }
 
-bool ListTask::forMe( Transfer* transfer ) const
+bool ListTask::forMe( const Transfer* transfer ) const
 {
-	kdDebug(YAHOO_RAW_DEBUG) << k_funcinfo << endl;
-	YMSGTransfer *t = 0L;
-	t = dynamic_cast<YMSGTransfer*>(transfer);
+	const YMSGTransfer *t = 0L;
+	t = dynamic_cast<const YMSGTransfer*>(transfer);
 	if (!t)
 		return false;
 
 
-	if ( t->service() == Yahoo::ServiceList )
+	if ( t->service() == Yahoo::ServiceBuddyList )
 		return true;
 	else
 		return false;
@@ -66,39 +62,32 @@ bool ListTask::forMe( Transfer* transfer ) const
 
 void ListTask::parseBuddyList( YMSGTransfer *t )
 {
-	kdDebug(YAHOO_RAW_DEBUG) << k_funcinfo << endl;
+	kDebug(YAHOO_RAW_DEBUG) ;
 
-	QString raw;
-	m_list.append( t->firstParam( 87 ) );
+	QString group;
 
-	if( t->firstParam( 59 ).isEmpty() )
-		return;
-
-	QStringList groups;
-	groups = QStringList::split( "\n", m_list );
-
-	for ( QStringList::Iterator groupIt = groups.begin(); groupIt != groups.end(); ++groupIt ) 
+	// We need some low-level parsing here
+	foreach( Param p, t->paramList() )
 	{
-		QString group = (*groupIt).section(":", 0, 0);
-		QStringList buddies;
-		buddies = QStringList::split( ",", (*groupIt).section(":", 1,1) );
-		for ( QStringList::Iterator buddyIt = buddies.begin(); buddyIt != buddies.end(); ++buddyIt ) 
+		switch( p.first )
 		{
-			kdDebug(YAHOO_RAW_DEBUG) << k_funcinfo << "Parsed buddy: " << *buddyIt << " in group " << group << endl;
-			emit gotBuddy( *buddyIt, QString::null, group );
+		case 65:
+			group = p.second;
+			break;
+		case 7:
+			emit gotBuddy( p.second, QString(), group );
 		}
 	}
-	m_list.truncate( 0 );
 }
 
 void ListTask::parseStealthList( YMSGTransfer *t )
 {
-	kdDebug(YAHOO_RAW_DEBUG) << k_funcinfo << endl;
+	kDebug(YAHOO_RAW_DEBUG) ;
 
 	QString raw;
 	raw = t->firstParam( 185 );
 
-	QStringList buddies = QStringList::split( ",", raw );
+	QStringList buddies = raw.split( ",", QString::SkipEmptyParts );
 	for ( QStringList::Iterator it = buddies.begin(); it != buddies.end(); ++it ) 
 	{
 		emit stealthStatusChanged( *it, Yahoo::StealthActive );
