@@ -2,7 +2,7 @@
     yahooconferencemessagemanager.h - Yahoo Conference Message Manager
 
     Copyright (c) 2003 by Duncan Mac-Vicar <duncan@kde.org>
-    Copyright (c) 2005 by André Duffeck        <andre@duffeck.de>
+    Copyright (c) 2005 by André Duffeck        <duffeck@kde.org>
 
     Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -17,10 +17,10 @@
 */
 
 #include <kdebug.h>
-#include <klineeditdlg.h>
+#include <klineedit.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kconfig.h>
 
 #include <kopetecontactaction.h>
@@ -28,26 +28,30 @@
 #include <kopetecontact.h>
 #include <kopetechatsessionmanager.h>
 #include <kopeteuiglobal.h>
+#include <kicon.h>
 
 #include "yahooconferencemessagemanager.h"
 #include "yahoocontact.h"
 #include "yahooaccount.h"
 #include "yahooinvitelistimpl.h"
+#include <kactioncollection.h>
 
 YahooConferenceChatSession::YahooConferenceChatSession( const QString & yahooRoom, Kopete::Protocol *protocol, const Kopete::Contact *user,
-	Kopete::ContactPtrList others, const char *name )
-: Kopete::ChatSession( user, others, protocol,  name )
+	Kopete::ContactPtrList others )
+: Kopete::ChatSession( user, others, protocol )
 {
 
 	Kopete::ChatSessionManager::self()->registerChatSession( this );
-	setInstance(protocol->instance());
+	setComponentData(protocol->componentData());
 
 	connect ( this, SIGNAL( messageSent ( Kopete::Message &, Kopete::ChatSession * ) ),
 			  SLOT( slotMessageSent ( Kopete::Message &, Kopete::ChatSession * ) ) );
 
 	m_yahooRoom = yahooRoom;
 
-	m_actionInvite = new KAction( i18n( "&Invite others" ), "kontact_contacts", this, SLOT( slotInviteOthers() ), actionCollection(), "yahooInvite");
+	m_actionInvite = new KAction( KIcon("x-office-contact"), i18n( "&Invite others" ), this ); // icon should probably be "contact-invite", but that doesn't exist... please request an icon on http://techbase.kde.org/index.php?title=Projects/Oxygen/Missing_Icons
+        actionCollection()->addAction( "yahooInvite", m_actionInvite );
+	connect ( m_actionInvite, SIGNAL( triggered ( bool ) ), this, SLOT( slotInviteOthers() ) );
 
 	setXMLFile("yahooconferenceui.rc");
 }
@@ -60,7 +64,7 @@ YahooConferenceChatSession::~YahooConferenceChatSession()
 YahooAccount *YahooConferenceChatSession::account()
 {
 	return static_cast< YahooAccount *>( Kopete::ChatSession::account() );
-}	
+}
 
 const QString &YahooConferenceChatSession::room()
 {
@@ -79,7 +83,7 @@ void YahooConferenceChatSession::left( YahooContact *c )
 
 void YahooConferenceChatSession::slotMessageSent( Kopete::Message & message, Kopete::ChatSession * )
 {
-	kdDebug ( YAHOO_GEN_DEBUG ) << k_funcinfo << endl;
+	kDebug ( YAHOO_GEN_DEBUG ) ;
 
 	YahooAccount *acc = dynamic_cast< YahooAccount *>( account() );
 	if( acc )
@@ -91,20 +95,21 @@ void YahooConferenceChatSession::slotMessageSent( Kopete::Message & message, Kop
 void YahooConferenceChatSession::slotInviteOthers()
 {
 	QStringList buddies;
-	QDictIterator<Kopete::Contact> it( account()->contacts() );
+
+	QHash<QString, Kopete::Contact*>::ConstIterator it, itEnd = account()->contacts().constEnd();
 	Kopete::Contact *myself = account()->myself();
-	for( ; it.current(); ++it )
+	for( it = account()->contacts().constBegin(); it != itEnd; ++it )
 	{
-		if( (*it) != myself && !members().contains( *it ) )
-			buddies.push_back( (*it)->contactId() );
+		if( it.value() != myself && !members().contains( it.value() ) )
+			buddies.push_back( it.value()->contactId() );
 	}
 
 	YahooInviteListImpl *dlg = new YahooInviteListImpl( Kopete::UI::Global::mainWidget() );
-	QObject::connect( dlg, SIGNAL( readyToInvite( const QString &, const QStringList &, const QStringList &, const QString & ) ), 
+	QObject::connect( dlg, SIGNAL( readyToInvite( const QString &, const QStringList &, const QStringList &, const QString & ) ),
 				account(), SLOT( slotAddInviteConference( const QString &, const QStringList &, const QStringList &, const QString & ) ) );
 	dlg->setRoom( m_yahooRoom );
 	dlg->fillFriendList( buddies );
-	for( QPtrList<Kopete::Contact>::ConstIterator it = members().begin(); it != members().end(); it++ )
+	for( QList<Kopete::Contact*>::ConstIterator it = members().constBegin(); it != members().constEnd(); it++ )
 		dlg->addParticipant( (*it)->contactId() );
 	dlg->show();
 }
