@@ -22,17 +22,17 @@
 #include "kopeteonlinestatus.h"
 #include "kopetemetacontact.h"
 #include "kopetechatsessionmanager.h"
-#include "kopetemetacontact.h"
 #include "kopeteuiglobal.h"
 #include "kopeteview.h"
 #include "kopetetransfermanager.h"
+#include "kopeteavatarmanager.h"
 
 // Local Includes
 #include "yahoocontact.h"
 #include "yahooaccount.h"
 #include "client.h"
 #include "yahoowebcamdialog.h"
-#include "yahoostealthsetting.h"
+#include "ui_yahoostealthsetting.h"
 #include "yahoochatsession.h"
 #include "yabentry.h"
 #include "yahoouserinfodialog.h"
@@ -46,28 +46,29 @@
 // KDE Includes
 #include <kdebug.h>
 #include <kaction.h>
-#include <kapplication.h>
+#include <kdialog.h>
 #include <klocale.h>
 #include <krun.h>
 #include <kshortcut.h>
 #include <kmessagebox.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <kio/global.h>
 #include <kio/job.h>
-#include <kurl.h>
 #include <kio/jobclasses.h>
 #include <kimageio.h>
 #include <kstandarddirs.h>
 #include <kfiledialog.h>
+#include <ktoolinvocation.h>
+#include <kicon.h>
 
 YahooContact::YahooContact( YahooAccount *account, const QString &userId, const QString &fullName, Kopete::MetaContact *metaContact )
 	: Kopete::Contact( account, userId, metaContact )
 {
-	//kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
+	//kDebug(YAHOO_GEN_DEBUG) ;
 
 	m_userId = userId;
 	if ( metaContact )
-		m_groupName = metaContact->groups().getFirst()->displayName();
+		m_groupName = metaContact->groups().first()->displayName();
 	m_manager = 0L;
 	m_account = account;
 	m_YABEntry = 0L;
@@ -79,10 +80,10 @@ YahooContact::YahooContact( YahooAccount *account, const QString &userId, const
 	setNickName( fullName );
 	setOnlineStatus( static_cast<YahooProtocol*>( m_account->protocol() )->Offline );
 	setFileCapable( true );
-	
+
 	if ( m_account->haveContactList() )
 		syncToServer();
-	
+
 	m_webcamDialog = 0L;
 	m_webcamAction = 0L;
 	m_stealthAction = 0L;
@@ -108,21 +109,21 @@ void YahooContact::setOnlineStatus(const Kopete::OnlineStatus &status)
 {
 	if( m_stealthed && status.internalStatus() <= 999)	// Not Stealted -> Stealthed
 	{
-		Contact::setOnlineStatus( 
+		Contact::setOnlineStatus(
 			Kopete::OnlineStatus(status.status() ,
 			(status.weight()==0) ? 0 : (status.weight() -1)  ,
 			protocol() ,
 			status.internalStatus()+1000 ,
 			status.overlayIcons() + QStringList("yahoo_stealthed") ,
-			i18n("%1|Stealthed").arg( status.description() ) ) );
+			i18n("%1|Stealthed", status.description() ) ) );
 	}
 	else if( !m_stealthed && status.internalStatus() > 999 )// Stealthed -> Not Stealthed
 		Contact::setOnlineStatus( static_cast< YahooProtocol *>( protocol() )->statusFromYahoo( status.internalStatus() - 1000 ) );
 	else
 		Contact::setOnlineStatus( status );
-	
-	if( status.status() == Kopete::OnlineStatus::Offline ) 
-		removeProperty( ((YahooProtocol*)(m_account->protocol()))->awayMessage);
+
+	if( status.status() == Kopete::OnlineStatus::Offline )
+		setStatusMessage( Kopete::StatusMessage() );
 }
 
 void YahooContact::setStealthed( bool stealthed )
@@ -138,37 +139,37 @@ bool YahooContact::stealthed()
 
 void YahooContact::serialize(QMap<QString, QString> &serializedData, QMap<QString, QString> &addressBookData)
 {
-	//kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
+	//kDebug(YAHOO_GEN_DEBUG) ;
 
 	Kopete::Contact::serialize(serializedData, addressBookData);
 }
 
 void YahooContact::syncToServer()
 {
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo  << endl;
+	kDebug(YAHOO_GEN_DEBUG) ;
 	if(!m_account->isConnected()) return;
 
 	if ( !m_account->isOnServer(m_userId) && !metaContact()->isTemporary() )
-	{	kdDebug(YAHOO_GEN_DEBUG) << "Contact " << m_userId << " doesn't exist on server-side. Adding..." << endl;
+	{	kDebug(YAHOO_GEN_DEBUG) << "Contact " << m_userId << " doesn't exist on server-side. Adding...";
 
 		Kopete::GroupList groupList = metaContact()->groups();
-		for( Kopete::Group *g = groupList.first(); g; g = groupList.next() )
+		foreach(Kopete::Group *g, groupList)
 			m_account->yahooSession()->addBuddy(m_userId, g->displayName() );
 	}
 }
 
 void YahooContact::sync(unsigned int flags)
 {
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo  << endl;
+	kDebug(YAHOO_GEN_DEBUG) ;
 	if ( !m_account->isConnected() )
 		return;
 
 	if ( !m_account->isOnServer( contactId() ) )
 	{
 		//TODO: Share this code with the above function
-		kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << "Contact isn't on the server. Adding..." << endl;
+		kDebug(YAHOO_GEN_DEBUG) << "Contact isn't on the server. Adding...";
 		Kopete::GroupList groupList = metaContact()->groups();
-		for ( Kopete::Group *g = groupList.first(); g; g = groupList.next() )
+		foreach(Kopete::Group *g, groupList)
 			m_account->yahooSession()->addBuddy(m_userId, g->displayName() );
 	}
 	else
@@ -176,7 +177,7 @@ void YahooContact::sync(unsigned int flags)
 		QString newGroup = metaContact()->groups().first()->displayName();
 		if ( flags & Kopete::Contact::MovedBetweenGroup )
 		{
-			kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << "contact changed groups. moving on server" << endl;
+			kDebug(YAHOO_GEN_DEBUG) << "contact changed groups. moving on server";
 			m_account->yahooSession()->moveBuddy( contactId(), m_groupName, newGroup );
 			m_groupName = newGroup;
 		}
@@ -186,13 +187,13 @@ void YahooContact::sync(unsigned int flags)
 
 bool YahooContact::isOnline() const
 {
-	//kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
+	//kDebug(YAHOO_GEN_DEBUG) ;
 	return onlineStatus().status() != Kopete::OnlineStatus::Offline && onlineStatus().status() != Kopete::OnlineStatus::Unknown;
 }
 
 bool YahooContact::isReachable()
 {
-	//kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
+	//kDebug(YAHOO_GEN_DEBUG) ;
 	if ( m_account->isConnected() )
 		return true;
 	else
@@ -217,111 +218,122 @@ Kopete::ChatSession *YahooContact::manager( Kopete::Contact::CanCreateFlags canC
 }
 
 QString YahooContact::prepareMessage( const QString &messageText )
-{	
+{
 	// Yahoo does not understand XML/HTML message data, so send plain text
 	// instead.  (Yahoo has its own format for "rich text".)
 	QString newMsg( messageText );
 	QRegExp regExp;
 	int pos = 0;
 	regExp.setMinimal( true );
-	
+	// find and replace <p>-formattings
+	regExp.setPattern( "<p style=\"([^\"]*)\">(.*)</p>" );
+	pos = 0;
+	while ( pos >= 0 ) {
+		pos = regExp.indexIn( messageText, pos );
+		if ( pos >= 0 ) {
+			pos += regExp.matchedLength();
+			newMsg.replace( regExp, QLatin1String("\\2" ) );
+		}
+	}
+
+
 	// find and replace Bold-formattings
 	regExp.setPattern( "<span([^>]*)font-weight:600([^>]*)>(.*)</span>" );
 	pos = 0;
 	while ( pos >= 0 ) {
-		pos = regExp.search( messageText, pos );
+		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-		newMsg.replace( regExp, QString::fromLatin1("<span\\1font-weight:600\\2>\033[1m\\3\033[x1m</span>" ) );
+			newMsg.replace( regExp, QLatin1String("<span\\1font-weight:600\\2>\033[1m\\3\033[x1m</span>" ) );
 		}
 	}
-	
+
 	// find and replace Underline-formattings
 	regExp.setPattern( "<span([^>]*)text-decoration:underline([^>]*)>(.*)</span>" );
 	pos = 0;
 	while ( pos >= 0 ) {
-		pos = regExp.search( messageText, pos );
+		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-		newMsg.replace( regExp, QString::fromLatin1("<span\\1text-decoration:underline\\2>\033[4m\\3\033[x4m</span>" ) );
+			newMsg.replace( regExp, QLatin1String("<span\\1text-decoration:underline\\2>\033[4m\\3\033[x4m</span>" ) );
 		}
 	}
-	
+
 	// find and replace Italic-formattings
 	regExp.setPattern( "<span([^>]*)font-style:italic([^>]*)>(.*)</span>" );
 	pos = 0;
 	while ( pos >= 0 ) {
-		pos = regExp.search( messageText, pos );
+		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-		newMsg.replace( regExp, QString::fromLatin1("<span\\1font-style:italic\\2>\033[2m\\3\033[x2m</span>" ) );
+			newMsg.replace( regExp, QLatin1String("<span\\1font-style:italic\\2>\033[2m\\3\033[x2m</span>" ) );
 		}
 	}
-	
+
 	// find and replace Color-formattings
 	regExp.setPattern( "<span([^>]*)color:#([0-9a-zA-Z]*)([^>]*)>(.*)</span>" );
 	pos = 0;
 	while ( pos >= 0 ) {
-		pos = regExp.search( messageText, pos );
+		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QString::fromLatin1("<span\\1\\3>\033[#\\2m\\4\033[#000000m</span>" ) );
+			newMsg.replace( regExp, QLatin1String("<span\\1\\3>\033[#\\2m\\4\033[#000000m</span>" ) );
 		}
 	}
-	
+
 	// find and replace Font-formattings
 	regExp.setPattern( "<span([^>]*)font-family:([^;\"]*)([^>]*)>(.*)</span>" );
 	pos = 0;
 	while ( pos >= 0 ) {
-		pos = regExp.search( messageText, pos );
+		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QString::fromLatin1("<span\\1\\3><font face=\"\\2\">\\4</span>" ) );
+			newMsg.replace( regExp, QLatin1String("<span\\1\\3><font face=\"\\2\">\\4</span>" ) );
 		}
 	}
-	
+
 	// find and replace Size-formattings
 	regExp.setPattern( "<span([^>]*)font-size:([0-9]*)pt([^>]*)>(.*)</span>" );
 	pos = 0;
 	while ( pos >= 0 ) {
-		pos = regExp.search( messageText, pos );
+		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QString::fromLatin1("<span\\1\\3><font size=\"\\2\">\\4</span>" ) );
+			newMsg.replace( regExp, QLatin1String("<span\\1\\3><font size=\"\\2\">\\4</span>" ) );
 		}
 	}
-	
+
 	// remove span-tags
 	regExp.setPattern( "<span([^>]*)>(.*)</span>" );
 	pos = 0;
 	while ( pos >= 0 ) {
-		pos = regExp.search( messageText, pos );
+		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QString::fromLatin1("\\2") );
+			newMsg.replace( regExp, QLatin1String("\\2") );
 		}
 	}
-	
+
 	// convert escaped chars
-	newMsg.replace( QString::fromLatin1( "&gt;" ), QString::fromLatin1( ">" ) );
-	newMsg.replace( QString::fromLatin1( "&lt;" ), QString::fromLatin1( "<" ) );
-	newMsg.replace( QString::fromLatin1( "&quot;" ), QString::fromLatin1( "\"" ) );
-	newMsg.replace( QString::fromLatin1( "&nbsp;" ), QString::fromLatin1( " " ) );
-	newMsg.replace( QString::fromLatin1( "&amp;" ), QString::fromLatin1( "&" ) );
-	newMsg.replace( QString::fromLatin1( "<br/>" ), QString::fromLatin1( "\r" ) );
-	
+	newMsg.replace( QLatin1String( "&gt;" ), QLatin1String( ">" ) );
+	newMsg.replace( QLatin1String( "&lt;" ), QLatin1String( "<" ) );
+	newMsg.replace( QLatin1String( "&quot;" ), QLatin1String( "\"" ) );
+	newMsg.replace( QLatin1String( "&nbsp;" ), QLatin1String( " " ) );
+	newMsg.replace( QLatin1String( "&amp;" ), QLatin1String( "&" ) );
+	newMsg.replace( QLatin1String( "<br/>" ), QLatin1String( "\r" ) );
+
 	return newMsg;
 }
 
 void YahooContact::slotSendMessage( Kopete::Message &message )
 {
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
-	
+	kDebug(YAHOO_GEN_DEBUG) ;
+
 	QString messageText = message.escapedBody();
-	kdDebug(YAHOO_GEN_DEBUG) << "Original message: " << messageText << endl;
+	kDebug(YAHOO_GEN_DEBUG) << "Original message: " << messageText;
 	messageText = prepareMessage( messageText );
-	kdDebug(YAHOO_GEN_DEBUG) << "Converted message: " << messageText << endl;
-	
+	kDebug(YAHOO_GEN_DEBUG) << "Converted message: " << messageText;
+
 	Kopete::ContactPtrList m_them = manager(Kopete::Contact::CanCreate)->members();
 	Kopete::Contact *target = m_them.first();
 
@@ -330,18 +342,18 @@ void YahooContact::slotSendMessage( Kopete::Message &message )
 		m_account->yahooSession()->setChatSessionState( m_userId, false );
 		m_sessionActive = true;
 	}
-	
+
 	m_account->yahooSession()->sendMessage( static_cast<YahooContact *>(target)->m_userId, messageText );
-	
+
 	// append message to window
 	manager(Kopete::Contact::CanCreate)->appendMessage(message);
 	manager(Kopete::Contact::CanCreate)->messageSucceeded();
 }
 
-void YahooContact::sendFile( const KURL &sourceURL, const QString &fileName, uint fileSize )
+void YahooContact::sendFile( const KUrl &sourceURL, const QString &fileName, uint fileSize )
 {
-	Kopete::TransferManager::transferManager()->sendFile( sourceURL, fileName, fileSize, 
-			false, this, SLOT(slotSendFile( const KURL & )) );
+	Kopete::TransferManager::transferManager()->sendFile( sourceURL, fileName, fileSize,
+			false, this, SLOT(slotSendFile( const KUrl & )) );
 }
 
 void YahooContact::slotTyping(bool isTyping_ )
@@ -360,82 +372,90 @@ void YahooContact::slotChatSessionDestroyed()
 	m_sessionActive = false;
 }
 
-QPtrList<KAction> *YahooContact::customContextMenuActions()
+QList<KAction*> *YahooContact::customContextMenuActions()
 {
-	QPtrList<KAction> *actionCollection = new QPtrList<KAction>();
+	QList<KAction*> *actionCollection = new QList<KAction*>();
 	if ( !m_webcamAction )
 	{
-		m_webcamAction = new KAction( i18n( "View &Webcam" ), "webcamreceive", KShortcut(),
-		                              this, SLOT( requestWebcam() ), this, "view_webcam" );
+		m_webcamAction = new KAction( KIcon("webcamreceive"), i18n( "View &Webcam" ), this );
+		connect( m_webcamAction, SIGNAL( triggered(bool) ), this, SLOT( requestWebcam() ) );
 	}
 	if ( isReachable() )
 		m_webcamAction->setEnabled( true );
 	else
 		m_webcamAction->setEnabled( false );
-	actionCollection->append( m_webcamAction );
-	
+	//actionCollection->addAction( "view_webcam", m_webcamAction );
+        actionCollection->append( m_webcamAction );
+
 	if( !m_inviteWebcamAction )
 	{
-		m_inviteWebcamAction = new KAction( i18n( "Invite to view your Webcam" ), "webcamsend", KShortcut(),
-		                                    this, SLOT( inviteWebcam() ), this, "invite_webcam" );
+		m_inviteWebcamAction = new KAction( KIcon("webcamsend"), i18n( "Invite to view your Webcam" ), this );
+		connect( m_inviteWebcamAction, SIGNAL( triggered(bool) ), this, SLOT( inviteWebcam() ) );
 	}
 	if ( isReachable() )
 		m_inviteWebcamAction->setEnabled( true );
 	else
 		m_inviteWebcamAction->setEnabled( false );
-	actionCollection->append( m_inviteWebcamAction );
-	
+	//actionCollection->addAction( "invite_webcam", m_inviteWebcamAction );
+        actionCollection->append( m_inviteWebcamAction );
+
 	if ( !m_buzzAction )
 	{
-		m_buzzAction = new KAction( i18n( "&Buzz Contact" ), "bell", KShortcut(), this, SLOT( buzzContact() ), this, "buzz_contact");
+		m_buzzAction = new KAction( KIcon("bell"), i18n( "&Buzz Contact" ), this);
+		connect( m_buzzAction, SIGNAL( triggered(bool) ), this, SLOT( buzzContact() ) );
 	}
 	if ( isReachable() )
 		m_buzzAction->setEnabled( true );
 	else
 		m_buzzAction->setEnabled( false );
-	actionCollection->append( m_buzzAction );
+	//actionCollection->addAction( "buzz_contact", m_buzzAction );
+        actionCollection->append( m_buzzAction );
 
 	if ( !m_stealthAction )
 	{
-		m_stealthAction = new KAction( i18n( "&Stealth Setting" ), "yahoo_stealthed", KShortcut(), this, SLOT( stealthContact() ), this, "stealth_contact");
+		m_stealthAction = new KAction( KIcon("yahoo_stealthed"), i18n( "&Stealth Setting" ), this );
+		connect( m_stealthAction, SIGNAL( triggered(bool) ), this, SLOT( stealthContact() ) );
 	}
 	if ( isReachable() )
 		m_stealthAction->setEnabled( true );
 	else
 		m_stealthAction->setEnabled( false );
-	actionCollection->append( m_stealthAction );
-	
+	//actionCollection->addAction( "stealth_contact", m_stealthAction );
+        actionCollection->append( m_stealthAction );
+
 	if ( !m_inviteConferenceAction )
 	{
-		m_inviteConferenceAction = new KAction( i18n( "&Invite to Conference" ), "kontact_contacts", KShortcut(), this, SLOT( inviteConference() ), this, "invite_conference");
+		m_inviteConferenceAction = new KAction( KIcon("x-office-contact"), i18n( "&Invite to Conference" ), this ); // icon should probably be "contact-invite", but that doesn't exist... please request an icon on http://techbase.kde.org/index.php?title=Projects/Oxygen/Missing_Icons
+		connect( m_inviteConferenceAction, SIGNAL( triggered(bool) ), this, SLOT( inviteConference() ) );
 	}
 	if ( isReachable() )
 		m_inviteConferenceAction->setEnabled( true );
 	else
 		m_inviteConferenceAction->setEnabled( false );
-	actionCollection->append( m_inviteConferenceAction );
-	
+	//actionCollection->addAction( "invite_conference", m_inviteConferenceAction );
+        actionCollection->append( m_inviteConferenceAction );
+
 	if ( !m_profileAction )
 	{
-		m_profileAction = new KAction( i18n( "&View Yahoo Profile" ), "kontact_notes", KShortcut(), this, SLOT( slotUserProfile() ), this, "profile_contact");
+		m_profileAction = new KAction( KIcon("document-preview"), i18n( "&View Yahoo Profile" ), this );
+		connect( m_profileAction, SIGNAL( triggered(bool) ), this, SLOT( slotUserProfile() ) );
 	}
 	m_profileAction->setEnabled( true );
-	actionCollection->append( m_profileAction );
-	
+	//actionCollection->addAction( "profile_contact", m_profileAction );
+        actionCollection->append( m_profileAction );
+
 	return actionCollection;
-	
-	//return 0L;
 }
 
 void YahooContact::slotUserInfo()
 {
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
+	kDebug(YAHOO_GEN_DEBUG) ;
 	if( !m_YABEntry )
 	{
 		readYABEntry();	// No YABEntry was set, so read the one from contactlist.xml
 	}
-	
-	YahooUserInfoDialog *dlg = new YahooUserInfoDialog( this, Kopete::UI::Global::mainWidget(), "yahoo userinfo" );
+
+	YahooUserInfoDialog *dlg = new YahooUserInfoDialog( this, Kopete::UI::Global::mainWidget() );
 	dlg->setData( *m_YABEntry );
 	dlg->setAccountConnected( m_account->isConnected() );
 	dlg->show();
@@ -444,131 +464,128 @@ void YahooContact::slotUserInfo()
 
 void YahooContact::slotUserProfile()
 {
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
-	
-	QString profileSiteString = QString::fromLatin1("http://profiles.yahoo.com/") + userId();
-	KRun::runURL( KURL( profileSiteString ) , "text/html" );
+	kDebug(YAHOO_GEN_DEBUG) ;
+
+	QString profileSiteString = QLatin1String("http://profiles.yahoo.com/") + userId();
+	KToolInvocation::invokeBrowser(  profileSiteString );
 }
 
-void YahooContact::slotSendFile( const KURL &url)
+void YahooContact::slotSendFile( const KUrl &url)
 {
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
+	kDebug(YAHOO_GEN_DEBUG) ;
 	m_account->sendFile( this, url );
 }
 
 void YahooContact::stealthContact()
 {
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
+	kDebug(YAHOO_GEN_DEBUG) ;
 
-	KDialogBase *stealthSettingDialog = new KDialogBase( Kopete::UI::Global::mainWidget(), "stealthSettingDialog", "true",
-				i18n("Stealth Setting"), KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, true );
-	YahooStealthSetting *stealthWidget = new YahooStealthSetting( stealthSettingDialog, "stealthSettingWidget" );
-	stealthSettingDialog->setMainWidget( stealthWidget );
+	KDialog *stealthSettingDialog = new KDialog( Kopete::UI::Global::mainWidget() );
+	stealthSettingDialog->setCaption( i18n("Stealth Setting") );
+	stealthSettingDialog->setButtons( KDialog::Ok | KDialog::Cancel );
+	stealthSettingDialog->setDefaultButton(KDialog::Ok);
+	stealthSettingDialog->showButtonSeparator(true);
+
+	QWidget* w = new QWidget( stealthSettingDialog );
+	Ui::YahooStealthSetting stealthWidget = Ui::YahooStealthSetting();
+	stealthWidget.setupUi( w );
+	stealthSettingDialog->setMainWidget( w );
 
 	// Prepare dialog
 	if( m_account->myself()->onlineStatus() == YahooProtocol::protocol()->Invisible )
 	{
-		stealthWidget->radioOffline->setEnabled( true );
-		stealthWidget->radioOffline->setChecked( true );
+		stealthWidget.radioOffline->setEnabled( true );
+		stealthWidget.radioOffline->setChecked( true );
 	}
 	if( stealthed() )
-		stealthWidget->radioPermOffline->setChecked( true );
-		
-	
+		stealthWidget.radioPermOffline->setChecked( true );
+
+
 	// Show dialog
 	if ( stealthSettingDialog->exec() == QDialog::Rejected )
-	{	
-		stealthSettingDialog->delayedDestruct();
+	{
+		stealthSettingDialog->deleteLater();
 		return;
 	}
-	
+
 	// Apply permanent setting
-	if( stealthed() && !stealthWidget->radioPermOffline->isChecked() )
+	if( stealthed() && !stealthWidget.radioPermOffline->isChecked() )
 		m_account->yahooSession()->stealthContact( m_userId, Yahoo::StealthPermOffline, Yahoo::StealthNotActive );
-	else if( !stealthed() && stealthWidget->radioPermOffline->isChecked() )
+	else if( !stealthed() && stealthWidget.radioPermOffline->isChecked() )
 		m_account->yahooSession()->stealthContact( m_userId, Yahoo::StealthPermOffline, Yahoo::StealthActive );
-	
+
 	// Apply temporary setting
 	if( m_account->myself()->onlineStatus() == YahooProtocol::protocol()->Invisible )
 	{
-		if( stealthWidget->radioOnline->isChecked() )
+		if( stealthWidget.radioOnline->isChecked() )
 		{
 			m_account->yahooSession()->stealthContact( m_userId, Yahoo::StealthOnline, Yahoo::StealthActive );
 		}
-		else if( stealthWidget->radioOffline->isChecked() )
+		else if( stealthWidget.radioOffline->isChecked() )
 		{
 			m_account->yahooSession()->stealthContact( m_userId, Yahoo::StealthOffline, Yahoo::StealthActive );
 		}
 	}
 
-	stealthSettingDialog->delayedDestruct();
+	stealthSettingDialog->deleteLater();
 }
 
 void YahooContact::buzzContact()
 {
 	Kopete::ContactPtrList m_them = manager(Kopete::Contact::CanCreate)->members();
 	Kopete::Contact *target = m_them.first();
-	
+
 	m_account->yahooSession()->sendBuzz( static_cast<YahooContact*>(target)->m_userId );
 
 	KopeteView *view = manager(Kopete::Contact::CannotCreate)->view(false);
 	if ( view )
 	{
 		Kopete::Message msg = Kopete::Message( manager(Kopete::Contact::CannotCreate)->myself() ,
-					manager(Kopete::Contact::CannotCreate)->members(), i18n("Buzzz!!!"),
-					Kopete::Message::Outbound, Kopete::Message::PlainText,
-					QString::null , Kopete::Message::TypeAction);
+					manager(Kopete::Contact::CannotCreate)->members() );
+		msg.setPlainBody( i18n("Buzz") );
+		msg.setDirection( Kopete::Message::Outbound );
+		msg.setType( Kopete::Message::TypeAction );
+		
 		view->appendMessage( msg );
 	}
 }
 
-void YahooContact::sendBuddyIconChecksum( int checksum )
+void YahooContact::setDisplayPicture(KTemporaryFile *f, int checksum)
 {
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
-	m_account->yahooSession()->sendPictureChecksum( checksum, m_userId );
-	
-}
-
-void YahooContact::sendBuddyIconInfo( const QString &url, int checksum )
-{
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
-	m_account->yahooSession()->sendPictureInformation( m_userId, url, checksum );
-}
-
-void YahooContact::sendBuddyIconUpdate( int type )
-{
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
-	m_account->yahooSession()->sendPictureStatusUpdate( m_userId, type );
-}
-
-void YahooContact::setDisplayPicture(KTempFile *f, int checksum)
-{
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
+	kDebug(YAHOO_GEN_DEBUG) ;
 	if( !f )
 		return;
 	// stolen from msncontact.cpp ;)
-	QString newlocation=locateLocal( "appdata", "yahoopictures/"+ contactId().lower().replace(QRegExp("[./~]"),"-")  +".png"  ) ;
 	setProperty( YahooProtocol::protocol()->iconCheckSum, checksum );
-	
-	KIO::Job *j=KIO::file_move( KURL::fromPathOrURL( f->name() ) , KURL::fromPathOrURL( newlocation ) , -1, true /*overwrite*/ , false /*resume*/ , false /*showProgressInfo*/ );
-	
-	f->setAutoDelete(false);
+
+	Kopete::AvatarManager::AvatarEntry entry;
+	entry.name = contactId();
+	entry.category = Kopete::AvatarManager::Contact;
+	entry.contact = this;
+	entry.image = QImage(f->fileName());
+	entry = Kopete::AvatarManager::self()->add(entry);
+
+	if (!entry.path.isNull())
+	{
+		setProperty( Kopete::Global::Properties::self()->photo(), QString() );
+		setProperty( Kopete::Global::Properties::self()->photo() , entry.path );
+		emit displayPictureChanged();
+	}
+
+	f->setAutoRemove(true);
 	delete f;
-	
-	//let the time to KIO to copy the file
-	connect(j, SIGNAL(result(KIO::Job *)) , this, SLOT(slotEmitDisplayPictureChanged() ));
 }
 
 
 void YahooContact::setYABEntry( YABEntry *entry, bool show )
 {
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << userId() << endl;
+	kDebug(YAHOO_GEN_DEBUG) << userId();
 	if( m_YABEntry )
 		delete m_YABEntry;
-	
+
 	m_YABEntry = entry;
 	writeYABEntry();	// Store data in Contact
-	
+
 	if( show )
 		slotUserInfo();
 }
@@ -579,15 +596,6 @@ const YABEntry *YahooContact::yabEntry()
 	return m_YABEntry;
 }
 
-void YahooContact::slotEmitDisplayPictureChanged()
-{
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
-	QString newlocation=locateLocal( "appdata", "yahoopictures/"+ contactId().lower().replace(QRegExp("[./~]"),"-")  +".png"  ) ;
-	setProperty( Kopete::Global::Properties::self()->photo(), QString::null );
-	setProperty( Kopete::Global::Properties::self()->photo() , newlocation );
-	emit displayPictureChanged();
-}
-
 void YahooContact::inviteConference()
 {
 	m_account->prepareConference( m_userId );
@@ -595,11 +603,11 @@ void YahooContact::inviteConference()
 
 void YahooContact::inviteWebcam()
 {
-	if ( !KStandardDirs::findExe("jasper") )
+	if ( KStandardDirs::findExe("jasper").isEmpty() )
 	{
-		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error, 
-			i18n("I cannot find the jasper image convert program.\njasper is required to render the yahoo webcam images."
-			"\nPlease see %1 for further information.").arg("http://wiki.kde.org/tiki-index.php?page=Kopete%20Webcam%20Support") );
+		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error,
+			i18n("I cannot find the Jasper image conversion program.\nJasper is required to render the Yahoo webcam images."
+			"\nPlease see %1 for further information.", QString("http://wiki.kde.org/tiki-index.php?page=Kopete%20Webcam%20Support") ) );
 		return;
 	}
 	m_account->yahooSession()->sendWebcamInvite( m_userId );
@@ -626,22 +634,22 @@ void YahooContact::webcamPaused()
 
 void YahooContact::initWebcamViewer()
 {
-	//KImageIO::registerFormats();
-	
+	//
+
 	if ( !m_webcamDialog )
 	{
 		m_webcamDialog = new YahooWebcamDialog( userId(), Kopete::UI::Global::mainWidget() );
 // 		QObject::connect( m_webcamDialog, SIGNAL( closeClicked() ), this, SLOT( closeWebcamDialog() ) );
-	
+
 		QObject::connect( this, SIGNAL( signalWebcamClosed( int ) ),
 		                  m_webcamDialog, SLOT( webcamClosed( int ) ) );
-		
+
 		QObject::connect( this, SIGNAL( signalWebcamPaused() ),
 		                  m_webcamDialog, SLOT( webcamPaused() ) );
-		
+
 		QObject::connect( this, SIGNAL ( signalReceivedWebcamImage( const QPixmap& ) ),
 				m_webcamDialog, SLOT( newImage( const QPixmap& ) ) );
-		
+
 		QObject::connect( m_webcamDialog, SIGNAL ( closingWebcamDialog ( ) ),
 				this, SLOT ( closeWebcamDialog ( ) ) );
 	}
@@ -650,14 +658,14 @@ void YahooContact::initWebcamViewer()
 
 void YahooContact::requestWebcam()
 {
-	if ( !KStandardDirs::findExe("jasper") )
+	if ( KStandardDirs::findExe("jasper").isEmpty() )
 	{
-		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error, 
+		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error,
 			i18n("I cannot find the jasper image convert program.\njasper is required to render the yahoo webcam images."
-			"\nPlease see %1 for further information.").arg("http://wiki.kde.org/tiki-index.php?page=Kopete%20Webcam%20Support") );
+			"\nPlease see %1 for further information.", QString("http://wiki.kde.org/tiki-index.php?page=Kopete%20Webcam%20Support") ) );
 		return;
 	}
-	
+
 	if( !m_webcamDialog )
 		initWebcamViewer();
 	m_account->yahooSession()->requestWebcam( contactId() );
@@ -667,13 +675,13 @@ void YahooContact::closeWebcamDialog()
 {
 	QObject::disconnect( this, SIGNAL( signalWebcamClosed( int ) ),
 	                  m_webcamDialog, SLOT( webcamClosed( int ) ) );
-	
+
 	QObject::disconnect( this, SIGNAL( signalWebcamPaused() ),
 	                  m_webcamDialog, SLOT( webcamPaused( ) ) );
-	
+
 	QObject::disconnect( this, SIGNAL ( signalReceivedWebcamImage( const QPixmap& ) ),
 	                  m_webcamDialog, SLOT( newImage( const QPixmap& ) ) );
-	
+
 	QObject::disconnect( m_webcamDialog, SIGNAL ( closingWebcamDialog ( ) ),
 	                  this, SLOT ( closeWebcamDialog ( ) ) );
 	if( m_receivingWebcam )
@@ -684,22 +692,22 @@ void YahooContact::closeWebcamDialog()
 
 void YahooContact::deleteContact()
 {
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
-	
+	kDebug(YAHOO_GEN_DEBUG) ;
+
 	if( !m_account->isOnServer( contactId() ) )
 	{
-		kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << "Contact does not exist on server-side. Not removing..." << endl;		
+		kDebug(YAHOO_GEN_DEBUG) << "Contact does not exist on server-side. Not removing...";
 	}
 	else
 	{
-		kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << "Contact is getting remove from server side contactlist...." << endl;
+		kDebug(YAHOO_GEN_DEBUG) << "Contact is getting remove from server side contact list....";
 		// Delete from YAB first
 		if( !m_YABEntry )
 			readYABEntry();
 		if( m_YABEntry->YABId )
 			m_account->yahooSession()->deleteYABEntry( *m_YABEntry );
-		
-		// Now remove from the contactlist
+
+		// Now remove from the contact list
 		m_account->yahooSession()->removeBuddy( contactId(), m_groupName );
 	}
 	Kopete::Contact::deleteContact();
@@ -707,20 +715,20 @@ void YahooContact::deleteContact()
 
 void YahooContact::writeYABEntry()
 {
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
-	
+	kDebug(YAHOO_GEN_DEBUG) ;
+
 	// Personal
 	setProperty( YahooProtocol::protocol()->propfirstName, m_YABEntry->firstName );
 	setProperty( YahooProtocol::protocol()->propSecondName, m_YABEntry->secondName );
 	setProperty( YahooProtocol::protocol()->propLastName, m_YABEntry->lastName );
 	setProperty( YahooProtocol::protocol()->propNickName, m_YABEntry->nickName );
 	setProperty( YahooProtocol::protocol()->propTitle, m_YABEntry->title );
-	
-	// Primary Information	
+
+	// Primary Information
 	setProperty( YahooProtocol::protocol()->propPhoneMobile, m_YABEntry->phoneMobile );
 	setProperty( YahooProtocol::protocol()->propEmail, m_YABEntry->email );
 	setProperty( YahooProtocol::protocol()->propYABId, m_YABEntry->YABId );
-	
+
 		// Additional Information
 	setProperty( YahooProtocol::protocol()->propPager, m_YABEntry->pager );
 	setProperty( YahooProtocol::protocol()->propFax, m_YABEntry->fax );
@@ -734,7 +742,7 @@ void YahooContact::writeYABEntry()
 	setProperty( YahooProtocol::protocol()->propImSkype, m_YABEntry->imSkype );
 	setProperty( YahooProtocol::protocol()->propImIRC, m_YABEntry->imIRC );
 	setProperty( YahooProtocol::protocol()->propImQQ, m_YABEntry->imQQ );
-	
+
 		// Private Information
 	setProperty( YahooProtocol::protocol()->propPrivateAddress, m_YABEntry->privateAdress );
 	setProperty( YahooProtocol::protocol()->propPrivateCity, m_YABEntry->privateCity );
@@ -743,7 +751,7 @@ void YahooContact::writeYABEntry()
 	setProperty( YahooProtocol::protocol()->propPrivateCountry, m_YABEntry->privateCountry );
 	setProperty( YahooProtocol::protocol()->propPrivatePhone, m_YABEntry->privatePhone );
 	setProperty( YahooProtocol::protocol()->propPrivateURL, m_YABEntry->privateURL );
-	
+
 		// Work Information
 	setProperty( YahooProtocol::protocol()->propCorporation, m_YABEntry->corporation );
 	setProperty( YahooProtocol::protocol()->propWorkAddress, m_YABEntry->workAdress );
@@ -753,8 +761,8 @@ void YahooContact::writeYABEntry()
 	setProperty( YahooProtocol::protocol()->propWorkCountry, m_YABEntry->workCountry );
 	setProperty( YahooProtocol::protocol()->propWorkPhone, m_YABEntry->workPhone );
 	setProperty( YahooProtocol::protocol()->propWorkURL, m_YABEntry->workURL );
-	
-		// Miscellanous
+
+		// Miscellaneous
 	setProperty( YahooProtocol::protocol()->propBirthday, m_YABEntry->birthday.toString( Qt::ISODate ) );
 	setProperty( YahooProtocol::protocol()->propAnniversary, m_YABEntry->anniversary.toString( Qt::ISODate ) );
 	setProperty( YahooProtocol::protocol()->propNotes, m_YABEntry->notes );
@@ -766,10 +774,10 @@ void YahooContact::writeYABEntry()
 
 void YahooContact::readYABEntry()
 {
-	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
+	kDebug(YAHOO_GEN_DEBUG) ;
 	if( m_YABEntry )
 		delete m_YABEntry;
-	
+
 	m_YABEntry = new YABEntry;
 	m_YABEntry->yahooId = userId();
 	// Personal
@@ -778,12 +786,12 @@ void YahooContact::readYABEntry()
 	m_YABEntry->lastName = property( YahooProtocol::protocol()->propLastName ).value().toString();
 	m_YABEntry->nickName = property( YahooProtocol::protocol()->propNickName ).value().toString();
 	m_YABEntry->title = property( YahooProtocol::protocol()->propTitle ).value().toString();
-	
-	// Primary Information	
+
+	// Primary Information
 	m_YABEntry->phoneMobile = property( YahooProtocol::protocol()->propPhoneMobile ).value().toString();
 	m_YABEntry->email = property( YahooProtocol::protocol()->propEmail ).value().toString();
 	m_YABEntry->YABId = property( YahooProtocol::protocol()->propYABId ).value().toInt();
-	
+
 	// Additional Information
 	m_YABEntry->pager = property( YahooProtocol::protocol()->propPager ).value().toString();
 	m_YABEntry->fax = property( YahooProtocol::protocol()->propFax ).value().toString();
@@ -797,7 +805,7 @@ void YahooContact::readYABEntry()
 	m_YABEntry->imSkype = property( YahooProtocol::protocol()->propImSkype ).value().toString();
 	m_YABEntry->imIRC = property( YahooProtocol::protocol()->propImIRC ).value().toString();
 	m_YABEntry->imQQ = property( YahooProtocol::protocol()->propImQQ ).value().toString();
-	
+
 	// Private Information
 	m_YABEntry->privateAdress = property( YahooProtocol::protocol()->propPrivateAddress ).value().toString();
 	m_YABEntry->privateCity = property( YahooProtocol::protocol()->propPrivateCity ).value().toString();
@@ -806,8 +814,8 @@ void YahooContact::readYABEntry()
 	m_YABEntry->privateCountry = property( YahooProtocol::protocol()->propPrivateCountry ).value().toString();
 	m_YABEntry->privatePhone = property( YahooProtocol::protocol()->propPrivatePhone ).value().toString();
 	m_YABEntry->privateURL = property( YahooProtocol::protocol()->propPrivateURL ).value().toString();
-	
-	// Work Information 
+
+	// Work Information
 	m_YABEntry->corporation = property( YahooProtocol::protocol()->propCorporation ).value().toString();
 	m_YABEntry->workAdress = property( YahooProtocol::protocol()->propWorkAddress ).value().toString();
 	m_YABEntry->workCity = property( YahooProtocol::protocol()->propWorkCity ).value().toString();
@@ -817,7 +825,7 @@ void YahooContact::readYABEntry()
 	m_YABEntry->workPhone = property( YahooProtocol::protocol()->propWorkPhone ).value().toString();
 	m_YABEntry->workURL = property( YahooProtocol::protocol()->propWorkURL ).value().toString();
 
-	// Miscellanous
+	// Miscellaneous
 	m_YABEntry->birthday = QDate::fromString( property( YahooProtocol::protocol()->propBirthday ).value().toString(), Qt::ISODate );
 	m_YABEntry->anniversary = QDate::fromString( property( YahooProtocol::protocol()->propAnniversary ).value().toString(), Qt::ISODate );
 	m_YABEntry->notes = property( YahooProtocol::protocol()->propNotes ).value().toString();
