@@ -12,7 +12,7 @@
 //
 //---------------------------------------------------------------------------
 //
-//  $Id: acctselect.cpp,v 1.40 2004/10/07 14:25:22 porten Exp $
+//  $Id: acctselect.cpp 762281 2008-01-16 18:36:48Z uwolfer $
 //
 //---------------------------------------------------------------------------
 //
@@ -28,19 +28,20 @@
 //
 //  You should have received a copy of the GNU Library General Public
 //  License along with this program; if not, write to the Free
-//  Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+//  Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
 //---------------------------------------------------------------------------
 
-
+#define QT3_SUPPORT
+#include <q3listview.h>
+#undef QT3_SUPPORT
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <kurllabel.h>
 #include <qlayout.h>
-#include <qlistview.h>
 #include <qdir.h>
 #include <qregexp.h>
-#include <qwmatrix.h>
+#include <qmatrix.h>
 #include <qcheckbox.h>
 #include <kdialog.h>
 #include <kstandarddirs.h>
@@ -53,27 +54,31 @@
 
 
 AccountingSelector::AccountingSelector(QWidget *parent, bool _isnewaccount, const char *name)
-  :  QWidget(parent, name),
+  :  QWidget(parent),
     isnewaccount(_isnewaccount)
 {
-  QVBoxLayout *l1 = new QVBoxLayout(parent, 0, KDialog::spacingHint());
+  setObjectName(name);
+
+  QVBoxLayout *l1 = new QVBoxLayout(parent);
+  l1->setSpacing(KDialog::spacingHint());
+  l1->setMargin(0);
 
   enable_accounting = new QCheckBox(i18n("&Enable accounting"), parent);
   l1->addWidget(enable_accounting, 1);
   connect(enable_accounting, SIGNAL(toggled(bool)), this, SLOT(enableItems(bool)));
 
   // insert the tree widget
-  tl = new QListView(parent, "treewidget");
+  tl = new Q3ListView(parent, "treewidget");
 
-  connect(tl, SIGNAL(selectionChanged(QListViewItem*)), this,
-          SLOT(slotSelectionChanged(QListViewItem*)));
+  connect(tl, SIGNAL(selectionChanged(Q3ListViewItem*)), this,
+          SLOT(slotSelectionChanged(Q3ListViewItem*)));
   tl->setMinimumSize(220, 200);
   l1->addWidget(tl, 1);
 
-  KURLLabel *up = new KURLLabel(parent);
+  KUrlLabel *up = new KUrlLabel(parent);
   up->setText(i18n("Check for rule updates"));
-  up->setURL("http://developer.kde.org/~kppp/rules.html");
-  connect(up, SIGNAL(leftClickedURL(const QString&)), SLOT(openURL(const QString&)));
+  up->setUrl("http://developer.kde.org/~kppp/rules.html");
+  connect(up, SIGNAL(leftClickedUrl(const QString&)), SLOT(openUrl(const QString&)));
 
   l1->addWidget(up, 1);
 
@@ -96,11 +101,11 @@ AccountingSelector::AccountingSelector(QWidget *parent, bool _isnewaccount, cons
   l1->addLayout(l12);
   QLabel *usevol_l = new QLabel(i18n("Volume accounting:"), parent);
   use_vol = new QComboBox(parent);
-  use_vol->insertItem(i18n("No Accounting"), 0);
-  use_vol->insertItem(i18n("Bytes In"), 1);
-  use_vol->insertItem(i18n("Bytes Out"), 2);
-  use_vol->insertItem(i18n("Bytes In & Out"), 3);
-  use_vol->setCurrentItem(gpppdata.VolAcctEnabled());
+  use_vol->insertItem(0, i18n("No Accounting"));
+  use_vol->insertItem(1, i18n("Bytes In"));
+  use_vol->insertItem(2, i18n("Bytes Out"));
+  use_vol->insertItem(3, i18n("Bytes In & Out"));
+  use_vol->setCurrentIndex(gpppdata.VolAcctEnabled());
   l12->addWidget(usevol_l);
   l12->addWidget(use_vol);
 
@@ -109,9 +114,9 @@ AccountingSelector::AccountingSelector(QWidget *parent, bool _isnewaccount, cons
 
   // scale the pixmap
   if(pmfolder.width() > 0) {
-    QWMatrix wm;
+    QMatrix wm;
     wm.scale(16.0/pmfolder.width(), 16.0/pmfolder.width());
-    pmfolder = pmfolder.xForm(wm);
+    pmfolder = pmfolder.transformed(wm);
   }
 
   // load the pmfolder pixmap from KDEdir
@@ -119,9 +124,9 @@ AccountingSelector::AccountingSelector(QWidget *parent, bool _isnewaccount, cons
 
   // scale the pixmap
   if(pmfile.width() > 0) {
-    QWMatrix wm;
+    QMatrix wm;
     wm.scale(16.0/pmfile.width(), 16.0/pmfile.width());
-    pmfile = pmfile.xForm(wm);
+    pmfile = pmfile.transformed(wm);
   }
 
   enable_accounting->setChecked(gpppdata.AcctEnabled());
@@ -135,7 +140,7 @@ AccountingSelector::AccountingSelector(QWidget *parent, bool _isnewaccount, cons
 QString AccountingSelector::fileNameToName(QString s) {
 
   s.replace('_', " ");
-  return KURL::decode_string(s);
+  return KUrl::decode_string(s);
 
 }
 
@@ -147,9 +152,9 @@ QString AccountingSelector::nameToFileName(QString s) {
 
 }
 
-QListViewItem *AccountingSelector::findByName(QString name)
+Q3ListViewItem *AccountingSelector::findByName(QString name)
 {
-  QListViewItem *ch = tl->firstChild();
+  Q3ListViewItem *ch = tl->firstChild();
   while(ch) {
     if(ch->text(0) == name)
       return ch;
@@ -159,9 +164,9 @@ QListViewItem *AccountingSelector::findByName(QString name)
 }
 
 
-void AccountingSelector::insertDir(QDir d, QListViewItem *root) {
+void AccountingSelector::insertDir(QDir d, Q3ListViewItem *root) {
 
-  QListViewItem* tli = 0;
+  Q3ListViewItem* tli = 0;
 
   // sanity check
   if(!d.exists() || !d.isReadable())
@@ -169,73 +174,81 @@ void AccountingSelector::insertDir(QDir d, QListViewItem *root) {
 
 
   // set up filter
-  d.setNameFilter("*.rst");
+  QStringList filters;
+  filters << "*.rst";
+  d.setNameFilters(filters);
   d.setFilter(QDir::Files);
   d.setSorting(QDir::Name);
 
   // read the list of files
-  const QFileInfoList *list = d.entryInfoList();
-  QFileInfoListIterator it( *list );
-  QFileInfo *fi;
+  const QFileInfoList list = d.entryInfoList();
+  QFileInfoList::const_iterator it = list.begin();
+  QFileInfoList::const_iterator itEnd = list.end();
+  QFileInfo fi;
 
   // traverse the list and insert into the widget
-  while((fi = it.current())) {
-    ++it;
+  while(it != itEnd) {
+    fi = *it;
+	  
+    QString samename = fi.fileName();
 
-    QString samename = fi->fileName();
-
-    QListViewItem *i = findByName(samename);
+    Q3ListViewItem *i = findByName(samename);
 
     // skip this file if already in tree
     if(i)
       continue;
 
     // check if this is the file we should mark
-    QString name = fileNameToName(fi->baseName(true));
+    QString name = fileNameToName(fi.completeBaseName());
     if(root)
-      tli = new QListViewItem(root, name);
+      tli = new Q3ListViewItem(root, name);
     else
-      tli = new QListViewItem(tl, name);
+      tli = new Q3ListViewItem(tl, name);
 
     tli->setPixmap(0, pmfile);
 
     // check if this is the item we are searching for
     // (only in "Edit"-mode, not in "New"-mode
     if(!isnewaccount && !edit_s.isEmpty() &&
-       (edit_s == QString(fi->filePath()).right(edit_s.length()))) {
+       (edit_s == QString(fi.filePath()).right(edit_s.length()))) {
       edit_item = tli;
     }
+    ++it;
   }
 
   // set up a filter for the directories
   d.setFilter(QDir::Dirs);
-  d.setNameFilter("*");
-  const QFileInfoList *dlist = d.entryInfoList();
-  QFileInfoListIterator dit(*dlist);
+  filters.clear();
+  filters << "*";
+  d.setNameFilters(filters);
+  const QFileInfoList dlist = d.entryInfoList();
+  QFileInfoList::const_iterator dit= dlist.begin();
+  QFileInfoList::const_iterator ditEnd = dlist.end();
 
-  while((fi = dit.current())) {
+  while(dit != ditEnd) {
+    fi = *dit;
     // skip "." and ".." directories
-    if(fi->fileName().left(1) != ".") {
+    if(fi.fileName().left(1) != ".") {
       // convert to human-readable name
-      QString name = fileNameToName(fi->fileName());
+      QString name = fileNameToName(fi.fileName());
 
       // if the tree already has an item with this name,
       // skip creation and use this one, otherwise
       // create a new entry
-      QListViewItem *i = findByName(name);
+      Q3ListViewItem *i = findByName(name);
       if(!i) {
-        QListViewItem* item;
+        Q3ListViewItem* item;
 
         if(root)
-          item = new QListViewItem(root, name);
+          item = new Q3ListViewItem(root, name);
         else
-          item = new QListViewItem(tl, name);
+          item = new Q3ListViewItem(tl, name);
 
         item->setPixmap(0, pmfolder);
 
-	insertDir(QDir(fi->filePath()), item);
+	insertDir(QDir(fi.filePath()), item);
       } else
-	insertDir(QDir(fi->filePath()), i);
+	insertDir(QDir(fi.filePath()), i);
     }
     ++dit;
   }
@@ -281,10 +294,10 @@ void AccountingSelector::enableItems(bool enabled) {
   if(!enabled || (!tl->currentItem()))
     selected->setText(i18n("(none)"));
   else {
-    QListViewItem* i = tl->currentItem();
+    Q3ListViewItem* i = tl->currentItem();
     QString s;
     while(i) {
-      s = "/" + i->text(0) + s;
+      s = '/' + i->text(0) + s;
       i = i->parent();
     }
     selected->setText(s.mid(1));
@@ -295,7 +308,7 @@ void AccountingSelector::enableItems(bool enabled) {
 }
 
 
-void AccountingSelector::slotSelectionChanged(QListViewItem* i) {
+void AccountingSelector::slotSelectionChanged(Q3ListViewItem* i) {
 
   if(!i || i->childCount())
     return;
@@ -317,13 +330,13 @@ bool AccountingSelector::save() {
     gpppdata.setAcctEnabled(false);
   }
 
-  gpppdata.setVolAcctEnabled(use_vol->currentItem());
+  gpppdata.setVolAcctEnabled(use_vol->currentIndex());
 
   return true;
 }
 
-void AccountingSelector::openURL(const QString &url) {
-  new KRun( KURL( url ) );
+void AccountingSelector::openUrl(const QString &url) {
+  new KRun( KUrl( url ),this);
 }
 
 #include "acctselect.moc"
