@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "log.h"
@@ -23,47 +23,51 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#include <qprogressdialog.h>
+#include <QProgressDialog>
+#include <QApplication>
 #include <qdir.h>
 
-#include <kapplication.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
 
-QPtrList<LogInfo> logList;
+Q3PtrList<LogInfo> logList;
 QProgressDialog *dlg;
 
 int loadLogs() {
   int logsize = 0;
 
-  QString logdirname = locateLocal("data", "kppp/Log/");
+  QString logdirname = KStandardDirs::locateLocal("data", "kppp/Log/");
   QDir logdir(logdirname, "*.log");
 
-  kdDebug() << "logdirname: " << logdirname << endl;
+  kDebug(5002) << "logdirname: " << logdirname;
   
   // get log file size
-  const QFileInfoList *list = logdir.entryInfoList();
-  QFileInfoListIterator it( *list );
-  QFileInfo *fi;
+  QFileInfoList list = logdir.entryInfoList();
+  QFileInfoList::const_iterator it = list.begin();
+  QFileInfoList::const_iterator itEnd = list.end();
+  QFileInfo fi;
 
-  while ((fi = it.current()) != 0) {
-    logsize += fi->size();
+  while (it != itEnd) {
+    fi = *it;
+    logsize += fi.size();
     ++it;
   }
 
   dlg = new QProgressDialog(i18n("Loading log files"),
-			     QString::null,
-			     logsize);
-  dlg->setProgress(0);
+			     QString(),
+			     0,logsize,0, 0);
+  dlg->setValue(0);
 
   // load logs
   list = logdir.entryInfoList();
-  QFileInfoListIterator it1( *list );
+  QFileInfoListIterator it1 = list.begin();
+  QFileInfoListIterator it1End = list.end();
 
   int retval = 0;
-  while ((fi = it1.current()) != 0) {
-    retval += loadLog(fi->absFilePath());
+  while (it1 != it1End) {
+    fi = *it1;
+    retval += loadLog(fi.absoluteFilePath());
     ++it1;
   }
 
@@ -71,7 +75,7 @@ int loadLogs() {
   return retval;
 }
 
-int loadLog(QString fname) {
+int loadLog(const QString &fname) {
   FILE *f;
   int warning=0;
 
@@ -91,8 +95,8 @@ int loadLog(QString fname) {
     if(slen < 10)
       continue;
     
-    dlg->setProgress(dlg->progress() + slen);
-    kapp->processEvents();
+    dlg->setValue(dlg->value() + slen);
+    qApp->processEvents();
 
     LogInfo *li = new LogInfo(buffer);    
     if(li->error()) {
@@ -100,7 +104,7 @@ int loadLog(QString fname) {
       // check if the connection has been terminated abnormally
       if(li->error() != 3) {
 	warning++;    
-	kdError() << "ERROR IN FILE " << fname << " LINE " << lineno << "\"" << buffer << "\" (" << li->error() << ")" << endl;
+	kError() << "ERROR IN FILE " << fname << " LINE " << lineno << "\"" << buffer << "\" (" << li->error() << ")" << endl;
 	delete li;
       } else
 	logList.append(li);
@@ -127,3 +131,4 @@ int QLogList::compareItems(Item a, Item b) {
   else
     return 0;
 }
+
