@@ -12,7 +12,7 @@
 //
 //---------------------------------------------------------------------------
 //
-//  $Id: modemdb.cpp,v 1.26 2004/04/13 16:10:50 binner Exp $
+//  $Id: modemdb.cpp 721935 2007-10-06 09:51:00Z apaku $
 //
 //---------------------------------------------------------------------------
 //
@@ -28,63 +28,61 @@
 //
 //  You should have received a copy of the GNU Library General Public
 //  License along with this program; if not, write to the Free
-//  Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+//  Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
 //---------------------------------------------------------------------------
 
 #include <qlabel.h>
-#include <kbuttonbox.h>
+//Added by qt3to4:
+#include <QVBoxLayout>
+#include <QHBoxLayout>
 #include <qlayout.h>
 #include "modemdb.h"
 #include <klocale.h>
 #include <qpushbutton.h>
-#include <qlistbox.h>
+#include <q3listbox.h>
 #include <kconfig.h>
-#include <kstdguiitem.h>
+#include <KStandardGuiItem>
+#include <kguiitem.h>
+#include <kdialog.h>
 
-ModemSelector::ModemSelector(QWidget *parent) : QDialog(parent, 0, true) {
+ModemSelector::ModemSelector(QWidget *parent) : KDialog(parent) {
   // set up widgets and such
-  setCaption(i18n("Select Modem Type"));
-  QVBoxLayout *tl = new QVBoxLayout(this, 10, 10);
+  setWindowTitle(i18n("Select Modem Type"));
+  QVBoxLayout *tl = new QVBoxLayout(this);
+  tl->setSpacing(10);
+  tl->setMargin(10);
   QLabel *l1 = new QLabel(i18n("To set up your modem, first choose its vendor in the "
 			       "list to the left, and then select the model from the "
 			       "right list. If you don't know which modem you have, "
 			       "you can try out one of the \"Generic\" modems."),
 			this);
-  l1->setAlignment(AlignLeft | WordBreak);
+  l1->setAlignment(Qt::AlignLeft);
+  l1->setWordWrap( true );
   l1->setFixedWidth(400);
   l1->setMinimumHeight(50);
   tl->addWidget(l1, 0);
 
   tl->addSpacing(10);
 
-  QHBoxLayout *tl1 = new QHBoxLayout(10);
+  QHBoxLayout *tl1 = new QHBoxLayout();
+  tl1->setSpacing( 10 );
   tl->addLayout(tl1, 1);
-  vendor = new QListBox(this);
-  model  = new QListBox(this);
+  vendor = new Q3ListBox(this);
+  model  = new Q3ListBox(this);
   vendor->setMinimumSize(200, 130);
   model->setMinimumSize(200, 130);
   tl1->addWidget(vendor, 2);
   tl1->addWidget(model, 3);
 
-  KButtonBox *bbox = new KButtonBox(this);
-  bbox->addStretch(1);
-  ok = bbox->addButton(KStdGuiItem::ok());
-  ok->setDefault(true);
-  ok->setEnabled(false);
-  cancel =   bbox->addButton(KStdGuiItem::cancel());
-  bbox->layout();
-  tl->addWidget(bbox);
+  setButtons(Ok|Cancel);
+  enableButton(Ok,false);
   setFixedSize(sizeHint());
 
   // set up modem database
   db = new ModemDatabase();
 
   // set up signal/slots
-  connect(ok, SIGNAL(clicked()),
-	  this, SLOT(reject()));
-  connect(cancel, SIGNAL(clicked()),
-	  this, SLOT(reject()));
   connect(vendor, SIGNAL(highlighted(int)),
 	  this, SLOT(vendorSelected(int)));
   connect(model, SIGNAL(highlighted(int)),
@@ -105,7 +103,7 @@ ModemSelector::~ModemSelector() {
 
 
 void ModemSelector::vendorSelected(int idx) {
-  ok->setEnabled(false);
+  enableButton(Ok,false);
 
   QString name = vendor->text(idx);
   QStringList *models = db->models(name);
@@ -120,7 +118,7 @@ void ModemSelector::vendorSelected(int idx) {
 
 
 void ModemSelector::modelSelected(int) {
-  ok->setEnabled(true);
+  enableButton(Ok,true);
 }
 
 void ModemSelector::selected(int) {
@@ -169,7 +167,6 @@ void ModemDatabase::loadModem(const QString &key, CharDict &dict) {
   QMap <QString, QString> map;
   QMap <QString, QString>::Iterator it;
   //  KEntryMapConstIterator e;
-  KEntry e;
   map = modemDB->entryMap(key);
   it = map.begin();
 
@@ -180,7 +177,7 @@ void ModemDatabase::loadModem(const QString &key, CharDict &dict) {
   //  e = it->current();
   while(!it.key().isNull()) {
     if(dict.find(it.key()) == 0) {
-      dict.insert(it.key(), new QString(it.data()));
+      dict.insert(it.key(), new QString(it.value()));
     }
     it++;
   }
@@ -202,14 +199,14 @@ void ModemDatabase::loadModem(const QString &key, CharDict &dict) {
 
 
 void ModemDatabase::load() {
-  modemDB = new KConfig("DB/modemDB.rc", 0);
+  modemDB = new KConfig("DB/modemDB.rc");
   lvendors = new QStringList;
   modems.setAutoDelete(true);
 
   QStringList list = modemDB->groupList();
   QStringList::Iterator it = list.begin();
   while(it != list.end()) {
-    modemDB->setGroup(*it);
+	KConfigGroup cg ( modemDB, *it);
     CharDict *c = new CharDict;
     c->setAutoDelete(true);
     loadModem(*it, *c);
@@ -224,9 +221,9 @@ void ModemDatabase::load() {
     }
     modems.append(c);
 
-    if(modemDB->hasKey("Vendor")) {
-      QString vendor = modemDB->readEntry("Vendor");
-      if(lvendors->findIndex(vendor) == -1)
+    if(cg.hasKey("Vendor")) {
+      QString vendor = cg.readEntry("Vendor");
+      if(lvendors->indexOf(vendor) == -1)
 	lvendors->append(vendor);
     }
     ++it;
