@@ -2,7 +2,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: opener.cpp 764273 2008-01-21 10:37:10Z hasso $
+ * $Id: opener.cpp 860922 2008-09-14 16:29:02Z woebbe $
  *
  *              Copyright (C) 1997,98 Bernd Johannes Wuebben,
  *		                      Mario Weilguni
@@ -195,8 +195,8 @@ void Opener::mainLoop() {
 	Debug("Opener: received OpenLock\n");
 	MY_ASSERT(len == sizeof(struct OpenLockRequest));
 	flags = request.lock.flags;
-	MY_ASSERT(flags == O_RDONLY || flags == O_WRONLY|O_TRUNC|O_CREAT);
-	if(flags == O_WRONLY|O_TRUNC|O_CREAT)
+	MY_ASSERT(flags == O_RDONLY || flags == (O_WRONLY|O_TRUNC|O_CREAT));
+	if(flags == (O_WRONLY|O_TRUNC|O_CREAT))
 	  mode = 0644;
 	else
 	  mode = 0;
